@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -24,18 +24,16 @@
 #include "data/localsettings.h"
 #include "data/bookmarksstore.h"
 #include "data/credentialsstore.h"
+#include "data/certificatesstore.h"
 #include "data/datamanager.h"
+#include "dialogs/dialogmanager.h"
 #include "dialogs/aboutbox.h"
 #include "utils/networkproxyfactory.h"
 #include "utils/updateclient.h"
+#include "utils/inifile.h"
 #include "utils/iconloader.h"
 #include "views/viewmanager.h"
 
-#if defined( HAVE_OPENSSL )
-#include "data/certificatesstore.h"
-#endif
-
-#include <QSettings>
 #include <QSessionManager>
 #include <QMessageBox>
 #include <QDir>
@@ -46,6 +44,8 @@
 #include <QNetworkAccessManager>
 #include <QPushButton>
 #include <QPrinter>
+#include <QTimer>
+#include <QSettings>
 
 #if defined( Q_WS_WIN )
 #define _WIN32_IE 0x0400
@@ -71,7 +71,7 @@ Application::Application( int& argc, char** argv ) : QApplication( argc, argv ),
     m_settings = new LocalSettings( locateDataFile( "settings.dat" ), this );
     m_bookmarks = new BookmarksStore( locateDataFile( "bookmarks.dat" ), this );
     m_credentials = new CredentialsStore( locateDataFile( "credentials.dat" ), this );
-#if defined( HAVE_OPENSSL )
+#if !defined( QT_NO_OPENSSL )
     m_certificates = new CertificatesStore( locateDataFile( "certificates.crt" ), this );
 #endif
 
@@ -88,14 +88,17 @@ Application::Application( int& argc, char** argv ) : QApplication( argc, argv ),
     setQuitOnLastWindowClosed( false );
 
     viewManager = new ViewManager();
+    dialogManager = new DialogManager();
 
     m_mainWindow = new MainWindow();
 
+    m_editorFont.setFamily( "Verdana, DejaVu Sans" );
+    m_editorFont.setPointSizeF( font().pointSizeF() );
+    m_editorFont.setStyleHint( QFont::SansSerif );
+
     m_manager = new QNetworkAccessManager();
 
-#if !defined( NO_PROXY_FACTORY )
     m_manager->setProxyFactory( new NetworkProxyFactory() );
-#endif
 
     m_updateClient = new UpdateClient( "webissues", version(), m_manager );
 
@@ -118,6 +121,9 @@ Application::~Application()
     delete viewManager;
     viewManager = NULL;
 
+    delete dialogManager;
+    dialogManager = NULL;
+
     delete m_mainWindow;
     m_mainWindow = NULL;
 
@@ -132,6 +138,12 @@ Application::~Application()
 
     delete m_printer;
     m_printer = NULL;
+
+    delete m_localeIni;
+    m_localeIni = NULL;
+
+    delete m_formatsIni;
+    m_formatsIni = NULL;
 }
 
 void Application::commitData( QSessionManager& manager )
@@ -153,7 +165,7 @@ void Application::about()
         " it under the terms of the GNU General Public License as published by"
         " the Free Software Foundation, either version 3 of the License, or"
         " (at your option) any later version." ) + "</p>";
-    message += "<p>" + trUtf8( "Copyright &copy; 2006 Michał Męciński" ) + "<br>" + tr( "Copyright &copy; 2007-2012 WebIssues Team" ) + "</p>";
+    message += "<p>" + trUtf8( "Copyright &copy; 2006 Michał Męciński" ) + "<br>" + tr( "Copyright &copy; 2007-2013 WebIssues Team" ) + "</p>";
 
     QString link = "<a href=\"http://webissues.mimec.org\">webissues.mimec.org</a>";
 
@@ -293,37 +305,22 @@ void Application::openDownloads()
 
 QString Application::version() const
 {
-    return QString( "1.0.2" );
+    return QString( "1.1.1" );
 }
 
 QString Application::protocolVersion() const
 {
-    return QString( "1.0" );
+    return QString( "1.1" );
 }
 
 void Application::initializeLanguage()
 {
-    QSettings settings( m_translationsPath + "/locale.ini", QSettings::IniFormat );
-#if ( QT_VERSION >= 0x040500 )
-    settings.setIniCodec( "UTF8" );
-#endif
+    m_localeIni = new IniFile( ":/resources/locale.ini" );
+    m_localeIni->load( m_translationsPath + "/locale.ini" );
 
-    settings.beginGroup( "languages" );
-    QStringList keys = settings.allKeys();
+    m_formatsIni = new IniFile( ":/resources/formats.ini" );
 
-    if ( keys.isEmpty() )
-        m_languages.insert( "en_US", "English / United States" );
-
-    foreach ( QString key, keys ) {
-        QString name = settings.value( key ).toString();
-#if ( QT_VERSION < 0x040500 )
-        QByteArray raw = name.toLatin1();
-        name = QString::fromUtf8( raw.data(), raw.size() );
-#endif
-        m_languages.insert( key, name );
-    }
-
-    settings.endGroup();
+    QMap<QString, QString> availableLanguages = languages();
 
     QString language = m_settings->value( "Language" ).toString();
     if ( language.isEmpty() )
@@ -332,7 +329,7 @@ void Application::initializeLanguage()
     m_language = "en_US";
 
     while ( !language.isEmpty() ) {
-        if ( m_languages.contains( language ) ) {
+        if ( availableLanguages.contains( language ) ) {
             m_language = language;
             break;
         }
@@ -370,6 +367,29 @@ bool Application::loadTranslation( const QString& name, bool tryQtDir )
     return false;
 }
 
+QMap<QString, QString> Application::languages() const
+{
+    return m_localeIni->values( "languages" );
+}
+
+QString Application::locale( const QString& key ) const
+{
+    QString value = m_localeIni->value( m_language, key );
+    if ( value.isEmpty() )
+        value = m_localeIni->value( "global", key );
+    return value;
+}
+
+QMap<QString, QString> Application::formats( const QString& type ) const
+{
+    return m_formatsIni->values( type );
+}
+
+QString Application::format( const QString& type, const QString& key ) const
+{
+    return m_formatsIni->value( type, key );
+}
+
 void Application::initializeDefaultPaths()
 {
     // NOTE: update these paths after changing them in the project file
@@ -387,32 +407,35 @@ void Application::initializeDefaultPaths()
     m_translationsPath = QDir::cleanPath( appPath + "/../share/webissues/translations" );
 #endif
 
+    QString dataPath;
+    QString cachePath;
+
 #if defined( Q_WS_WIN )
     wchar_t appDataPath[ MAX_PATH ];
     if ( SHGetSpecialFolderPath( 0, appDataPath, CSIDL_APPDATA, FALSE ) )
-        m_dataPath = QDir::fromNativeSeparators( QString::fromWCharArray( appDataPath ) );
+        dataPath = QDir::fromNativeSeparators( QString::fromWCharArray( appDataPath ) );
     else
-        m_dataPath = QDir::homePath();
+        dataPath = QDir::homePath();
 
-    m_dataPath += QLatin1String( "/WebIssues Client/1.0" );
+    m_dataPath = dataPath + QLatin1String( "/WebIssues Client/1.1" );
+    m_oldDataPath = dataPath + QLatin1String( "/WebIssues Client/1.0" );
 
     wchar_t localAppDataPath[ MAX_PATH ];
     if ( SHGetSpecialFolderPath( 0, localAppDataPath, CSIDL_LOCAL_APPDATA, FALSE ) )
-        m_cachePath = QDir::fromNativeSeparators( QString::fromWCharArray( localAppDataPath ) );
+        cachePath = QDir::fromNativeSeparators( QString::fromWCharArray( localAppDataPath ) );
     else
-        m_cachePath = QDir::homePath();
+        cachePath = QDir::homePath();
 
-    m_cachePath += QLatin1String( "/WebIssues Client/1.0/cache" );
-
-    m_tempPath = QDir::tempPath() + "/WebIssues Client";
+    m_cachePath = cachePath + QLatin1String( "/WebIssues Client/1.1/cache" );
+    m_sharedCachePath = cachePath + QLatin1String( "/WebIssues Client/shared/cache" );
 #else
-    m_dataPath = QDesktopServices::storageLocation( QDesktopServices::DataLocation );
-    m_dataPath += QLatin1String( "/webissues-1.0" );
+    dataPath = QDesktopServices::storageLocation( QDesktopServices::DataLocation );
+    m_dataPath = dataPath + QLatin1String( "/webissues-1.1" );
+    m_oldDataPath = dataPath + QLatin1String( "/webissues-1.0" );
 
-    m_cachePath = QDesktopServices::storageLocation( QDesktopServices::CacheLocation );
-    m_cachePath += QLatin1String( "/webissues-1.0" );
-
-    m_tempPath = QDir::tempPath() + "/webissues";
+    cachePath = QDesktopServices::storageLocation( QDesktopServices::CacheLocation );
+    m_cachePath = cachePath + QLatin1String( "/webissues-1.1" );
+    m_sharedCachePath = cachePath + QLatin1String( "/webissues-shared" );
 #endif
 }
 
@@ -425,14 +448,15 @@ void Application::processArguments()
         if ( arg == QLatin1String( "-data" ) ) {
             if ( i + 1 < args.count() && !args.at( i + 1 ).startsWith( '-' ) ) {
                 m_dataPath = QDir::fromNativeSeparators( args.at( ++i ) );
+                m_oldDataPath.clear();
                 m_portable = true;
             }
         } else if ( arg == QLatin1String( "-cache" ) ) {
             if ( i + 1 < args.count() && !args.at( i + 1 ).startsWith( '-' ) )
                 m_cachePath = QDir::fromNativeSeparators( args.at( ++i ) );
-        } else if ( arg == QLatin1String( "-temp" ) ) {
+        } else if ( arg == QLatin1String( "-shared" ) ) {
             if ( i + 1 < args.count() && !args.at( i + 1 ).startsWith( '-' ) )
-                m_tempPath = QDir::fromNativeSeparators( args.at( ++i ) );
+                m_sharedCachePath = QDir::fromNativeSeparators( args.at( ++i ) );
         }
     }
 }
@@ -441,7 +465,10 @@ QString Application::locateDataFile( const QString& name )
 {
     QString path = m_dataPath + '/' + name;
 
-    checkAccess( path );
+    if ( checkAccess( path ) ) {
+        if ( !m_oldDataPath.isEmpty() && !QFile::exists( path ) && QFile::exists( m_oldDataPath + '/' + name ) )
+            QFile::copy( m_oldDataPath + '/' + name, path );
+    }
 
     return path;
 }
@@ -455,9 +482,9 @@ QString Application::locateCacheFile( const QString& name )
     return path;
 }
 
-QString Application::locateTempFile( const QString& name )
+QString Application::locateSharedCacheFile( const QString& name )
 {
-    QString path = m_tempPath + '/' + name;
+    QString path = m_sharedCachePath + '/' + name;
 
     checkAccess( path );
 
@@ -490,19 +517,11 @@ void Application::initializeSettings()
         { "ShowAtStartup", (int)RestoreAlways },
         { "ConnectAtStartup", (int)RestoreNever },
         { "AutoStart", false },
-        { "CommentFont", "Verdana" },
-        { "CommentFontSize", 8 },
-        { "ReportFont", "Verdana" },
-        { "ReportFontSize", 8 },
         { "AutoUpdate", true },
         { "DefaultAttachmentAction", (int)ActionAsk },
         { "FolderUpdateInterval", 1 },
         { "UpdateInterval", 5 },
-        { "IssuesCacheSize", 100 },
-        { "AttachmentsCacheSize", 10 },
-#if !defined( NO_PROXY_FACTORY )
         { "ProxyType", (int)QNetworkProxy::NoProxy },
-#endif
     };
 
     for ( int i = 0; i < (int)( sizeof( defaults ) / sizeof( defaults[ 0 ] ) ); i++ ) {
@@ -545,10 +564,15 @@ void Application::restoreState()
 
     if ( m_settings->value( "LastVersion" ).toString() != version() ) {
         m_settings->setValue( "LastVersion", version() );
-        about();
+        QTimer::singleShot( 100, this, SLOT( about() ) );
     }
 }
 
+double Application::textSizeMultiplier() const
+{
+    return QFontMetrics( m_editorFont ).height() / 13.0;
+}
+
 QPrinter* Application::printer()
 {
     if ( !m_printer ) {
@@ -557,3 +581,23 @@ QPrinter* Application::printer()
     }
     return m_printer;
 }
+
+void Application::openUrl( QWidget* parent, const QUrl& url )
+{
+#if defined( Q_WS_WIN )
+    if ( url.isValid() && url.scheme().toLower() == QLatin1String( "file" ) ) {
+        QString path = url.path();
+        if ( path.startsWith( QLatin1Char( '/' ) ) )
+            path = path.mid( 1 );
+        path = QDir::toNativeSeparators( path );
+        QString host = url.host();
+        if ( !host.isEmpty() )
+            path = QLatin1String( "\\\\" ) + host + QLatin1String( "\\" ) + path;
+        if ( !path.isEmpty() )
+            ShellExecute( parent->effectiveWinId(), NULL, (LPCTSTR)path.utf16(), NULL, NULL, SW_NORMAL );
+    } else
+#else
+    Q_UNUSED( parent )
+#endif
+    QDesktopServices::openUrl( url );
+}
