@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -23,17 +23,16 @@
 #include <QApplication>
 #include <QPointer>
 #include <QMap>
+#include <QFont>
 
 class MainWindow;
 class LocalSettings;
 class BookmarksStore;
 class CredentialsStore;
+class CertificatesStore;
 class UpdateClient;
 class AboutBoxSection;
-
-#if defined( HAVE_OPENSSL )
-class CertificatesStore;
-#endif
+class IniFile;
 
 class QNetworkAccessManager;
 class QUrl;
@@ -92,10 +91,10 @@ public:
     QString locateCacheFile( const QString& name );
 
     /**
-    * Return the path of a temporary file.
-    * @param name The name of the temporary file.
+    * Return the path of a shared cache file.
+    * @param name The name of the shared cache file.
     */
-    QString locateTempFile( const QString& name );
+    QString locateSharedCacheFile( const QString& name );
 
     /**
     * Return @c true if application was started in portable mode.
@@ -117,7 +116,7 @@ public:
     */
     CredentialsStore* credentialsStore() const { return m_credentials; }
 
-#if defined( HAVE_OPENSSL )
+#if !defined( QT_NO_OPENSSL )
     /**
     * Return the certificates store.
     */
@@ -127,13 +126,38 @@ public:
     /**
     * Return the list of available languages.
     */
-    const QMap<QString, QString>& languages() const { return m_languages; }
+    QMap<QString, QString> languages() const;
 
     /**
     * Return the current language.
     */
     const QString& language() const { return m_language; }
 
+    /**
+    * Return the default locale setting for the current language.
+    */
+    QString locale( const QString& key ) const;
+
+    /**
+    * Return all format definition of the given type.
+    */
+    QMap<QString, QString> formats( const QString& type ) const;
+
+    /**
+    * Return the format definition with the given type and key.
+    */
+    QString format( const QString& type, const QString& key ) const;
+
+    /**
+    * Return the font used by the text editor.
+    */
+    const QFont editorFont() const { return m_editorFont; }
+
+    /**
+    * Return the text size multiplier for the web view.
+    */
+    double textSizeMultiplier() const;
+
     /**
     * Return the network access manager.
     */
@@ -144,6 +168,11 @@ public:
     */
     QPrinter* printer();
 
+    /**
+    * Wrapper for QDesktopServices::openUrl.
+    */
+    static void openUrl( QWidget* parent, const QUrl& url );
+
 public slots:
     /**
     * Show the About WebIssues dialog.
@@ -186,21 +215,26 @@ private:
     QString m_translationsPath;
 
     QString m_dataPath;
+    QString m_oldDataPath;
     QString m_cachePath;
-    QString m_tempPath;
+    QString m_sharedCachePath;
 
     bool m_portable;
 
     LocalSettings* m_settings;
     BookmarksStore* m_bookmarks;
     CredentialsStore* m_credentials;
-#if defined( HAVE_OPENSSL )
+#if !defined( QT_NO_OPENSSL )
     CertificatesStore* m_certificates;
 #endif
 
-    QMap<QString, QString> m_languages;
     QString m_language;
 
+    IniFile* m_localeIni;
+    IniFile* m_formatsIni;
+
+    QFont m_editorFont;
+
     QNetworkAccessManager* m_manager;
 
     UpdateClient* m_updateClient;
