@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,10 +20,16 @@
 #include "abstractbatch.h"
 
 AbstractBatch::AbstractBatch( int priority ) :
-    m_priority( priority )
+    m_priority( priority ),
+    m_preventClose( false )
 {
 }
 
 AbstractBatch::~AbstractBatch()
 {
 }
+
+void AbstractBatch::setPreventClose( bool on )
+{
+    m_preventClose= on;
+}
