@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -50,18 +50,34 @@ public:
 public:
     /**
     * Add the <tt>ADD ALERT</tt> command to the batch.
-    * @param typeId Identifier of the folder containing the alert.
+    * @param folderId Identifier of the folder associated with the alert.
     * @param viewId Optional identifier of the view associated with the alert.
     * @param alertEmail Email type for the alert.
+    * @param summaryDays List of days of week on which summary emails are sent.
+    * @param summaryHours List of hours at which summary emails are sent.
+    * @param isPublic @c true if the alert is public, @c false otherwise.
     */
-    void addAlert( int folderId, int viewId, AlertEmail alertEmail );
+    void addAlert( int folderId, int viewId, AlertEmail alertEmail, const QString& summaryDays, const QString& summaryHours, bool isPublic );
+
+    /**
+    * Add the <tt>ADD GLOBAL ALERT</tt> command to the batch.
+    * @param typeId Identifier of the issue type associated the alert.
+    * @param viewId Optional identifier of the view associated with the alert.
+    * @param alertEmail Email type for the alert.
+    * @param summaryDays List of days of week on which summary emails are sent.
+    * @param summaryHours List of hours at which summary emails are sent.
+    * @param isPublic @c true if the alert is public, @c false otherwise.
+    */
+    void addGlobalAlert( int typeId, int viewId, AlertEmail alertEmail, const QString& summaryDays, const QString& summaryHours, bool isPublic );
 
     /**
     * Add the <tt>MODIFY ALERT</tt> command to the batch. 
     * @param alertId Identifier of the alert to modify.
     * @param alertEmail Email type for the alert.
+    * @param summaryDays List of days of week on which summary emails are sent.
+    * @param summaryHours List of hours at which summary emails are sent.
     */
-    void modifyAlert( int alertId, AlertEmail alertEmail );
+    void modifyAlert( int alertId, AlertEmail alertEmail, const QString& summaryDays, const QString& summaryHours );
 
     /**
     * Add the <tt>DELETE ALERT</tt> command to the batch.
@@ -78,6 +94,7 @@ private:
 
 private:
     Command* addAlertJob( const Job& job );
+    Command* addGlobalAlertJob( const Job& job );
     Command* modifyAlertJob( const Job& job );
     Command* deleteAlertJob( const Job& job );
 
