@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,9 @@
 #include "application.h"
 #include "data/localsettings.h"
 #include "data/credentialsstore.h"
+#include "data/certificatesstore.h"
 #include "dialogs/logindialog.h"
+#include "dialogs/ssldialogs.h"
 #include "utils/errorhelper.h"
 
 #include <QNetworkAccessManager>
@@ -36,11 +38,6 @@
 #include <QRegExp>
 #include <QStringList>
 
-#if defined( HAVE_OPENSSL )
-#include "data/certificatesstore.h"
-#include "dialogs/ssldialogs.h"
-#endif
-
 CommandManager* commandManager = NULL;
 
 CommandManager::CommandManager( QNetworkAccessManager* manager ) :
@@ -60,7 +57,7 @@ CommandManager::CommandManager( QNetworkAccessManager* manager ) :
     connect( m_manager, SIGNAL( proxyAuthenticationRequired( const QNetworkProxy&, QAuthenticator* ) ),
         this, SLOT( proxyAuthenticationRequired( const QNetworkProxy&, QAuthenticator* ) ) );
 
-#if defined( HAVE_OPENSSL )
+#if !defined( QT_NO_OPENSSL )
     connect( m_manager, SIGNAL( sslErrors( QNetworkReply*, const QList<QSslError>& ) ),
         this, SLOT( handleSslErrors( QNetworkReply*, const QList<QSslError>& ) ) );
 #endif
@@ -141,6 +138,19 @@ void CommandManager::abortAll()
     }
 }
 
+bool CommandManager::preventClose() const
+{
+    if ( m_currentBatch && m_currentBatch->preventClose() )
+        return true;
+
+    foreach ( AbstractBatch* batch, m_batches ) {
+        if ( batch->preventClose() )
+            return true;
+    }
+
+    return false;
+}
+
 QString CommandManager::errorMessage()
 {
     switch ( m_error ) {
@@ -208,7 +218,10 @@ QString CommandManager::networkError()
             case QNetworkReply::ContentNotFoundError:
                 return tr( "The requested URL was not found" );
             default:
-                return tr( "Server returned an invalid response" );
+                if ( m_statusCode == 406 )
+                    return tr( "The request was not accepted by the server" );
+                else
+                    return tr( "Server returned an invalid response" );
         }
     }
 
@@ -276,6 +289,34 @@ void CommandManager::checkPendingCommand()
     }
 }
 
+static QString userAgent()
+{
+    QString agent = "Mozilla/5.0 (";
+
+#if defined( Q_WS_WIN )
+    agent += QLatin1String( "Windows" );
+#elif defined( Q_WS_MAC )
+    agent += QLatin1String( "Mac OS X" );
+#elif defined( Q_WS_X11 )
+    agent += QLatin1String( "X11; " );
+#if defined( Q_OS_LINUX )
+    agent += QLatin1String( "Linux" );
+#else
+    agent += QLatin1String( "Unknown" );
+#endif
+#else
+    agent += QLatin1String( "Unknown" );
+#endif
+
+    agent += QLatin1String( ") WebIssues/" );
+    agent += application->version();
+
+    agent += QLatin1String( " Qt/" );
+    agent += qVersion();
+
+    return agent;
+}
+
 void CommandManager::sendCommandRequest( Command* command )
 {
     QNetworkRequest request( m_url );
@@ -303,6 +344,13 @@ void CommandManager::sendCommandRequest( Command* command )
 
     request.setHeader( QNetworkRequest::ContentTypeHeader, m_currentMessage->contentType() );
 
+    request.setRawHeader( "User-Agent", userAgent().toLatin1() );
+
+    if ( command->binaryResponseOutput() )
+        request.setRawHeader( "Accept", "application/octet-stream,*/*" );
+    else
+        request.setRawHeader( "Accept", "text/plain,*/*" );
+
     m_statusCode = 0;
     setError( NoError );
 
@@ -321,7 +369,9 @@ void CommandManager::metaDataChanged()
     m_redirectionTarget = m_currentReply->attribute( QNetworkRequest::RedirectionTargetAttribute ).toUrl();
     m_contentType = m_currentReply->header( QNetworkRequest::ContentTypeHeader ).toByteArray();
     m_protocolVersion = m_currentReply->rawHeader( "X-WebIssues-Version" );
+#if !defined( QT_NO_OPENSSL )
     m_sslConfiguration = m_currentReply->sslConfiguration();
+#endif
 
     if ( m_statusCode != 200 )
         return;
@@ -485,7 +535,7 @@ bool CommandManager::validateReply( const Reply& reply )
         ReplyRule replyRule = m_currentCommand->rules().at( rule );
         if ( makeSignature( reply.lines().at( line ) ) == replyRule.signature() ) {
             line++;
-            if ( replyRule.multiplicity() == ReplyRule::One )
+            if ( replyRule.multiplicity() == ReplyRule::One || replyRule.multiplicity() == ReplyRule::ZeroOrOne )
                 rule++;
         } else {
             if ( replyRule.multiplicity() == ReplyRule::One )
@@ -567,7 +617,7 @@ QString CommandManager::unquoteString( const QString& string )
     return result;
 }
 
-void CommandManager::setError( Error error, int code /*= 0*/, const QString& string /*= QString()*/ )
+void CommandManager::setError( Error error, int code, const QString& string )
 {
     m_error = error;
     m_errorCode = code;
@@ -628,7 +678,7 @@ void CommandManager::handleAuthentication( int mode, const QString& hostName, QA
     authenticator->setPassword( password );
 }
 
-#if defined( HAVE_OPENSSL )
+#if !defined( QT_NO_OPENSSL )
 
 void CommandManager::handleSslErrors( QNetworkReply* reply, const QList<QSslError>& errors )
 {
@@ -665,4 +715,4 @@ void CommandManager::handleSslErrors( QNetworkReply* reply, const QList<QSslErro
     reply->ignoreSslErrors();
 }
 
-#endif // defined( HAVE_OPENSSL )
+#endif // !defined( QT_NO_OPENSSL )
