@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -86,18 +86,20 @@ void IssueBatch::deleteIssue()
     setUpdateFolder( true );
 }
 
-void IssueBatch::addComment( const QString& text )
+void IssueBatch::addComment( const QString& text, TextFormat format )
 {
     Job job( &IssueBatch::addCommentJob );
     job.addArg( text );
+    job.addArg( format );
     m_queue.addJob( job );
 }
 
-void IssueBatch::editComment( int commentId, const QString& newText )
+void IssueBatch::editComment( int commentId, const QString& newText, TextFormat newFormat )
 {
     Job job( &IssueBatch::editCommentJob );
     job.addArg( commentId );
     job.addArg( newText );
+    job.addArg( newFormat );
     m_queue.addJob( job );
 }
 
@@ -141,6 +143,27 @@ void IssueBatch::deleteAttachment( int fileId )
     m_queue.addJob( job );
 }
 
+void IssueBatch::addDescription( const QString& text, TextFormat format )
+{
+    Job job( &IssueBatch::addDescriptionJob );
+    job.addArg( text );
+    job.addArg( format );
+    m_queue.addJob( job );
+}
+
+void IssueBatch::editDescription( const QString& newText, TextFormat newFormat )
+{
+    Job job( &IssueBatch::editDescriptionJob );
+    job.addArg( newText );
+    job.addArg( newFormat );
+    m_queue.addJob( job );
+}
+
+void IssueBatch::deleteDescription()
+{
+    m_queue.addJob( &IssueBatch::deleteDescriptionJob );
+}
+
 void IssueBatch::setUpdateFolder( bool update )
 {
     if ( update ) {
@@ -263,6 +286,7 @@ Command* IssueBatch::addCommentJob( const Job& job )
     command->setKeyword( "ADD COMMENT" );
     command->addArg( m_issueId );
     command->addArg( job.argString( 0 ) );
+    command->addArg( job.argInt( 1 ) );
 
     command->addRule( "ID i", ReplyRule::One );
 
@@ -380,6 +404,53 @@ Command* IssueBatch::deleteAttachmentJob( const Job& job )
     return command;
 }
 
+Command* IssueBatch::addDescriptionJob( const Job& job )
+{
+    Command* command = new Command();
+
+    command->setKeyword( "ADD DESCRIPTION" );
+    command->addArg( m_issueId );
+    command->addArg( job.argString( 0 ) );
+    command->addArg( job.argInt( 1 ) );
+
+    command->addRule( "ID i", ReplyRule::One );
+
+    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( setUpdate() ) );
+
+    return command;
+}
+
+Command* IssueBatch::editDescriptionJob( const Job& job )
+{
+    Command* command = new Command();
+
+    command->setKeyword( "EDIT DESCRIPTION" );
+    command->addArg( m_issueId );
+    command->addArg( job.argString( 0 ) );
+    command->addArg( job.argInt( 1 ) );
+
+    command->setAcceptNullReply( true );
+    command->addRule( "ID i", ReplyRule::One );
+
+    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( setUpdate() ) );
+
+    return command;
+}
+
+Command* IssueBatch::deleteDescriptionJob( const Job& /*job*/ )
+{
+    Command* command = new Command();
+
+    command->setKeyword( "DELETE DESCRIPTION" );
+    command->addArg( m_issueId );
+
+    command->addRule( "ID i", ReplyRule::One );
+
+    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( setUpdate() ) );
+
+    return command;
+}
+
 void IssueBatch::addIssueReply( const Reply& reply )
 {
     ReplyLine line = reply.lines().at( 0 );
