@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,8 +20,9 @@
 #ifndef ISSUEBATCH_H
 #define ISSUEBATCH_H
 
-#include "abstractbatch.h"
-#include "batchjob.h"
+#include "commands/abstractbatch.h"
+#include "commands/batchjob.h"
+#include "data/datamanager.h"
 
 class Reply;
 
@@ -86,15 +87,17 @@ public:
     /**
     * Add the <tt>ADD COMMENT</tt> command to the batch.
     * @param text Text of the comment.
+    * @param format Format of the text.
     */
-    void addComment( const QString& text );
+    void addComment( const QString& text, TextFormat format );
 
     /**
     * Add the <tt>EDIT COMMENT</tt> command to the batch.
     * @param commentId Identifier of the comment.
     * @param newText New text of the comment.
+    * @param newFormat New format of the text.
     */
-    void editComment( int commentId, const QString& newText );
+    void editComment( int commentId, const QString& newText, TextFormat newFormat );
 
     /**
     * Add the <tt>DELETE COMMENT</tt> command to the batch.
@@ -131,6 +134,25 @@ public:
     */
     void deleteAttachment( int fileId );
 
+    /**
+    * Add the <tt>ADD DESCRIPTION</tt> command to the batch.
+    * @param text Text of the description.
+    * @param format Format of the description.
+    */
+    void addDescription( const QString& text, TextFormat format );
+
+    /**
+    * Add the <tt>EDIT DESCRIPTION</tt> command to the batch.
+    * @param newText New text of the description.
+    * @param newFormat New format of the description.
+    */
+    void editDescription( const QString& newText, TextFormat newFormat );
+
+    /**
+    * Add the <tt>DELETE DESCRIPTION</tt> command to the batch.
+    */
+    void deleteDescription();
+
     /**
     * If @c true, update folder instead of issue details after making the changes.
     */
@@ -141,6 +163,11 @@ public:
     */
     int issueId() const { return m_issueId; }
 
+    /**
+    * Return the identifier of the folder.
+    */
+    int folderId() const { return m_folderId; }
+
     /**
     * Return the status of reading or writing the attachment file.
     * If the file to upload cannot be opened for reading, the <tt>ADD ATTACHMENT</tt> command is not executed
@@ -188,6 +215,10 @@ private:
     Command* editAttachmentJob( const Job& job );
     Command* deleteAttachmentJob( const Job& job );
 
+    Command* addDescriptionJob( const Job& job );
+    Command* editDescriptionJob( const Job& job );
+    Command* deleteDescriptionJob( const Job& job );
+
 private slots:
     void addIssueReply( const Reply& reply );
 
