@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ Command* SetPreferencesBatch::fetchNext()
 
     if ( m_update ) {
         m_update = false;
-        return dataManager->updateSettings();
+        return dataManager->updateUsers();
     }
 
     return NULL;
@@ -66,8 +66,7 @@ Command* SetPreferencesBatch::setPreferenceJob( const Job& job )
     command->setAcceptNullReply( true );
     command->addRule( "OK", ReplyRule::One );
 
-    if ( m_userId == dataManager->currentUserId() )
-        connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( setUpdate() ) );
+    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( setUpdate() ) );
 
     return command;
 }
