@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -18,12 +18,12 @@
 **************************************************************************/
 
 #include "projectsbatch.h"
-#include "command.h"
 
-#include "data/datamanager.h"
+#include "commands/command.h"
 
 ProjectsBatch::ProjectsBatch() : AbstractBatch( 0 ),
-    m_update( false )
+    m_update( false ),
+    m_newProjectId( 0 )
 {
 }
 
@@ -87,6 +87,47 @@ void ProjectsBatch::moveFolder( int folderId, int projectId )
     m_queue.addJob( job );
 }
 
+void ProjectsBatch::addInitialDescription( const QString& text, TextFormat format )
+{
+    Job job( &ProjectsBatch::addInitialDescriptionJob );
+    job.addArg( text );
+    job.addArg( format );
+    m_queue.addJob( job );
+}
+
+void ProjectsBatch::addProjectDescription( int projectId, const QString& text, TextFormat format )
+{
+    Job job( &ProjectsBatch::addProjectDescriptionJob );
+    job.addArg( projectId );
+    job.addArg( text );
+    job.addArg( format );
+    m_queue.addJob( job );
+}
+
+void ProjectsBatch::editProjectDescription( int projectId, const QString& newText, TextFormat newFormat )
+{
+    Job job( &ProjectsBatch::editProjectDescriptionJob );
+    job.addArg( projectId );
+    job.addArg( newText );
+    job.addArg( newFormat );
+    m_queue.addJob( job );
+}
+
+void ProjectsBatch::deleteProjectDescription( int projectId )
+{
+    Job job( &ProjectsBatch::deleteProjectDescriptionJob );
+    job.addArg( projectId );
+    m_queue.addJob( job );
+}
+
+void ProjectsBatch::setProjectAccess( int projectId, bool isPublic )
+{
+    Job job( &ProjectsBatch::setProjectAccessJob );
+    job.addArg( projectId );
+    job.addArg( isPublic ? 1 : 0 );
+    m_queue.addJob( job );
+}
+
 Command* ProjectsBatch::fetchNext()
 {
     if ( m_queue.moreJobs() )
@@ -109,7 +150,7 @@ Command* ProjectsBatch::addProjectJob( const Job& job )
 
     command->addRule( "ID i", ReplyRule::One );
 
-    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( setUpdate() ) );
+    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( addProjectReply( const Reply& ) ) );
 
     return command;
 }
@@ -201,7 +242,89 @@ Command* ProjectsBatch::moveFolderJob( const Job& job )
     return command;
 }
 
+Command* ProjectsBatch::addInitialDescriptionJob( const Job& job )
+{
+    Command* command = new Command();
+
+    command->setKeyword( "ADD PROJECT DESCRIPTION" );
+    command->addArg( m_newProjectId );
+    command->addArg( job.argString( 0 ) );
+    command->addArg( job.argInt( 1 ) );
+
+    command->addRule( "ID i", ReplyRule::One );
+
+    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( setUpdate() ) );
+
+    return command;
+}
+
+Command* ProjectsBatch::addProjectDescriptionJob( const Job& job )
+{
+    Command* command = new Command();
+
+    command->setKeyword( "ADD PROJECT DESCRIPTION" );
+    command->setArgs( job.args() );
+
+    command->addRule( "ID i", ReplyRule::One );
+
+    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( setUpdate() ) );
+
+    return command;
+}
+
+Command* ProjectsBatch::editProjectDescriptionJob( const Job& job )
+{
+    Command* command = new Command();
+
+    command->setKeyword( "EDIT PROJECT DESCRIPTION" );
+    command->setArgs( job.args() );
+
+    command->setAcceptNullReply( true );
+    command->addRule( "ID i", ReplyRule::One );
+
+    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( setUpdate() ) );
+
+    return command;
+}
+
+Command* ProjectsBatch::deleteProjectDescriptionJob( const Job& job )
+{
+    Command* command = new Command();
+
+    command->setKeyword( "DELETE PROJECT DESCRIPTION" );
+    command->setArgs( job.args() );
+
+    command->addRule( "ID i", ReplyRule::One );
+
+    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( setUpdate() ) );
+
+    return command;
+}
+
+Command* ProjectsBatch::setProjectAccessJob( const Job& job )
+{
+    Command* command = new Command();
+
+    command->setKeyword( "SET PROJECT ACCESS" );
+    command->setArgs( job.args() );
+
+    command->setAcceptNullReply( true );
+    command->addRule( "OK", ReplyRule::One );
+
+    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( setUpdate() ) );
+
+    return command;
+}
+
 void ProjectsBatch::setUpdate()
 {
     m_update = true;
 }
+
+void ProjectsBatch::addProjectReply( const Reply& reply )
+{
+    ReplyLine line = reply.lines().at( 0 );
+    m_newProjectId = line.argInt( 0 );
+
+    m_update = true;
+}
