@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,8 +20,9 @@
 #ifndef PROJECTSBATCH_H
 #define PROJECTSBATCH_H
 
-#include "abstractbatch.h"
-#include "batchjob.h"
+#include "commands/abstractbatch.h"
+#include "commands/batchjob.h"
+#include "data/datamanager.h"
 
 /**
 * Batch for operations on projects and folders.
@@ -94,6 +95,43 @@ public:
     */
     void moveFolder( int folderId, int projectId );
 
+    /**
+    * Add the <tt>ADD PROJECT DESCRIPTION</tt> command to the batch.
+    * The project must be first created using the addProject method.
+    * @param text Text of the description.
+    * @param format Format of the description.
+    */
+    void addInitialDescription( const QString& text, TextFormat format );
+
+    /**
+    * Add the <tt>ADD PROJECT DESCRIPTION</tt> command to the batch.
+    * @param projectId Identifier of the project.
+    * @param text Text of the description.
+    * @param format Format of the description.
+    */
+    void addProjectDescription( int projectId, const QString& text, TextFormat format );
+
+    /**
+    * Add the <tt>EDIT PROJECT DESCRIPTION</tt> command to the batch.
+    * @param projectId Identifier of the project.
+    * @param newText New text of the description.
+    * @param newFormat New format of the description.
+    */
+    void editProjectDescription( int projectId, const QString& newText, TextFormat newFormat );
+
+    /**
+    * Add the <tt>DELETE PROJECT DESCRIPTION</tt> command to the batch.
+    * @param projectId Identifier of the project.
+    */
+    void deleteProjectDescription( int projectId );
+
+    /**
+    * Add the <tt>SET PROJECT ACCESS</tt> command to the batch.
+    * @param projectId Identifier of the project.
+    * @param isPublic @c true if the project is public.
+    */
+    void setProjectAccess( int projectId, bool isPublic );
+
 public: // overrides
     Command* fetchNext();
 
@@ -111,13 +149,24 @@ private:
     Command* deleteFolderJob( const Job& job );
     Command* moveFolderJob( const Job& job );
 
+    Command* addInitialDescriptionJob( const Job& job );
+    Command* addProjectDescriptionJob( const Job& job );
+    Command* editProjectDescriptionJob( const Job& job );
+    Command* deleteProjectDescriptionJob( const Job& job );
+
+    Command* setProjectAccessJob( const Job& job );
+
 private slots:
+    void addProjectReply( const Reply& reply );
+
     void setUpdate();
 
 private:
     JobQueue m_queue;
 
     bool m_update;
+
+    int m_newProjectId;
 };
 
 #endif
