@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -47,6 +47,20 @@ void StateBatch::setFolderRead( int folderId, int readId )
     m_queue.addJob( job );
 }
 
+void StateBatch::addSubscription( int issueId )
+{
+    Job job( &StateBatch::addSubscriptionJob );
+    job.addArg( issueId );
+    m_queue.addJob( job );
+}
+
+void StateBatch::deleteSubscription( int subscriptionId )
+{
+    Job job( &StateBatch::deleteSubscriptionJob );
+    job.addArg( subscriptionId );
+    m_queue.addJob( job );
+}
+
 Command* StateBatch::fetchNext()
 {
     if ( m_queue.moreJobs() )
@@ -90,6 +104,34 @@ Command* StateBatch::setFolderReadJob( const Job& job )
     return command;
 }
 
+Command* StateBatch::addSubscriptionJob( const Job& job )
+{
+    Command* command = new Command();
+
+    command->setKeyword( "ADD SUBSCRIPTION" );
+    command->setArgs( job.args() );
+
+    command->addRule( "ID i", ReplyRule::One );
+
+    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( setUpdate() ) );
+
+    return command;
+}
+
+Command* StateBatch::deleteSubscriptionJob( const Job& job )
+{
+    Command* command = new Command();
+
+    command->setKeyword( "DELETE SUBSCRIPTION" );
+    command->setArgs( job.args() );
+
+    command->addRule( "OK", ReplyRule::One );
+
+    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( setUpdate() ) );
+
+    return command;
+}
+
 void StateBatch::setUpdate()
 {
     m_update = true;
