@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -60,6 +60,18 @@ public:
     */
     void setFolderRead( int folderId, int readId );
 
+    /**
+    * Add the <tt>ADD SUBSCRIPTION</tt> command to the batch.
+    * @param issueId Identifier of the issue.
+    */
+    void addSubscription( int issueId );
+
+    /**
+    * Add the <tt>DELETE SUBSCRIPTION</tt> command to the batch.
+    * @param subscriptionId Identifier of the subscription.
+    */
+    void deleteSubscription( int subscriptionId );
+
 public: // overrides
     Command* fetchNext();
 
@@ -70,6 +82,8 @@ private:
 private:
     Command* setIssueReadJob( const Job& job );
     Command* setFolderReadJob( const Job& job );
+    Command* addSubscriptionJob( const Job& job );
+    Command* deleteSubscriptionJob( const Job& job );
 
 private slots:
     void setUpdate();
