@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -36,18 +36,6 @@ void UpdateBatch::updateSettings()
     m_queue.addJob( &UpdateBatch::updateSettingsJob );
 }
 
-void UpdateBatch::updateLocale()
-{
-    m_queue.addJob( &UpdateBatch::updateLocaleJob );
-}
-
-void UpdateBatch::updatePreferences( int userId )
-{
-    Job job( &UpdateBatch::updatePreferencesJob );
-    job.addArg( userId );
-    m_queue.addJob( job );
-}
-
 void UpdateBatch::updateUsers()
 {
     m_queue.addJob( &UpdateBatch::updateUsersJob );
@@ -68,6 +56,13 @@ void UpdateBatch::updateStates()
     m_queue.addJob( &UpdateBatch::updateStatesJob );
 }
 
+void UpdateBatch::updateSummary( int projectId )
+{
+    Job job( &UpdateBatch::updateSummaryJob );
+    job.addArg( projectId );
+    m_queue.addJob( job );
+}
+
 void UpdateBatch::updateFolder( int folderId )
 {
     Job job( &UpdateBatch::updateFolderJob );
@@ -104,19 +99,6 @@ Command* UpdateBatch::updateSettingsJob( const Job& /*job*/ )
     return dataManager->updateSettings();
 }
 
-Command* UpdateBatch::updateLocaleJob( const Job& /*job*/ )
-{
-    if ( dataManager->localeUpdateNeeded() )
-        return dataManager->updateLocale();
-
-    return NULL;
-}
-
-Command* UpdateBatch::updatePreferencesJob( const Job& job )
-{
-    return dataManager->updatePreferences( job.argInt( 0 ) );
-}
-
 Command* UpdateBatch::updateUsersJob( const Job& /*job*/ )
 {
     return dataManager->updateUsers();
@@ -137,6 +119,16 @@ Command* UpdateBatch::updateStatesJob( const Job& /*job*/ )
     return dataManager->updateStates();
 }
 
+Command* UpdateBatch::updateSummaryJob( const Job& job )
+{
+    int projectId = job.argInt( 0 );
+
+    if ( !m_ifNeeded || dataManager->summaryUpdateNeeded( projectId ) )
+        return dataManager->updateSummary( projectId );
+
+    return NULL;
+}
+
 Command* UpdateBatch::updateFolderJob( const Job& job )
 {
     int folderId = job.argInt( 0 );
