@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -47,16 +47,6 @@ public:
     */
     void updateSettings();
 
-    /**
-    * Add a <tt>GET LOCALE</tt> command to the batch.
-    */
-    void updateLocale();
-
-    /**
-    * Add a <tt>LIST PREFERENCES</tt> command to the batch.
-    */
-    void updatePreferences( int userId );
-
     /**
     * Add a <tt>LIST USERS</tt> command to the batch.
     */
@@ -77,6 +67,11 @@ public:
     */
     void updateStates();
 
+    /**
+    * Add a <tt>GET SUMMARY</tt> command to the batch.
+    */
+    void updateSummary( int projectId );
+
     /**
     * Add a <tt>LIST ISSUES</tt> command to the batch.
     * @param folderId Identifier of the folder to update.
@@ -109,12 +104,11 @@ private:
 
 private:
     Command* updateSettingsJob( const Job& job );
-    Command* updateLocaleJob( const Job& job );
-    Command* updatePreferencesJob( const Job& job );
     Command* updateUsersJob( const Job& job );
     Command* updateTypesJob( const Job& job );
     Command* updateProjectsJob( const Job& job );
     Command* updateStatesJob( const Job& job );
+    Command* updateSummaryJob( const Job& job );
     Command* updateFolderJob( const Job& job );
     Command* updateIssueJob( const Job& job );
 
