@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -17,8 +17,6 @@
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 
-#if defined( HAVE_OPENSSL )
-
 #include "certificatesstore.h"
 
 #include <QFile>
@@ -67,5 +65,3 @@ void CertificatesStore::save()
     for ( int i = 0; i < m_certificates.count(); i++ )
         file.write( m_certificates.at( i ).toPem() );
 }
-
-#endif // defined( HAVE_OPENSSL )
