@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 
 #include <QSqlDatabase>
 #include <QFile>
+#include <QStringList>
 
 DataManager* dataManager = NULL;
 
@@ -38,8 +39,7 @@ DataManager::DataManager() :
     m_currentUserId( 0 ),
     m_currentUserAccess( NoAccess ),
     m_connectionSettings( NULL ),
-    m_fileCache( NULL ),
-    m_localeUpdated( false )
+    m_fileCache( NULL )
 {
 }
 
@@ -49,9 +49,6 @@ DataManager::~DataManager()
         clearIssueLocks();
         closeDatabase();
     }
-
-    if ( m_fileCache )
-        m_fileCache->flush();
 }
 
 static int parseVersion( const QString& version )
@@ -78,6 +75,26 @@ QString DataManager::setting( const QString& key ) const
     return m_settings.value( key );
 }
 
+QString DataManager::preferenceOrSetting( const QString& key ) const
+{
+    if ( m_preferences.contains( key ) )
+        return m_preferences.value( key );
+    return m_settings.value( key );
+}
+
+QString DataManager::preference( const QString& key ) const
+{
+    return m_preferences.value( key );
+}
+
+QString DataManager::localeSetting( const QString& key ) const
+{
+    QString value = preferenceOrSetting( key );
+    if ( value.isEmpty() )
+        value = application->locale( key );
+    return value;
+}
+
 IssueTypeCache* DataManager::issueTypeCache( int typeId )
 {
     IssueTypeCache* cache = m_issueTypesCache.value( typeId );
@@ -158,9 +175,10 @@ bool DataManager::lockDatabase( const QSqlDatabase& database )
     return true;
 }
 
-bool DataManager::installSchema( const QSqlDatabase& database )
+bool DataManager::installSchema( QSqlDatabase& database )
 {
-    const int schemaVersion = 2;
+    const int schemaVersion = 6;
+    const int minSchemaVersion = 3;
 
     Query query( database );
 
@@ -175,22 +193,34 @@ bool DataManager::installSchema( const QSqlDatabase& database )
     if ( currentVersion > schemaVersion )
         return false;
 
-    if ( currentVersion < 1 ) {
+    if ( currentVersion > 0 && currentVersion < minSchemaVersion ) {
+        foreach ( const QString& table, database.tables() ) {
+            if ( !query.execQuery( "DROP TABLE " + table ) )
+                return false;
+        }
+        database.commit();
+        if ( !query.execQuery( "VACUUM" ) )
+            return false;
+        database.transaction();
+        currentVersion = 0;
+    }
+
+    if ( currentVersion == 0 ) {
         const char* schema[] = {
-            "CREATE TABLE alerts ( alert_id integer UNIQUE, folder_id integer, view_id integer, alert_email integer )",
+            "CREATE TABLE alerts ( alert_id integer UNIQUE, folder_id integer, view_id integer, alert_email integer, type_id integer, summary_days text, summary_hours text, is_public integer )",
             "CREATE TABLE alerts_cache ( alert_id integer UNIQUE, total_count integer, modified_count integer, new_count integer )",
             "CREATE TABLE attr_types ( attr_id integer UNIQUE, type_id integer, attr_name text, attr_def text )",
             "CREATE TABLE attr_values ( attr_id integer, issue_id integer, attr_value text, UNIQUE ( attr_id, issue_id ) )",
             "CREATE TABLE changes ( change_id integer UNIQUE, issue_id integer, change_type integer, stamp_id integer, created_time integer, created_user_id integer, "
                 "modified_time integer, modified_user_id integer, attr_id integer, old_value text, new_value text, from_folder_id integer, to_folder_id integer )",
             "CREATE INDEX changes_issue_idx ON changes ( issue_id )",
-            "CREATE TABLE comments ( comment_id integer UNIQUE, comment_text text )",
+            "CREATE TABLE comments ( comment_id integer UNIQUE, comment_text text, comment_format integer )",
             "CREATE TABLE files ( file_id integer UNIQUE, file_name text, file_size integer, file_descr text )",
             "CREATE TABLE folders ( folder_id integer UNIQUE, project_id integer, folder_name text, type_id integer, stamp_id integer )",
             "CREATE TABLE folders_cache ( folder_id integer UNIQUE, list_id integer )",
-            "CREATE TABLE formats ( format_type text, format_key text, format_def text )",
+            "CREATE TABLE issue_descriptions ( issue_id integer UNIQUE, descr_text text, descr_format integer, modified_time integer, modified_user_id integer )",
             "CREATE TABLE issue_locks ( issue_id integer UNIQUE, lock_count integer, last_access integer )",
-            "CREATE TABLE issue_states ( user_id integer, issue_id integer, read_id integer, UNIQUE ( user_id, issue_id ) )",
+            "CREATE TABLE issue_states ( user_id integer, issue_id integer, read_id integer, subscription_id integer, UNIQUE ( user_id, issue_id ) )",
             "CREATE TABLE issue_types ( type_id integer UNIQUE, type_name text )",
             "CREATE TABLE issues ( issue_id integer UNIQUE, folder_id integer, issue_name text, stamp_id integer, created_time integer, created_user_id integer, "
                 "modified_time integer, modified_user_id integer )",
@@ -198,14 +228,22 @@ bool DataManager::installSchema( const QSqlDatabase& database )
             "CREATE TABLE issues_cache ( issue_id integer UNIQUE, details_id integer )",
             "CREATE TABLE languages ( lang_code text, lang_name text )",
             "CREATE TABLE preferences ( user_id integer, pref_key text, pref_value text, UNIQUE ( user_id, pref_key ) )",
-            "CREATE TABLE projects ( project_id integer UNIQUE, project_name text )",
+            "CREATE TABLE project_descriptions ( project_id integer UNIQUE, descr_text text, descr_format integer, modified_time integer, modified_user_id integer )",
+            "CREATE TABLE projects ( project_id integer UNIQUE, project_name text, stamp_id integer, is_public integer )",
+            "CREATE TABLE projects_cache ( project_id integer UNIQUE, summary_id integer )",
             "CREATE TABLE rights ( project_id integer, user_id integer, project_access integer, UNIQUE ( project_id, user_id ) )",
             "CREATE TABLE settings ( set_key text UNIQUE, set_value text )",
             "CREATE TABLE time_zones ( tz_name text, tz_offset integer )",
             "CREATE TABLE users ( user_id integer UNIQUE, user_login text, user_name text, user_access integer )",
             "CREATE TABLE users_cache ( user_id integer UNIQUE, state_id integer )",
             "CREATE TABLE view_settings ( type_id integer, set_key text, set_value text, UNIQUE ( type_id, set_key ) )",
-            "CREATE TABLE views ( view_id integer UNIQUE, type_id integer, view_name text, view_def text, is_public integer )"
+            "CREATE TABLE views ( view_id integer UNIQUE, type_id integer, view_name text, view_def text, is_public integer )",
+            "CREATE VIEW effective_rights AS"
+                " SELECT p.project_id, u.user_id, COALESCE( r.project_access, 1 ) AS project_access "
+                " FROM projects AS p"
+                " CROSS JOIN users AS u"
+                " LEFT OUTER JOIN rights AS r ON r.project_id = p.project_id AND r.user_id = u.user_id"
+                " WHERE r.project_access IS NOT NULL OR p.is_public = 1"
         };
 
         for ( int i = 0; i < (int)( sizeof( schema ) / sizeof( schema[ 0 ] ) ); i++ ) {
@@ -216,22 +254,31 @@ bool DataManager::installSchema( const QSqlDatabase& database )
         currentVersion = schemaVersion;
     }
 
-    if ( currentVersion < 2 ) {
-        if ( !query.execQuery( "SELECT file_id, file_path, file_size FROM files_cache ORDER BY last_access ASC" ) )
+    if ( currentVersion < 4 ) {
+        if ( !query.execQuery( "ALTER TABLE issue_states ADD subscription_id integer" ) )
             return false;
+    }
 
-        while ( query.next() ) {
-            int fileId = query.value( 0 ).toInt();
-            QString path = query.value( 1 ).toString();
-            int size = query.value( 2 ).toInt();
+    if ( currentVersion < 5 ) {
+        if ( !query.execQuery( "ALTER TABLE alerts ADD type_id integer" ) )
+            return false;
+        if ( !query.execQuery( "ALTER TABLE alerts ADD summary_days text" ) )
+            return false;
+        if ( !query.execQuery( "ALTER TABLE alerts ADD summary_hours text" ) )
+            return false;
+        if ( !query.execQuery( "ALTER TABLE alerts ADD is_public integer" ) )
+            return false;
+    }
 
-            if ( QFile::exists( path ) )
-                m_fileCache->commitFile( fileId, path, size );
-        }
-
-        m_fileCache->flush();
-
-        if ( !query.execQuery( "DROP TABLE files_cache" ) )
+    if ( currentVersion < 6 ) {
+        if ( !query.execQuery( "ALTER TABLE projects ADD is_public integer" ) )
+            return false;
+        if ( !query.execQuery( "CREATE VIEW effective_rights AS"
+            " SELECT p.project_id, u.user_id, COALESCE( r.project_access, 1 ) AS project_access "
+            " FROM projects AS p"
+            " CROSS JOIN users AS u"
+            " LEFT OUTER JOIN rights AS r ON r.project_id = p.project_id AND r.user_id = u.user_id"
+            " WHERE r.project_access IS NOT NULL OR p.is_public = 1" ) )
             return false;
     }
 
@@ -249,9 +296,28 @@ void DataManager::closeDatabase()
     database.close();
 }
 
-bool DataManager::localeUpdateNeeded() const
+bool DataManager::summaryUpdateNeeded( int projectId ) const
 {
-    return !m_localeUpdated;
+    QSqlDatabase database = QSqlDatabase::database();
+    Query query( database );
+
+    if ( !query.execQuery( "SELECT stamp_id FROM projects WHERE project_id = ?", projectId ) )
+        return false;
+
+    int stampId = query.readScalar().toInt();
+
+    if ( stampId == 0 )
+        return false;
+
+    if ( !query.execQuery( "SELECT summary_id FROM projects_cache WHERE project_id = ?", projectId ) )
+        return false;
+
+    int lastStampId = query.readScalar().toInt();
+
+    if ( stampId > lastStampId )
+        return true;
+
+    return false;
 }
 
 bool DataManager::folderUpdateNeeded( int folderId ) const
@@ -265,7 +331,7 @@ bool DataManager::folderUpdateNeeded( int folderId ) const
     int stampId = query.readScalar().toInt();
 
     if ( stampId == 0 )
-        return true;
+        return false;
 
     if ( !query.execQuery( "SELECT list_id FROM folders_cache WHERE folder_id = ?", folderId ) )
         return false;
@@ -323,15 +389,14 @@ void DataManager::helloReply( const Reply& reply )
 
     m_connectionSettings = new LocalSettings( locateDataFile( "connection.dat" ), this );
 
-    m_fileCache = new FileCache( m_serverUuid, application->locateCacheFile( "filecache.dat" ), this );
-    m_fileCache->flush();
-
-    connect( application->applicationSettings(), SIGNAL( settingsChanged() ), this, SLOT( settingsChanged() ) );
+    m_fileCache = new FileCache( m_serverUuid, application->locateSharedCacheFile( "cache.dat" ), this );
 
     m_valid = openDatabase();
 
-    if ( m_valid )
+    if ( m_valid ) {
+        recalculateSettings();
         clearIssueLocks();
+    }
 }
 
 Command* DataManager::login( const QString& login, const QString& password )
@@ -381,10 +446,11 @@ Command* DataManager::updateSettings()
     Command* command = new Command();
 
     command->setKeyword( "GET SETTINGS" );
-    command->addArg( application->language() );
 
     command->setAcceptNullReply( true );
     command->addRule( "S ss", ReplyRule::ZeroOrMore );
+    command->addRule( "L ss", ReplyRule::ZeroOrMore );
+    command->addRule( "Z si", ReplyRule::ZeroOrMore );
 
     connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( updateSettingsReply( const Reply& ) ) );
 
@@ -414,64 +480,18 @@ bool DataManager::updateSettingsReply( const Reply& reply, const QSqlDatabase& d
     if ( !query.execQuery( "DELETE FROM settings" ) )
         return false;
 
-    QMap<QString, QString> settings;
+    int i = 0;
 
     query.setQuery( "INSERT INTO settings VALUES ( ?, ? )" );
 
-    for ( int i = 0; i < reply.count() && reply.at( i ).keyword() == QLatin1String( "S" ); i++ ) {
+    for ( ; i < reply.count() && reply.at( i ).keyword() == QLatin1String( "S" ); i++ ) {
         if ( !query.exec( reply.at( i ).args() ) )
             return false;
-
-        settings.insert( reply.at( i ).argString( 0 ), reply.at( i ).argString( 1 ) );
     }
 
-    m_settings = settings;
-
-    m_numberFormat = DefinitionInfo::fromString( m_settings.value( "number_format" ) );
-    m_dateFormat = DefinitionInfo::fromString( m_settings.value( "date_format" ) );
-    m_timeFormat = DefinitionInfo::fromString( m_settings.value( "time_format" ) );
-
-    return true;
-}
-
-Command* DataManager::updateLocale()
-{
-    Command* command = new Command();
-
-    command->setKeyword( "GET LOCALE" );
-
-    command->setAcceptNullReply( true );
-    command->addRule( "L ss", ReplyRule::ZeroOrMore );
-    command->addRule( "F sss", ReplyRule::ZeroOrMore );
-    command->addRule( "Z si", ReplyRule::ZeroOrMore );
-
-    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( updateLocaleReply( const Reply& ) ) );
-
-    return command;
-}
-
-void DataManager::updateLocaleReply( const Reply& reply )
-{
-    QSqlDatabase database = QSqlDatabase::database();
-    database.transaction();
-
-    bool ok = updateLocaleReply( reply, database );
-    if ( ok )
-        ok = database.commit();
-
-    if ( !ok )
-        database.rollback();
-}
-
-bool DataManager::updateLocaleReply( const Reply& reply, const QSqlDatabase& database )
-{
-    Query query( database );
-
     if ( !query.execQuery( "DELETE FROM languages" ) )
         return false;
 
-    int i = 0;
-
     query.setQuery( "INSERT INTO languages VALUES ( ?, ? )" );
 
     for ( ; i < reply.count() && reply.at( i ).keyword() == QLatin1String( "L" ); i++ ) {
@@ -479,16 +499,6 @@ bool DataManager::updateLocaleReply( const Reply& reply, const QSqlDatabase& dat
             return false;
     }
 
-    if ( !query.execQuery( "DELETE FROM formats" ) )
-        return false;
-
-    query.setQuery( "INSERT INTO formats VALUES ( ?, ?, ? )" );
-
-    for ( ; i < reply.count() && reply.at( i ).keyword() == QLatin1String( "F" ); i++ ) {
-        if ( !query.exec( reply.at( i ).args() ) )
-            return false;
-    }
-
     if ( !query.execQuery( "DELETE FROM time_zones" ) )
         return false;
 
@@ -499,57 +509,9 @@ bool DataManager::updateLocaleReply( const Reply& reply, const QSqlDatabase& dat
             return false;
     }
 
-    m_localeUpdated = true;
-
-    return true;
-}
-
-Command* DataManager::updatePreferences( int userId )
-{
-    Command* command = new Command();
-
-    command->setKeyword( "LIST PREFERENCES" );
-    command->addArg( userId );
-
-    command->setAcceptNullReply( true );
-    command->setReportNullReply( true );
-    command->addRule( "P ss", ReplyRule::ZeroOrMore );
-
-    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( updatePreferencesReply( const Reply& ) ) );
-
-    return command;
-}
-
-void DataManager::updatePreferencesReply( const Reply& reply )
-{
-    Command* command = static_cast<Command*>( sender() );
-    int userId = command->argInt( 0 );
-
-    QSqlDatabase database = QSqlDatabase::database();
-    database.transaction();
-
-    bool ok = updatePreferencesReply( reply, userId, database );
-    if ( ok )
-        ok = database.commit();
-
-    if ( !ok )
-        database.rollback();
-}
-
-bool DataManager::updatePreferencesReply( const Reply& reply, int userId, const QSqlDatabase& database )
-{
-    Query query( database );
-
-    if ( !query.execQuery( "DELETE FROM preferences WHERE user_id = ?", userId ) )
+    if ( !recalculateSettings( database ) )
         return false;
 
-    query.setQuery( "INSERT INTO preferences VALUES ( ?, ?, ? )" );
-
-    for ( int i = 0; i < reply.count(); i++ ) {
-        if ( !query.exec( userId, reply.at( i ).arg( 0 ), reply.at( i ).arg( 1 ) ) )
-            return false;
-    }
-
     return true;
 }
 
@@ -562,6 +524,7 @@ Command* DataManager::updateUsers()
     command->setAcceptNullReply( true );
     command->addRule( "U issi", ReplyRule::ZeroOrMore );
     command->addRule( "M iii", ReplyRule::ZeroOrMore );
+    command->addRule( "P iss", ReplyRule::ZeroOrMore );
 
     connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( updateUsersReply( const Reply& ) ) );
 
@@ -610,6 +573,19 @@ bool DataManager::updateUsersReply( const Reply& reply, const QSqlDatabase& data
             return false;
     }
 
+    if ( !query.execQuery( "DELETE FROM preferences" ) )
+        return false;
+
+    query.setQuery( "INSERT INTO preferences VALUES ( ?, ?, ? )" );
+
+    for ( ; i < reply.count(); i++ ) {
+        if ( !query.exec( reply.at( i ).args() ) )
+            return false;
+    }
+
+    if ( !recalculateSettings( database ) )
+        return false;
+
     return true;
 }
 
@@ -710,9 +686,9 @@ Command* DataManager::updateProjects()
 
     command->setAcceptNullReply( true );
     command->setReportNullReply( true );
-    command->addRule( "P is", ReplyRule::ZeroOrMore );
+    command->addRule( "P isii", ReplyRule::ZeroOrMore );
     command->addRule( "F iisii", ReplyRule::ZeroOrMore );
-    command->addRule( "A iiii", ReplyRule::ZeroOrMore );
+    command->addRule( "A iiiiissi", ReplyRule::ZeroOrMore );
 
     connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( updateProjectsReply( const Reply& ) ) );
 
@@ -744,7 +720,7 @@ bool DataManager::updateProjectsReply( const Reply& reply, const QSqlDatabase& d
 
     int i = 0;
 
-    query.setQuery( "INSERT INTO projects VALUES ( ?, ? )" );
+    query.setQuery( "INSERT INTO projects ( project_id, project_name, stamp_id, is_public ) VALUES ( ?, ?, ?, ? )" );
 
     for ( ; i < reply.count() && reply.at( i ).keyword() == QLatin1String( "P" ); i++ ) {
         if ( !query.exec( reply.at( i ).args() ) )
@@ -764,7 +740,7 @@ bool DataManager::updateProjectsReply( const Reply& reply, const QSqlDatabase& d
     if ( !query.execQuery( "DELETE FROM alerts" ) )
         return false;
 
-    query.setQuery( "INSERT INTO alerts VALUES ( ?, ?, ?, ? )" );
+    query.setQuery( "INSERT INTO alerts ( alert_id, folder_id, type_id, view_id, alert_email, summary_days, summary_hours, is_public ) VALUES ( ?, ?, ?, ?, ?, ?, ?, ? )" );
 
     for ( ; i < reply.count() && reply.at( i ).keyword() == QLatin1String( "A" ); i++ ) {
         if ( !query.exec( reply.at( i ).args() ) )
@@ -793,7 +769,7 @@ Command* DataManager::updateStates()
     command->addArg( lastStateId );
 
     command->setAcceptNullReply( true );
-    command->addRule( "S iii", ReplyRule::ZeroOrMore );
+    command->addRule( "S iiii", ReplyRule::ZeroOrMore );
 
     connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( updateStatesReply( const Reply& ) ) );
 
@@ -823,10 +799,10 @@ bool DataManager::updateStatesReply( const Reply& reply, int lastStateId, const
 {
     Query query( database );
 
-    query.setQuery( "INSERT OR REPLACE INTO issue_states VALUES ( ?, ?, ? )" );
+    query.setQuery( "INSERT OR REPLACE INTO issue_states VALUES ( ?, ?, ?, ? )" );
 
     for ( int i = 0; i < reply.count(); i++ ) {
-        if ( !query.exec( m_currentUserId, reply.at( i ).arg( 1 ), reply.at( i ).arg( 2 ) ) )
+        if ( !query.exec( m_currentUserId, reply.at( i ).arg( 1 ), reply.at( i ).arg( 2 ), reply.at( i ).arg( 3 ) ) )
             return false;
 
         int stateId = reply.at( i ).argInt( 0 );
@@ -843,13 +819,88 @@ bool DataManager::updateStatesReply( const Reply& reply, int lastStateId, const
     return true;
 }
 
+Command* DataManager::updateSummary( int projectId )
+{
+    QSqlDatabase database = QSqlDatabase::database();
+    Query query( database );
+
+    if ( !query.execQuery( "SELECT summary_id FROM projects_cache WHERE project_id = ?", projectId ) )
+        return NULL;
+
+    int lastStampId = query.readScalar().toInt();
+
+    Command* command = new Command();
+
+    command->setKeyword( "GET SUMMARY" );
+    command->addArg( projectId );
+    command->addArg( lastStampId );
+
+    command->setAcceptNullReply( true );
+    command->addRule( "P isii", ReplyRule::One );
+    command->addRule( "D isiii", ReplyRule::ZeroOrOne );
+    command->addRule( "DX i", ReplyRule::ZeroOrOne );
+
+    connect( command, SIGNAL( commandReply( const Reply& ) ), this, SLOT( updateSummaryReply( const Reply& ) ) );
+
+    return command;
+}
+
+void DataManager::updateSummaryReply( const Reply& reply )
+{
+    int projectId;
+
+    QSqlDatabase database = QSqlDatabase::database();
+    database.transaction();
+
+    bool ok = updateSummaryReply( reply, database, projectId );
+    if ( ok )
+        ok = database.commit();
+
+    if ( !ok )
+        database.rollback();
+
+    if ( ok ) {
+        notifyObservers( UpdateEvent::Summary, projectId );
+    }
+}
+
+bool DataManager::updateSummaryReply( const Reply& reply, const QSqlDatabase& database, int& projectId )
+{
+    projectId = reply.at( 0 ).argInt( 0 );
+    int lastStampId = reply.at( 0 ).argInt( 2 );
+
+    Query query( database );
+
+    if ( !query.execQuery( "INSERT OR REPLACE INTO projects ( project_id, project_name, stamp_id, is_public ) VALUES ( ?, ?, ?, ? )", reply.at( 0 ).args() ) )
+        return false;
+
+    if ( !query.execQuery( "INSERT OR REPLACE INTO projects_cache VALUES ( ?, ? )", projectId, lastStampId ) )
+        return false;
+
+    int i = 1;
+
+    if ( i < reply.count() && reply.at( i ).keyword() == QLatin1String( "D" ) ) {
+        if ( !query.execQuery( "INSERT OR REPLACE INTO project_descriptions VALUES ( ?, ?, ?, ?, ? )", reply.at( i ).args() ) )
+            return false;
+        i++;
+    }
+
+    if ( i < reply.count() && reply.at( i ).keyword() == QLatin1String( "DX" ) ) {
+        if ( !query.execQuery( "DELETE FROM project_descriptions WHERE project_id = ?", reply.at( i ).args() ) )
+            return false;
+        i++;
+    }
+
+    return true;
+}
+
 Command* DataManager::updateFolder( int folderId )
 {
     QSqlDatabase database = QSqlDatabase::database();
     Query query( database );
 
     if ( !query.execQuery( "SELECT list_id FROM folders_cache WHERE folder_id = ?", folderId ) )
-        return false;
+        return NULL;
 
     int lastStampId = query.readScalar().toInt();
 
@@ -895,6 +946,7 @@ void DataManager::updateFolderReply( const Reply& reply )
 bool DataManager::updateFolderReply( const Reply& reply, const QSqlDatabase& database, QList<int>& updatedFolders )
 {
     int folderId = reply.at( 0 ).argInt( 0 );
+    int typeId = reply.at( 0 ).argInt( 3 );
     int lastStampId = reply.at( 0 ).argInt( 4 );
 
     updatedFolders.append( folderId );
@@ -986,6 +1038,9 @@ bool DataManager::updateFolderReply( const Reply& reply, const QSqlDatabase& dat
             return false;
     }
 
+    if ( !recalculateGlobalAlerts( typeId, database ) )
+        return false;
+
     return true;
 }
 
@@ -1009,8 +1064,10 @@ Command* DataManager::updateIssue( int issueId, bool markAsRead )
     command->setAcceptNullReply( true );
     command->addRule( "I iisiiiii", ReplyRule::One );
     command->addRule( "V iis", ReplyRule::ZeroOrMore );
+    command->addRule( "D isiii", ReplyRule::ZeroOrOne );
+    command->addRule( "DX i", ReplyRule::ZeroOrOne );
     command->addRule( "H iiiiiiiiissii", ReplyRule::ZeroOrMore );
-    command->addRule( "C is", ReplyRule::ZeroOrMore );
+    command->addRule( "C isi", ReplyRule::ZeroOrMore );
     command->addRule( "A isis", ReplyRule::ZeroOrMore );
     command->addRule( "X i", ReplyRule::ZeroOrMore );
 
@@ -1070,6 +1127,11 @@ bool DataManager::updateIssueReply( const Reply& reply, const QSqlDatabase& data
             return false;
     }
 
+    if ( !query.execQuery( "SELECT type_id FROM folders WHERE folder_id = ?", folderId ) )
+        return false;
+
+    int typeId = query.readScalar().toInt();
+
     if ( !query.execQuery( "INSERT OR REPLACE INTO issues VALUES ( ?, ?, ?, ?, ?, ?, ?, ? )", reply.at( 0 ).args() ) )
         return false;
 
@@ -1077,7 +1139,12 @@ bool DataManager::updateIssueReply( const Reply& reply, const QSqlDatabase& data
         return false;
 
     if ( markAsRead ) {
-        if ( !query.execQuery( "INSERT OR REPLACE INTO issue_states VALUES ( ?, ?, ? )", m_currentUserId, issueId, lastStampId ) )
+        if ( !query.execQuery( "SELECT subscription_id FROM issue_states WHERE user_id = ? AND issue_id = ?", m_currentUserId, issueId ) )
+            return false;
+
+        int subscriptionId = query.readScalar().toInt();
+
+        if ( !query.execQuery( "INSERT OR REPLACE INTO issue_states VALUES ( ?, ?, ?, ? )", m_currentUserId, issueId, lastStampId, subscriptionId ) )
             return false;
     }
 
@@ -1090,6 +1157,18 @@ bool DataManager::updateIssueReply( const Reply& reply, const QSqlDatabase& data
             return false;
     }
 
+    if ( i < reply.count() && reply.at( i ).keyword() == QLatin1String( "D" ) ) {
+        if ( !query.execQuery( "INSERT OR REPLACE INTO issue_descriptions VALUES ( ?, ?, ?, ?, ? )", reply.at( i ).args() ) )
+            return false;
+        i++;
+    }
+
+    if ( i < reply.count() && reply.at( i ).keyword() == QLatin1String( "DX" ) ) {
+        if ( !query.execQuery( "DELETE FROM issue_descriptions WHERE issue_id = ?", reply.at( i ).args() ) )
+            return false;
+        i++;
+    }
+
     query.setQuery( "INSERT OR REPLACE INTO changes VALUES ( ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ? )" );
 
     for ( ; i < reply.count() && reply.at( i ).keyword() == QLatin1String( "H" ); i++ ) {
@@ -1097,7 +1176,7 @@ bool DataManager::updateIssueReply( const Reply& reply, const QSqlDatabase& data
             return false;
     }
 
-    query.setQuery( "INSERT OR REPLACE INTO comments VALUES ( ?, ? )" );
+    query.setQuery( "INSERT OR REPLACE INTO comments VALUES ( ?, ?, ? )" );
 
     for ( ; i < reply.count() && reply.at( i ).keyword() == QLatin1String( "C" ); i++ ) {
         if ( !query.exec( reply.at( i ).args() ) )
@@ -1146,6 +1225,11 @@ bool DataManager::updateIssueReply( const Reply& reply, const QSqlDatabase& data
             return false;
     }
 
+    if ( typeId != 0 ) {
+        if ( !recalculateGlobalAlerts( typeId, database ) )
+            return false;
+    }
+
     return true;
 }
 
@@ -1244,18 +1328,17 @@ void DataManager::flushIssueDetails()
 
 bool DataManager::flushIssueDetails( const QSqlDatabase& database )
 {
+    const int maxCount = 100;
+
     Query query( database );
 
     if ( !query.execQuery( "SELECT COUNT(*) FROM issue_locks" ) )
         return false;
 
-    LocalSettings* settings = application->applicationSettings();
-    int limit = settings->value( "IssuesCacheSize" ).toInt();
-
     int count = query.readScalar().toInt();
 
-    if ( count > limit ) {
-        if ( !query.execQuery( "SELECT issue_id FROM issue_locks WHERE lock_count = 0 ORDER BY last_access LIMIT ?", count - limit ) )
+    if ( count > maxCount ) {
+        if ( !query.execQuery( "SELECT issue_id FROM issue_locks WHERE lock_count = 0 ORDER BY last_access LIMIT ?", count - maxCount ) )
             return false;
 
         QList<int> deletedIssues;
@@ -1332,13 +1415,6 @@ void DataManager::commitFile( int fileId, const QString& path, int size )
     m_fileCache->commitFile( fileId, path, size );
 }
 
-void DataManager::settingsChanged()
-{
-    flushIssueDetails();
-
-    m_fileCache->flush();
-}
-
 bool DataManager::recalculateAllAlerts( const QSqlDatabase& database )
 {
     Query query( database );
@@ -1346,11 +1422,19 @@ bool DataManager::recalculateAllAlerts( const QSqlDatabase& database )
     if ( !query.execQuery( "DELETE FROM alerts_cache" ) )
         return false;
 
-    if ( !query.execQuery( "SELECT a.alert_id, f.folder_id, a.view_id FROM alerts AS a JOIN folders AS f ON f.folder_id = a.folder_id" ) )
+    if ( !query.execQuery( "SELECT a.alert_id, f.folder_id, a.view_id FROM alerts AS a JOIN folders AS f ON f.folder_id = a.folder_id WHERE a.folder_id <> 0" ) )
         return false;
 
     while ( query.next() ) {
-        if ( !recalculateAlert( query.value( 0 ).toInt(), query.value( 1 ).toInt(), query.value( 2 ).toInt(), database ) )
+        if ( !recalculateAlert( query.value( 0 ).toInt(), query.value( 1 ).toInt(), 0, query.value( 2 ).toInt(), database ) )
+            return false;
+    }
+
+    if ( !query.execQuery( "SELECT a.alert_id, t.type_id, a.view_id FROM alerts AS a JOIN issue_types AS t ON t.type_id = a.type_id WHERE a.type_id <> 0" ) )
+        return false;
+
+    while ( query.next() ) {
+        if ( !recalculateAlert( query.value( 0 ).toInt(), 0, query.value( 1 ).toInt(), query.value( 2 ).toInt(), database ) )
             return false;
     }
 
@@ -1368,16 +1452,38 @@ bool DataManager::recalculateAlerts( int folderId, const QSqlDatabase& database
         return false;
 
     while ( query.next() ) {
-        if ( !recalculateAlert( query.value( 0 ).toInt(), query.value( 1 ).toInt(), query.value( 2 ).toInt(), database ) )
+        if ( !recalculateAlert( query.value( 0 ).toInt(), query.value( 1 ).toInt(), 0, query.value( 2 ).toInt(), database ) )
             return false;
     }
 
     return true;
 }
 
-bool DataManager::recalculateAlert( int alertId, int folderId, int viewId, const QSqlDatabase& database )
+bool DataManager::recalculateGlobalAlerts( int typeId, const QSqlDatabase& database )
 {
-    QueryGenerator generator( folderId, viewId );
+    Query query( database );
+
+    if ( !query.execQuery( "DELETE FROM alerts_cache WHERE alert_id IN ( SELECT alert_id FROM alerts WHERE type_id = ? )", typeId ) )
+        return false;
+
+    if ( !query.execQuery( "SELECT a.alert_id, t.type_id, a.view_id FROM alerts AS a JOIN issue_types AS t ON t.type_id = a.type_id WHERE t.type_id = ?", typeId ) )
+        return false;
+
+    while ( query.next() ) {
+        if ( !recalculateAlert( query.value( 0 ).toInt(), 0, query.value( 1 ).toInt(), query.value( 2 ).toInt(), database ) )
+            return false;
+    }
+
+    return true;
+}
+
+bool DataManager::recalculateAlert( int alertId, int folderId, int typeId, int viewId, const QSqlDatabase& database )
+{
+    QueryGenerator generator;
+    if ( folderId != 0 )
+        generator.initializeFolder( folderId, viewId );
+    else if ( typeId != 0 )
+        generator.initializeGlobalList( typeId, viewId );
 
     QString sql = generator.query( false );
     if ( sql.isEmpty() )
@@ -1409,3 +1515,49 @@ bool DataManager::recalculateAlert( int alertId, int folderId, int viewId, const
 
     return true;
 }
+
+void DataManager::recalculateSettings()
+{
+    QSqlDatabase database = QSqlDatabase::database();
+    database.transaction();
+
+    bool ok = recalculateSettings( database );
+    if ( ok )
+        ok = database.commit();
+
+    if ( !ok )
+        database.rollback();
+}
+
+bool DataManager::recalculateSettings( const QSqlDatabase& database )
+{
+    Query query( database );
+
+    if ( !query.execQuery( "SELECT set_key, set_value FROM settings" ) )
+        return false;
+
+    m_settings.clear();
+
+    while ( query.next() ) {
+        QString key = query.value( 0 ).toString();
+        QString value = query.value( 1 ).toString();
+        m_settings.insert( key, value );
+    }
+
+    if ( !query.execQuery( "SELECT pref_key, pref_value FROM preferences WHERE user_id = ?", m_currentUserId ) )
+        return false;
+
+    m_preferences.clear();
+
+    while ( query.next() ) {
+        QString key = query.value( 0 ).toString();
+        QString value = query.value( 1 ).toString();
+        m_preferences.insert( key, value );
+    }
+
+    m_numberFormat = DefinitionInfo::fromString( application->format( "number_format", localeSetting( "number_format" ) ) );
+    m_dateFormat = DefinitionInfo::fromString( application->format( "date_format", localeSetting( "date_format" ) ) );
+    m_timeFormat = DefinitionInfo::fromString( application->format( "time_format", localeSetting( "time_format" ) ) );
+
+    return true;
+}
