@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -111,6 +111,21 @@ enum AlertEmail
     SummaryReportEmail = 3
 };
 
+/**
+* Format of comment or description.
+*/
+enum TextFormat
+{
+    /**
+    * Plain text format.
+    */
+    PlainText = 0,
+    /**
+    * Text with markup.
+    */
+    TextWithMarkup = 1
+};
+
 /**
 * Class for storing data retrieved from the Webissues server.
 *
@@ -208,6 +223,27 @@ public:
     */
     QString setting( const QString& key ) const;
 
+    /**
+    * Return the value of a user preference or server setting.
+    * @param key The key of the setting.
+    * @return The value of the setting or an empty string if it doesn't exist.
+    */
+    QString preferenceOrSetting( const QString& key ) const;
+
+    /**
+    * Return the value of a user preference.
+    * @param key The key of the setting.
+    * @return The value of the setting or an empty string if it doesn't exist.
+    */
+    QString preference( const QString& key ) const;
+
+    /**
+    * Return the value of a user preference, server setting or locale setting.
+    * @param key The key of the setting.
+    * @return The value of the setting.
+    */
+    QString localeSetting( const QString& key ) const;
+
     /**
     * Return the definition of the number format.
     */
@@ -256,9 +292,11 @@ public:
     void removeObserver( QObject* observer );
 
     /**
-    * Check if the locale information needs updating.
+    * Check if the project summary needs updating.
+    * @param projectId Identifier of the project.
+    * @return @c True if the project summary needs updating.
     */
-    bool localeUpdateNeeded() const;
+    bool summaryUpdateNeeded( int projectId ) const;
 
     /**
     * Check if the folder needs updating.
@@ -303,16 +341,6 @@ public:
     */
     Command* updateSettings();
 
-    /**
-    * Create a command for retrieving locale information.
-    */
-    Command* updateLocale();
-
-    /**
-    * Create a command for retrieving preferences of the given user.
-    */
-    Command* updatePreferences( int userId );
-
     /**
     * Create a command for updating users and their membership.
     */
@@ -333,6 +361,11 @@ public:
     */
     Command* updateStates();
 
+    /**
+    * Create a command for updating the given project summary.
+    */
+    Command* updateSummary( int projectId );
+
     /**
     * Create a command for updating the given folder.
     */
@@ -388,17 +421,14 @@ private slots:
     void helloReply( const Reply& reply );
     void loginReply( const Reply& reply );
     void updateSettingsReply( const Reply& reply );
-    void updateLocaleReply( const Reply& reply );
-    void updatePreferencesReply( const Reply& reply );
     void updateUsersReply( const Reply& reply );
     void updateTypesReply( const Reply& reply );
     void updateProjectsReply( const Reply& reply );
     void updateStatesReply( const Reply& reply );
+    void updateSummaryReply( const Reply& reply );
     void updateFolderReply( const Reply& reply );
     void updateIssueReply( const Reply& reply );
 
-    void settingsChanged();
-
 private:
     void notifyObservers( UpdateEvent::Unit unit, int id = 0 );
 
@@ -406,15 +436,14 @@ private:
     void closeDatabase();
 
     bool lockDatabase( const QSqlDatabase& database );
-    bool installSchema( const QSqlDatabase& database );
+    bool installSchema( QSqlDatabase& database );
 
     bool updateSettingsReply( const Reply& reply, const QSqlDatabase& database );
-    bool updateLocaleReply( const Reply& reply, const QSqlDatabase& database );
-    bool updatePreferencesReply( const Reply& reply, int userId, const QSqlDatabase& database );
     bool updateUsersReply( const Reply& reply, const QSqlDatabase& database );
     bool updateTypesReply( const Reply& reply, const QSqlDatabase& database );
     bool updateProjectsReply( const Reply& reply, const QSqlDatabase& database );
     bool updateStatesReply( const Reply& reply, int lastStateId, const QSqlDatabase& database );
+    bool updateSummaryReply( const Reply& reply, const QSqlDatabase& database, int& projectId );
     bool updateFolderReply( const Reply& reply, const QSqlDatabase& database, QList<int>& updatedFolders );
     bool updateIssueReply( const Reply& reply, const QSqlDatabase& database, QList<int>& updatedFolders, int& issueId );
 
@@ -430,7 +459,11 @@ private:
 
     bool recalculateAllAlerts( const QSqlDatabase& database );
     bool recalculateAlerts( int folderId, const QSqlDatabase& database );
-    bool recalculateAlert( int alertId, int folderId, int viewId, const QSqlDatabase& database );
+    bool recalculateGlobalAlerts( int typeId, const QSqlDatabase& database );
+    bool recalculateAlert( int alertId, int folderId, int typeId, int viewId, const QSqlDatabase& database );
+
+    void recalculateSettings();
+    bool recalculateSettings( const QSqlDatabase& database );
 
 private:
     bool m_valid;
@@ -446,6 +479,7 @@ private:
 
     LocalSettings* m_connectionSettings;
 
+    QMap<QString, QString> m_preferences;
     QMap<QString, QString> m_settings;
 
     QHash<int, IssueTypeCache*> m_issueTypesCache;
@@ -457,8 +491,6 @@ private:
     DefinitionInfo m_timeFormat;
 
     QList<QObject*> m_observers;
-
-    bool m_localeUpdated;
 };
 
 /**
