@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -46,7 +46,8 @@ ProjectEntity& ProjectEntity::operator =( const ProjectEntity& other )
 }
 
 ProjectEntityData::ProjectEntityData() :
-    m_id( 0 )
+    m_id( 0 ),
+    m_isPublic( false )
 {
 }
 
@@ -69,12 +70,17 @@ const QString& ProjectEntity::name() const
     return d->m_name;
 }
 
+bool ProjectEntity::isPublic() const
+{
+    return d->m_isPublic;
+}
+
 ProjectEntity ProjectEntity::find( int id )
 {
     ProjectEntity entity;
 
     if ( id != 0 ) {
-        Query query( "SELECT project_id, project_name FROM projects WHERE project_id = ?" );
+        Query query( "SELECT project_id, project_name, is_public FROM projects WHERE project_id = ?" );
         query.exec( id );
 
         if ( query.next() )
@@ -88,7 +94,7 @@ QList<ProjectEntity> ProjectEntity::list()
 {
     QList<ProjectEntity> result;
 
-    Query query( "SELECT project_id, project_name FROM projects ORDER BY project_name COLLATE LOCALE" );
+    Query query( "SELECT project_id, project_name, is_public FROM projects ORDER BY project_name COLLATE LOCALE" );
     query.exec();
 
     while ( query.next() ) {
@@ -100,10 +106,33 @@ QList<ProjectEntity> ProjectEntity::list()
     return result;
 }
 
+QList<ProjectEntity> UserEntity::projects() const
+{
+    QList<ProjectEntity> result;
+
+    if ( d->m_id != 0 ) {
+        Query query( "SELECT p.project_id, p.project_name, p.is_public"
+            " FROM projects AS p"
+            " JOIN rights AS r ON r.project_id = p.project_id"
+            " WHERE r.user_id = ?"
+            " ORDER BY p.project_name COLLATE LOCALE" );
+        query.exec( d->m_id );
+
+        while ( query.next() ) {
+            ProjectEntity entity;
+            entity.d->read( query );
+            result.append( entity );
+        }
+    }
+
+    return result;
+}
+
 void ProjectEntityData::read( const Query& query )
 {
     m_id = query.value( 0 ).toInt();
     m_name = query.value( 1 ).toString();
+    m_isPublic = query.value( 2 ).toBool();
 }
 
 bool ProjectEntity::isAdmin( int id )
@@ -664,8 +693,10 @@ AlertEntity& AlertEntity::operator =( const AlertEntity& other )
 AlertEntityData::AlertEntityData() :
     m_id( 0 ),
     m_folderId( 0 ),
+    m_typeId( 0 ),
     m_viewId( 0 ),
-    m_alertEmail( NoEmail )
+    m_alertEmail( NoEmail ),
+    m_isPublic( false )
 {
 }
 
@@ -693,11 +724,31 @@ AlertEmail AlertEntity::alertEmail() const
     return d->m_alertEmail;
 }
 
+const QString& AlertEntity::summaryDays() const
+{
+    return d->m_summaryDays;
+}
+
+const QString& AlertEntity::summaryHours() const
+{
+    return d->m_summaryHours;
+}
+
+bool AlertEntity::isPublic() const
+{
+    return d->m_isPublic;
+}
+
 FolderEntity AlertEntity::folder() const
 {
     return FolderEntity::find( d->m_folderId );
 }
 
+TypeEntity AlertEntity::type() const
+{
+    return TypeEntity::find( d->m_typeId );
+}
+
 ViewEntity AlertEntity::view() const
 {
     return ViewEntity::find( d->m_viewId );
@@ -708,7 +759,7 @@ AlertEntity AlertEntity::find( int id )
     AlertEntity entity;
 
     if ( id != 0 ) {
-        Query query( "SELECT alert_id, folder_id, view_id, alert_email"
+        Query query( "SELECT alert_id, folder_id, type_id, view_id, alert_email, summary_days, summary_hours, is_public"
             " FROM alerts"
             " WHERE alert_id = ?" );
         query.exec( id );
@@ -725,7 +776,7 @@ QList<AlertEntity> FolderEntity::alerts() const
     QList<AlertEntity> result;
 
     if ( d->m_id != 0 ) {
-        Query query( "SELECT alert_id, folder_id, view_id, alert_email"
+        Query query( "SELECT alert_id, folder_id, type_id, view_id, alert_email, summary_days, summary_hours, is_public"
             " FROM alerts"
             " WHERE folder_id = ?" );
         query.exec( d->m_id );
@@ -740,12 +791,36 @@ QList<AlertEntity> FolderEntity::alerts() const
     return result;
 }
 
+QList<AlertEntity> TypeEntity::alerts() const
+{
+    QList<AlertEntity> result;
+
+    if ( d->m_id != 0 ) {
+        Query query( "SELECT alert_id, folder_id, type_id, view_id, alert_email, summary_days, summary_hours, is_public"
+            " FROM alerts"
+            " WHERE type_id = ?" );
+        query.exec( d->m_id );
+
+        while ( query.next() ) {
+            AlertEntity entity;
+            entity.d->read( query );
+            result.append( entity );
+        }
+    }
+
+    return result;
+}
+
 void AlertEntityData::read( const Query& query )
 {
     m_id = query.value( 0 ).toInt();
     m_folderId = query.value( 1 ).toInt();
-    m_viewId = query.value( 2 ).toInt();
-    m_alertEmail = (AlertEmail)query.value( 3 ).toInt();
+    m_typeId = query.value( 2 ).toInt();
+    m_viewId = query.value( 3 ).toInt();
+    m_alertEmail = (AlertEmail)query.value( 4 ).toInt();
+    m_summaryDays = query.value( 5 ).toString();
+    m_summaryHours = query.value( 6 ).toString();
+    m_isPublic = query.value( 7 ).toBool();
 }
 
 UserEntity::UserEntity() :
@@ -958,6 +1033,24 @@ MemberEntity MemberEntity::find( int projectId, int userId )
     return entity;
 }
 
+MemberEntity MemberEntity::findEffective( int projectId, int userId )
+{
+    MemberEntity entity;
+
+    if ( projectId != 0 && userId != 0 ) {
+        Query query( "SELECT r.user_id, r.project_id, u.user_login, u.user_name, r.project_access"
+            " FROM users AS u"
+            " JOIN effective_rights AS r ON r.user_id = u.user_id"
+            " WHERE u.user_id = ? AND r.project_id = ?" );
+        query.exec( userId, projectId );
+
+        if ( query.next() )
+            entity.d->read( query );
+    }
+
+    return entity;
+}
+
 QList<MemberEntity> MemberEntity::list( int userId )
 {
     QList<MemberEntity> result;
@@ -1012,6 +1105,7 @@ IssueEntityData::IssueEntityData() :
     m_id( 0 ),
     m_stampId( 0 ),
     m_readId( 0 ),
+    m_subscriptionId( 0 ),
     m_folderId( 0 ),
     m_typeId( 0 )
 {
@@ -1046,6 +1140,11 @@ int IssueEntity::readId() const
     return d->m_readId;
 }
 
+int IssueEntity::subscriptionId() const
+{
+    return d->m_subscriptionId;
+}
+
 int IssueEntity::folderId() const
 {
     return d->m_folderId;
@@ -1081,7 +1180,7 @@ IssueEntity IssueEntity::find( int id )
     IssueEntity entity;
 
     if ( id != 0 ) {
-        Query query( "SELECT i.issue_id, i.stamp_id, s.read_id, i.folder_id, f.type_id, i.issue_name,"
+        Query query( "SELECT i.issue_id, i.stamp_id, s.read_id, s.subscription_id, i.folder_id, f.type_id, i.issue_name,"
             " i.created_time, uc.user_name AS created_user, i.modified_time, um.user_name AS modified_user"
             " FROM issues AS i"
             " JOIN folders AS f ON f.folder_id = i.folder_id"
@@ -1103,7 +1202,7 @@ QList<IssueEntity> FolderEntity::issues() const
     QList<IssueEntity> result;
 
     if ( d->m_id != 0 ) {
-        Query query( "SELECT i.issue_id, i.stamp_id, s.read_id, i.folder_id, f.type_id, i.issue_name,"
+        Query query( "SELECT i.issue_id, i.stamp_id, s.read_id, s.subscription_id, i.folder_id, f.type_id, i.issue_name,"
             " i.created_time, uc.user_name AS created_user, i.modified_time, um.user_name AS modified_user"
             " FROM issues AS i"
             " JOIN folders AS f ON f.folder_id = i.folder_id"
@@ -1128,13 +1227,25 @@ void IssueEntityData::read( const Query& query )
     m_id = query.value( 0 ).toInt();
     m_stampId = query.value( 1 ).toInt();
     m_readId = query.value( 2 ).toInt();
-    m_folderId = query.value( 3 ).toInt();
-    m_typeId = query.value( 4 ).toInt();
-    m_name = query.value( 5 ).toString();
-    m_createdDate.setTime_t( query.value( 6 ).toInt() );
-    m_createdUser = query.value( 7 ).toString();
-    m_modifiedDate.setTime_t( query.value( 8 ).toInt() );
-    m_modifiedUser = query.value( 9 ).toString();
+    m_subscriptionId = query.value( 3 ).toInt();
+    m_folderId = query.value( 4 ).toInt();
+    m_typeId = query.value( 5 ).toInt();
+    m_name = query.value( 6 ).toString();
+    m_createdDate.setTime_t( query.value( 7 ).toInt() );
+    m_createdUser = query.value( 8 ).toString();
+    m_modifiedDate.setTime_t( query.value( 9 ).toInt() );
+    m_modifiedUser = query.value( 10 ).toString();
+}
+
+bool IssueEntity::isOwner( int id )
+{
+    Query query( "SELECT created_user_id FROM issues WHERE issue_id = ?" );
+    query.exec( id );
+
+    if ( query.next() && query.value( 0 ).toInt() == dataManager->currentUserId() )
+        return true;
+
+    return false;
 }
 
 bool IssueEntity::isAdmin( int id )
@@ -1295,6 +1406,32 @@ QList<ValueEntity> IssueEntity::values() const
     return result;
 }
 
+QList<ValueEntity> IssueEntity::nonEmptyValues() const
+{
+    QList<ValueEntity> result;
+
+    if ( d->m_id != 0 && d->m_typeId != 0 ) {
+        Query query( "SELECT a.attr_id, v.attr_value"
+            " FROM attr_types AS a"
+            " JOIN attr_values AS v ON v.attr_id = a.attr_id AND v.issue_id = ?"
+            " WHERE a.type_id = ?" );
+        query.exec( d->m_id, d->m_typeId );
+
+        while ( query.next() ) {
+            ValueEntity entity;
+            entity.d->read( query );
+            entity.d->m_typeId = d->m_typeId;
+            result.append( entity );
+        }
+
+        IssueTypeCache* cache = dataManager->issueTypeCache( d->m_typeId );
+
+        qSort( result.begin(), result.end(), ValueEntityLessThan( cache->attributes() ) );
+    }
+
+    return result;
+}
+
 QList<ValueEntity> AttributeEntity::values() const
 {
     QList<ValueEntity> result;
@@ -1320,6 +1457,111 @@ void ValueEntityData::read( const Query& query )
     m_value = query.value( 1 ).toString();
 }
 
+DescriptionEntity::DescriptionEntity() :
+    d ( new DescriptionEntityData() )
+{
+}
+
+DescriptionEntity::~DescriptionEntity()
+{
+}
+
+DescriptionEntity::DescriptionEntity( const DescriptionEntity& other ) :
+    d( other.d )
+{
+}
+
+DescriptionEntity& DescriptionEntity::operator =( const DescriptionEntity& other )
+{
+    d = other.d;
+    return *this;
+}
+
+DescriptionEntityData::DescriptionEntityData() :
+    m_id( 0 ),
+    m_format( PlainText )
+{
+}
+
+DescriptionEntityData::~DescriptionEntityData()
+{
+}
+
+bool DescriptionEntity::isValid() const
+{
+    return d->m_id != 0;
+}
+
+int DescriptionEntity::id() const
+{
+    return d->m_id;
+}
+
+const QString& DescriptionEntity::text() const
+{
+    return d->m_text;
+}
+
+TextFormat DescriptionEntity::format() const
+{
+    return d->m_format;
+}
+
+const QDateTime& DescriptionEntity::modifiedDate() const
+{
+    return d->m_modifiedDate;
+}
+
+const QString& DescriptionEntity::modifiedUser() const
+{
+    return d->m_modifiedUser;
+}
+
+DescriptionEntity ProjectEntity::description() const
+{
+    DescriptionEntity result;
+
+    if ( d->m_id != 0 ) {
+        Query query( "SELECT pd.project_id, pd.descr_text, pd.descr_format, pd.modified_time, um.user_name AS modified_user"
+            " FROM project_descriptions AS pd"
+            " LEFT OUTER JOIN users AS um ON um.user_id = pd.modified_user_id"
+            " WHERE pd.project_id = ?" );
+        query.exec( d->m_id );
+
+        if ( query.next() )
+            result.d->read( query );
+    }
+
+    return result;
+}
+
+DescriptionEntity IssueEntity::description() const
+{
+    DescriptionEntity result;
+
+    if ( d->m_id != 0 ) {
+        Query query( "SELECT id.issue_id, id.descr_text, id.descr_format, id.modified_time, um.user_name AS modified_user"
+            " FROM issue_descriptions AS id"
+            " LEFT OUTER JOIN users AS um ON um.user_id = id.modified_user_id"
+            " WHERE id.issue_id = ?" );
+        query.exec( d->m_id );
+
+        if ( query.next() )
+            result.d->read( query );
+    }
+
+    return result;
+}
+
+void DescriptionEntityData::read( const Query& query )
+{
+    m_id = query.value( 0 ).toInt();
+    m_text = query.value( 1 ).toString();
+    m_format = (TextFormat)query.value( 2 ).toInt();
+    m_modifiedDate.setTime_t( query.value( 3 ).toInt() );
+    m_modifiedUser = query.value( 4 ).toString();
+}
+
 CommentEntity::CommentEntity() :
     d( new CommentEntityData() )
 {
@@ -1364,10 +1606,16 @@ const QString& CommentEntity::text() const
     return d->m_text;
 }
 
+TextFormat CommentEntity::format() const
+{
+    return d->m_format;
+}
+
 void CommentEntityData::read( const Query& query )
 {
     m_id = query.value( 0 ).toInt();
     m_text = query.value( 1 ).toString();
+    m_format = (TextFormat)query.value( 2 ).toInt();
 }
 
 FileEntity::FileEntity() :
@@ -1567,6 +1815,7 @@ CommentEntity ChangeEntity::comment() const
     if ( d->m_id != 0 && d->m_type == CommentAdded ) {
         entity.d->m_id = d->m_id;
         entity.d->m_text = d->m_commentText;
+        entity.d->m_format = d->m_commentFormat;
     }
 
     return entity;
@@ -1586,17 +1835,17 @@ FileEntity ChangeEntity::file() const
     return entity;
 }
 
-QList<ChangeEntity> IssueEntity::changes() const
+QList<ChangeEntity> IssueEntity::changes( Qt::SortOrder order ) const
 {
-    return d->changes( true );
+    return d->changes( true, order );
 }
 
-QList<ChangeEntity> IssueEntity::commentsAndFiles() const
+QList<ChangeEntity> IssueEntity::commentsAndFiles( Qt::SortOrder order ) const
 {
-    return d->changes( false );
+    return d->changes( false, order );
 }
 
-QList<ChangeEntity> IssueEntityData::changes( bool all ) const
+QList<ChangeEntity> IssueEntityData::changes( bool all, Qt::SortOrder order ) const
 {
     QList<ChangeEntity> result;
 
@@ -1605,7 +1854,7 @@ QList<ChangeEntity> IssueEntityData::changes( bool all ) const
             " ch.created_time, uc.user_name AS created_user, ch.created_user_id,"
             " ch.modified_time, um.user_name AS modified_user,"
             " a.attr_id, ch.old_value, ch.new_value, ff.folder_name AS from_folder, tf.folder_name AS to_folder,"
-            " c.comment_text, f.file_name, f.file_size, f.file_descr"
+            " c.comment_text, c.comment_format, f.file_name, f.file_size, f.file_descr"
             " FROM changes AS ch"
             " LEFT OUTER JOIN users AS uc ON uc.user_id = ch.created_user_id"
             " LEFT OUTER JOIN users AS um ON um.user_id = ch.modified_user_id"
@@ -1618,6 +1867,7 @@ QList<ChangeEntity> IssueEntityData::changes( bool all ) const
         if ( !all )
             sql += " AND ( c.comment_id IS NOT NULL OR f.file_id IS NOT NULL )";
         sql += " ORDER BY ch.change_id";
+        sql += ( order == Qt::DescendingOrder ) ? " DESC" : " ASC";
 
         Query query( sql );
         query.exec( CommentAdded, FileAdded, m_id );
@@ -1654,12 +1904,14 @@ void ChangeEntityData::read( const Query& query )
         m_fromFolder = query.value( 12 ).toString();
         m_toFolder = query.value( 13 ).toString();
     }
-    if ( m_type == CommentAdded )
+    if ( m_type == CommentAdded ) {
         m_commentText = query.value( 14 ).toString();
+        m_commentFormat = (TextFormat)query.value( 15 ).toInt();
+    }
     if ( m_type == FileAdded ) {
-        m_fileName = query.value( 15 ).toString();
-        m_fileSize = query.value( 16 ).toInt();
-        m_fileDescription = query.value( 17 ).toString();
+        m_fileName = query.value( 16 ).toString();
+        m_fileSize = query.value( 17 ).toInt();
+        m_fileDescription = query.value( 18 ).toString();
     }
 }
 
@@ -1671,7 +1923,7 @@ ChangeEntity ChangeEntity::findComment( int id )
         Query query( "SELECT ch.change_id, ch.issue_id, ch.stamp_id,"
             " ch.created_time, uc.user_name AS created_user, ch.created_user_id,"
             " ch.modified_time, um.user_name AS modified_user,"
-            " c.comment_text"
+            " c.comment_text, c.comment_format"
             " FROM changes AS ch"
             " LEFT OUTER JOIN users AS uc ON uc.user_id = ch.created_user_id"
             " LEFT OUTER JOIN users AS um ON um.user_id = ch.modified_user_id"
@@ -1686,21 +1938,24 @@ ChangeEntity ChangeEntity::findComment( int id )
     return entity;
 }
 
-QList<ChangeEntity> IssueEntity::comments() const
+QList<ChangeEntity> IssueEntity::comments( Qt::SortOrder order ) const
 {
     QList<ChangeEntity> result;
 
     if ( d->m_id != 0 ) {
-        Query query( "SELECT ch.change_id, ch.issue_id, ch.stamp_id,"
+        QString sql = "SELECT ch.change_id, ch.issue_id, ch.stamp_id,"
             " ch.created_time, uc.user_name AS created_user, ch.created_user_id,"
             " ch.modified_time, um.user_name AS modified_user,"
-            " c.comment_text"
+            " c.comment_text, c.comment_format"
             " FROM changes AS ch"
             " LEFT OUTER JOIN users AS uc ON uc.user_id = ch.created_user_id"
             " LEFT OUTER JOIN users AS um ON um.user_id = ch.modified_user_id"
             " JOIN comments AS c ON c.comment_id = ch.change_id AND ch.change_type = ?"
             " WHERE ch.issue_id = ?"
-            " ORDER BY ch.change_id" );
+            " ORDER BY ch.change_id";
+        sql += ( order == Qt::DescendingOrder ) ? " DESC" : " ASC";
+
+        Query query( sql );
         query.exec( CommentAdded, d->m_id );
 
         while ( query.next() ) {
@@ -1725,6 +1980,7 @@ void ChangeEntityData::readComment( const Query& query )
     m_modifiedDate.setTime_t( query.value( 6 ).toInt() );
     m_modifiedUser = query.value( 7 ).toString();
     m_commentText = query.value( 8 ).toString();
+    m_commentFormat = (TextFormat)query.value( 9 ).toInt();
 }
 
 ChangeEntity ChangeEntity::findFile( int id )
@@ -1750,12 +2006,12 @@ ChangeEntity ChangeEntity::findFile( int id )
     return entity;
 }
 
-QList<ChangeEntity> IssueEntity::files() const
+QList<ChangeEntity> IssueEntity::files( Qt::SortOrder order ) const
 {
     QList<ChangeEntity> result;
 
     if ( d->m_id != 0 ) {
-        Query query( "SELECT ch.change_id, ch.issue_id, ch.stamp_id,"
+        QString sql = "SELECT ch.change_id, ch.issue_id, ch.stamp_id,"
             " ch.created_time, ch.created_user_id, uc.user_name AS created_user,"
             " ch.modified_time, um.user_name AS modified_user,"
             " f.file_name, f.file_size, f.file_descr"
@@ -1764,7 +2020,10 @@ QList<ChangeEntity> IssueEntity::files() const
             " LEFT OUTER JOIN users AS um ON um.user_id = ch.modified_user_id"
             " JOIN files AS f ON f.file_id = ch.change_id AND ch.change_type = ?"
             " WHERE ch.issue_id = ?"
-            " ORDER BY ch.change_id" );
+            " ORDER BY ch.change_id";
+        sql += ( order == Qt::DescendingOrder ) ? " DESC" : " ASC";
+
+        Query query( sql );
         query.exec( FileAdded, d->m_id );
 
         while ( query.next() ) {
@@ -1853,66 +2112,6 @@ void PreferenceEntityData::read( const Query& query )
     m_value = query.value( 1 ).toString();
 }
 
-FormatEntity::FormatEntity() :
-    d( new FormatEntityData() )
-{
-}
-
-FormatEntity::~FormatEntity()
-{
-}
-
-FormatEntity::FormatEntity( const FormatEntity& other ) :
-    d( other.d )
-{
-}
-
-FormatEntity& FormatEntity::operator =( const FormatEntity& other )
-{
-    d = other.d;
-    return *this;
-}
-
-FormatEntityData::FormatEntityData()
-{
-}
-
-FormatEntityData::~FormatEntityData()
-{
-}
-
-const QString& FormatEntity::key() const
-{
-    return d->m_key;
-}
-
-const QString& FormatEntity::definition() const
-{
-    return d->m_definition;
-}
-
-QList<FormatEntity> FormatEntity::list( const QString& type )
-{
-    QList<FormatEntity> result;
-
-    Query query( "SELECT format_key, format_def FROM formats WHERE format_type = ? ORDER BY format_key" );
-    query.exec( type );
-
-    while ( query.next() ) {
-        FormatEntity entity;
-        entity.d->read( query );
-        result.append( entity );
-    }
-
-    return result;
-}
-
-void FormatEntityData::read( const Query& query )
-{
-    m_key = query.value( 0 ).toString();
-    m_definition = query.value( 1 ).toString();
-}
-
 LanguageEntity::LanguageEntity() :
     d( new LanguageEntityData() )
 {
@@ -1955,7 +2154,7 @@ QList<LanguageEntity> LanguageEntity::list()
 {
     QList<LanguageEntity> result;
 
-    Query query( "SELECT lang_code, lang_name FROM languages ORDER BY lang_name COLLATE LOCALE" );
+    Query query( "SELECT lang_code, lang_name FROM languages ORDER BY lang_code" );
     query.exec();
 
     while ( query.next() ) {
@@ -1967,6 +2166,19 @@ QList<LanguageEntity> LanguageEntity::list()
     return result;
 }
 
+LanguageEntity LanguageEntity::find( const QString& code )
+{
+    LanguageEntity result;
+
+    Query query( "SELECT lang_code, lang_name FROM languages WHERE lang_code = ?" );
+    query.exec( code );
+
+    if ( query.next() )
+        result.d->read( query );
+
+    return result;
+}
+
 void LanguageEntityData::read( const Query& query )
 {
     m_code = query.value( 0 ).toString();
