@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -35,11 +35,11 @@ class UserEntity;
 class MemberEntity;
 class IssueEntity;
 class ValueEntity;
+class DescriptionEntity;
 class CommentEntity;
 class FileEntity;
 class ChangeEntity;
 class PreferenceEntity;
-class FormatEntity;
 class LanguageEntity;
 class TimeZoneEntity;
 
@@ -53,11 +53,11 @@ class UserEntityData;
 class MemberEntityData;
 class IssueEntityData;
 class ValueEntityData;
+class DescriptionEntityData;
 class CommentEntityData;
 class FileEntityData;
 class ChangeEntityData;
 class PreferenceEntityData;
-class FormatEntityData;
 class LanguageEntityData;
 class TimeZoneEntityData;
 
@@ -77,6 +77,9 @@ public:
 
     int id() const;
     const QString& name() const;
+    bool isPublic() const;
+
+    DescriptionEntity description() const;
 
     QList<FolderEntity> folders() const;
 
@@ -93,6 +96,8 @@ public:
 
 private:
     QExplicitlySharedDataPointer<ProjectEntityData> d;
+
+    friend class UserEntity;
 };
 
 class FolderEntity
@@ -153,6 +158,7 @@ public:
     QList<AttributeEntity> attributes() const;
 
     QList<ViewEntity> views() const;
+    QList<AlertEntity> alerts() const;
 
     QList<FolderEntity> folders() const;
 
@@ -244,8 +250,12 @@ public:
     int id() const;
     int viewId() const;
     AlertEmail alertEmail() const;
+    const QString& summaryDays() const;
+    const QString& summaryHours() const;
+    bool isPublic() const;
 
     FolderEntity folder() const;
+    TypeEntity type() const;
     ViewEntity view() const;
 
 public:
@@ -255,6 +265,7 @@ private:
     QExplicitlySharedDataPointer<AlertEntityData> d;
 
     friend class FolderEntity;
+    friend class TypeEntity;
 };
 
 class UserEntity
@@ -274,6 +285,8 @@ public:
     const QString& name() const;
     Access access() const;
 
+    QList<ProjectEntity> projects() const;
+
 public:
     static UserEntity find( int id );
 
@@ -308,6 +321,8 @@ public:
 public:
     static MemberEntity find( int projectId, int userId );
 
+    static MemberEntity findEffective( int projectId, int userId );
+
     static QList<MemberEntity> list( int userId );
 
 private:
@@ -331,6 +346,7 @@ public:
 
     int stampId() const;
     int readId() const;
+    int subscriptionId() const;
 
     int folderId() const;
 
@@ -343,15 +359,19 @@ public:
     const QString& modifiedUser() const;
 
     QList<ValueEntity> values() const;
+    QList<ValueEntity> nonEmptyValues() const;
 
-    QList<ChangeEntity> changes() const;
-    QList<ChangeEntity> commentsAndFiles() const;
-    QList<ChangeEntity> comments() const;
-    QList<ChangeEntity> files() const;
+    DescriptionEntity description() const;
+
+    QList<ChangeEntity> changes( Qt::SortOrder order ) const;
+    QList<ChangeEntity> commentsAndFiles( Qt::SortOrder order ) const;
+    QList<ChangeEntity> comments( Qt::SortOrder order ) const;
+    QList<ChangeEntity> files( Qt::SortOrder order ) const;
 
 public:
     static IssueEntity find( int id );
 
+    static bool isOwner( int id );
     static bool isAdmin( int id );
 
     static int findItem( int itemId );
@@ -390,6 +410,32 @@ private:
     friend class AttributeEntity;
 };
 
+class DescriptionEntity
+{
+public:
+    DescriptionEntity();
+    ~DescriptionEntity();
+
+    DescriptionEntity( const DescriptionEntity& other );
+    DescriptionEntity& operator =( const DescriptionEntity& other );
+
+public:
+    bool isValid() const;
+
+    int id() const;
+    const QString& text() const;
+    TextFormat format() const;
+
+    const QDateTime& modifiedDate() const;
+    const QString& modifiedUser() const;
+
+private:
+    QExplicitlySharedDataPointer<DescriptionEntityData> d;
+
+    friend class ProjectEntity;
+    friend class IssueEntity;
+};
+
 class CommentEntity
 {
 public:
@@ -404,6 +450,7 @@ public:
 
     int id() const;
     const QString& text() const;
+    TextFormat format() const;
 
 private:
     QExplicitlySharedDataPointer<CommentEntityData> d;
@@ -503,26 +550,6 @@ private:
     QExplicitlySharedDataPointer<PreferenceEntityData> d;
 };
 
-class FormatEntity
-{
-public:
-    FormatEntity();
-    ~FormatEntity();
-
-    FormatEntity( const FormatEntity& other );
-    FormatEntity& operator =( const FormatEntity& other );
-
-public:
-    const QString& key() const;
-    const QString& definition() const;
-
-public:
-    static QList<FormatEntity> list( const QString& type );
-
-private:
-    QExplicitlySharedDataPointer<FormatEntityData> d;
-};
-
 class LanguageEntity
 {
 public:
@@ -539,6 +566,8 @@ public:
 public:
     static QList<LanguageEntity> list();
 
+    static LanguageEntity find( const QString& code );
+
 private:
     QExplicitlySharedDataPointer<LanguageEntityData> d;
 };
@@ -563,4 +592,22 @@ private:
     QExplicitlySharedDataPointer<TimeZoneEntityData> d;
 };
 
+Q_DECLARE_TYPEINFO( ProjectEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( TypeEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( FolderEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( AttributeEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( ViewEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( AlertEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( UserEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( MemberEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( IssueEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( ValueEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( DescriptionEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( CommentEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( FileEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( ChangeEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( PreferenceEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( LanguageEntity, Q_MOVABLE_TYPE );
+Q_DECLARE_TYPEINFO( TimeZoneEntity, Q_MOVABLE_TYPE );
+
 #endif
