@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@ public:
 public:
     int m_id;
     QString m_name;
+    bool m_isPublic;
 };
 
 class FolderEntityData : public QSharedData
@@ -113,8 +114,12 @@ public:
 public:
     int m_id;
     int m_folderId;
+    int m_typeId;
     int m_viewId;
     AlertEmail m_alertEmail;
+    QString m_summaryDays;
+    QString m_summaryHours;
+    bool m_isPublic;
 };
 
 class UserEntityData : public QSharedData
@@ -159,12 +164,13 @@ public:
 public:
     void read( const Query& query );
 
-    QList<ChangeEntity> changes( bool all ) const;
+    QList<ChangeEntity> changes( bool all, Qt::SortOrder order ) const;
 
 public:
     int m_id;
     int m_stampId;
     int m_readId;
+    int m_subscriptionId;
     int m_folderId;
     int m_typeId;
     QString m_name;
@@ -189,6 +195,23 @@ public:
     QString m_value;
 };
 
+class DescriptionEntityData : public QSharedData
+{
+public:
+    DescriptionEntityData();
+    ~DescriptionEntityData();
+
+public:
+    void read( const Query& query );
+
+public:
+    int m_id;
+    QString m_text;
+    TextFormat m_format;
+    QDateTime m_modifiedDate;
+    QString m_modifiedUser;
+};
+
 class CommentEntityData : public QSharedData
 {
 public:
@@ -201,6 +224,7 @@ public:
 public:
     int m_id;
     QString m_text;
+    TextFormat m_format;
 };
 
 class FileEntityData : public QSharedData
@@ -254,6 +278,7 @@ public:
     QString m_toFolder;
 
     QString m_commentText;
+    TextFormat m_commentFormat;
 
     QString m_fileName;
     int m_fileSize;
@@ -274,20 +299,6 @@ public:
     QString m_value;
 };
 
-class FormatEntityData : public QSharedData
-{
-public:
-    FormatEntityData();
-    ~FormatEntityData();
-
-public:
-    void read( const Query& query );
-
-public:
-    QString m_key;
-    QString m_definition;
-};
-
 class LanguageEntityData : public QSharedData
 {
 public:
