@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,8 @@
 #include <QObject>
 #include <QList>
 
+class QSqlDatabase;
+
 /**
 * Class for caching downloaded attachments.
 */
@@ -70,34 +72,13 @@ public:
     */
     void commitFile( int fileId, const QString& path, int size );
 
-    /**
-    * Remove files exceeding the limit from the cache.
-    */
-    void flush();
-
 private:
-    void flush( int allocated );
+    bool installSchema( const QSqlDatabase& database );
 
-    void load();
-    void save();
-
-private:
-    struct Item
-    {
-        QString m_uuid;
-        int m_fileId;
-        QString m_path;
-        int m_size;
-    };
-
-    friend QDataStream& operator <<( QDataStream& stream, const Item& item );
-    friend QDataStream& operator >>( QDataStream& stream, Item& item );
+    bool allocFileSpace( int allocated, const QSqlDatabase& database );
 
 private:
     QString m_uuid;
-    QString m_path;
-
-    QList<Item> m_items;
 };
 
 #endif
