@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -19,12 +19,14 @@
 
 #include "issuetypecache.h"
 
+#include "data/entities.h"
 #include "models/foldermodel.h"
 #include "utils/attributehelper.h"
 
 #include <QSqlQuery>
 
-IssueTypeCache::IssueTypeCache( int typeId, QObject* parent ) : QObject( parent )
+IssueTypeCache::IssueTypeCache( int typeId, QObject* parent ) : QObject( parent ),
+    m_initialViewId( 0 )
 {
     QString query = "SELECT attr_id, attr_name, attr_def"
         " FROM attr_types"
@@ -65,6 +67,8 @@ IssueTypeCache::IssueTypeCache( int typeId, QObject* parent ) : QObject( parent
             list = value.split( ',' );
         else if ( key == QLatin1String( "default_view" ) )
             m_defaultView = DefinitionInfo::fromString( value );
+        else if ( key == QLatin1String( "initial_view" ) )
+            m_initialViewId = value.toInt();
     }
 
     for ( int i = 0; i < list.count(); i++ ) {
@@ -77,17 +81,25 @@ IssueTypeCache::IssueTypeCache( int typeId, QObject* parent ) : QObject( parent
     }
 
     m_attributes += remaining;
+
+    if ( m_initialViewId != 0 ) {
+        ViewEntity view = ViewEntity::find( m_initialViewId );
+        if ( !view.isValid() || !view.isPublic() || view.typeId() != typeId )
+            m_initialViewId = 0;
+    }
 }
 
 IssueTypeCache::~IssueTypeCache()
 {
 }
 
-QList<int> IssueTypeCache::availableColumns() const
+QList<int> IssueTypeCache::availableColumns( bool withLocation ) const
 {
     QList<int> columns;
     columns.append( Column_ID );
     columns.append( Column_Name );
+    if ( withLocation )
+        columns.append( Column_Location );
     columns.append( Column_CreatedDate );
     columns.append( Column_CreatedBy );
     columns.append( Column_ModifiedDate );
@@ -109,11 +121,13 @@ DefinitionInfo IssueTypeCache::attributeDefinition( int attributeId ) const
     return m_attributeDefinitions.value( attributeId );
 }
 
-QList<int> IssueTypeCache::viewColumns( const DefinitionInfo& info ) const
+QList<int> IssueTypeCache::viewColumns( const DefinitionInfo& info, bool withLocation ) const
 {
     QList<int> result;
     result.append( Column_ID );
     result.append( Column_Name );
+    if ( withLocation )
+        result.append( Column_Location );
 
     QString columns = info.metadata( "columns" ).toString();
 
