@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ public:
     /**
     * Return the list of available columns for the issue type.
     */
-    QList<int> availableColumns() const;
+    QList<int> availableColumns( bool withLocation = false ) const;
 
     /**
     * Return the name of the given attribute.
@@ -73,7 +73,7 @@ public:
     /**
     * Return the list of columns for given view.
     */
-    QList<int> viewColumns( const DefinitionInfo& info ) const;
+    QList<int> viewColumns( const DefinitionInfo& info, bool withLocation = false ) const;
 
     /**
     * Return the sort order for given view.
@@ -100,6 +100,11 @@ public:
     */
     QMap<int, int> defaultWidths() const;
 
+    /**
+    * Return the identifier of the initial view.
+    */
+    int initialViewId() const { return m_initialViewId; }
+
 private:
     QList<int> m_attributes;
 
@@ -107,6 +112,8 @@ private:
     QHash<int, DefinitionInfo> m_attributeDefinitions;
 
     DefinitionInfo m_defaultView;
+
+    int m_initialViewId;
 };
 
 #endif
