@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ void LocalSettings::setValue( const QString& key, const QVariant& value )
     m_data.insert( key, value );
 }
 
-QVariant LocalSettings::value( const QString& key, const QVariant& defaultValue /*= QVariant()*/ ) const
+QVariant LocalSettings::value( const QString& key, const QVariant& defaultValue ) const
 {
     return m_data.value( key, defaultValue );
 }
