@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 
 #include "query.h"
 
-Query::Query( const QSqlDatabase& database /*= QSqlDatabase()*/ ) :
+Query::Query( const QSqlDatabase& database ) :
     m_prepared( false ),
     m_valid( false ),
     m_query( database )
@@ -27,7 +27,7 @@ Query::Query( const QSqlDatabase& database /*= QSqlDatabase()*/ ) :
     m_query.setForwardOnly( true );
 }
 
-Query::Query( const QString& query, const QSqlDatabase& database /*= QSqlDatabase()*/ ) :
+Query::Query( const QString& query, const QSqlDatabase& database ) :
     m_queryText( query ),
     m_prepared( false ),
     m_valid( false ),
