@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -21,10 +21,12 @@
 
 #include "commands/abstractbatch.h"
 #include "commands/commandmanager.h"
+#include "dialogs/messagebox.h"
 #include "utils/errorhelper.h"
 #include "utils/iconloader.h"
 #include "widgets/inputlineedit.h"
 #include "widgets/inputtextedit.h"
+#include "widgets/markuptextedit.h"
 #include "widgets/elidedlabel.h"
 #include "xmlui/gradientwidget.h"
 
@@ -39,11 +41,12 @@
 #include <QMessageBox>
 #include <QAccessible>
 
-CommandDialog::CommandDialog( QWidget* parent ) : QDialog( parent ),
+CommandDialog::CommandDialog( QWidget* parent, Qt::WindowFlags flags ) : QDialog( parent, flags ),
     m_promptPixmap( NULL ),
     m_contentLayout( NULL ),
     m_fixed( false ),
     m_statusSet( false ),
+    m_queryClose( false ),
     m_progressBar( NULL ),
     m_progressLabel( NULL ),
     m_batch( NULL )
@@ -204,6 +207,9 @@ void CommandDialog::showCloseButton()
 
 bool CommandDialog::validate()
 {
+    foreach ( MarkupTextEdit* edit, findChildren<MarkupTextEdit*>() )
+        edit->closePreview();
+
     bool result = true;
     QWidget* errorWidget = NULL;
 
@@ -252,7 +258,7 @@ bool CommandDialog::validate()
     return result;
 }
 
-void CommandDialog::executeBatch( AbstractBatch* batch, const QString& text /* = QString() */ )
+void CommandDialog::executeBatch( AbstractBatch* batch, const QString& text )
 {
     if ( m_contentLayout )
         setWidgetsEnabled( m_contentLayout, false );
@@ -268,6 +274,8 @@ void CommandDialog::executeBatch( AbstractBatch* batch, const QString& text /* =
 
     connect( batch, SIGNAL( completed( bool ) ), this, SLOT( batchCompleted( bool ) ) );
 
+    batch->setPreventClose( true );
+
     m_batch = batch;
 
     commandManager->execute( batch );
@@ -275,12 +283,50 @@ void CommandDialog::executeBatch( AbstractBatch* batch, const QString& text /* =
 
 void CommandDialog::reject()
 {
-    if ( m_batch ) {
+    if ( m_batch )
         commandManager->abort( m_batch );
-        return;
+    else if ( queryClose() )
+        QDialog::reject();
+}
+
+void CommandDialog::closeEvent( QCloseEvent* e )
+{
+    if ( !m_batch && queryClose() )
+        e->accept();
+    else
+        e->ignore();
+}
+
+void CommandDialog::setQueryCloseEnabled( bool on )
+{
+    m_queryClose = on;
+}
+
+bool CommandDialog::queryClose()
+{
+    if ( !m_queryClose )
+        return true;
+
+    bool modified = false;
+
+    foreach ( InputLineEdit* edit, findChildren<InputLineEdit*>() ) {
+        if ( edit->isEnabled() && edit->isModified() )
+            modified = true;
     }
 
-    QDialog::reject();
+    foreach ( InputTextEdit* edit, findChildren<InputTextEdit*>() ) {
+        if ( edit->isEnabled() && edit->document()->isModified() )
+            modified = true;
+    }
+
+    if ( modified ) {
+        if ( MessageBox::warning( this, tr( "Warning" ), tr( "The changes have not been submitted and will be lost.\nAre you sure you want to continue?" ),
+             QMessageBox::Ok | QMessageBox::Cancel ) != QMessageBox::Ok ) {
+            return false;
+        }
+    }
+
+    return true;
 }
 
 void CommandDialog::batchCompleted( bool successful )
