@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -19,12 +19,10 @@
 
 #include "issuedialogs.h"
 
-#include "application.h"
 #include "commands/issuebatch.h"
 #include "data/datamanager.h"
 #include "data/entities.h"
 #include "data/issuetypecache.h"
-#include "data/localsettings.h"
 #include "dialogs/messagebox.h"
 #include "utils/definitioninfo.h"
 #include "utils/viewsettingshelper.h"
@@ -32,6 +30,7 @@
 #include "utils/formatter.h"
 #include "utils/iconloader.h"
 #include "widgets/inputlineedit.h"
+#include "widgets/markuptextedit.h"
 #include "widgets/abstractvalueeditor.h"
 #include "widgets/valueeditorfactory.h"
 #include "widgets/separatorcombobox.h"
@@ -46,19 +45,23 @@
 #include <QFileInfo>
 #include <QRegExp>
 
-IssueDialog::IssueDialog( QWidget* parent ) : CommandDialog( parent ),
-    m_nameEdit( NULL )
+IssueDialog::IssueDialog() : CommandDialog( NULL, Qt::Window ),
+    m_nameEdit( NULL ),
+    m_folderCombo( NULL ),
+    m_descriptionEdit( NULL ),
+    m_typeId( 0 ),
+    m_isAdding( false )
 {
 }
 
 IssueDialog::~IssueDialog()
 {
-    if ( !isFixed() )
-        application->applicationSettings()->setValue( "IssueDialogSize", size() );
 }
 
-bool IssueDialog::initialize( int typeId, int projectId )
+bool IssueDialog::initialize( int typeId, int projectId, Flags flags )
 {
+    m_typeId = typeId;
+
     IssueTypeCache* cache = dataManager->issueTypeCache( typeId );
     QList<int> attributes = cache->attributes();
 
@@ -74,7 +77,7 @@ bool IssueDialog::initialize( int typeId, int projectId )
         }
     }
 
-    if ( membersRequired ) {
+    if ( membersRequired && projectId != 0 ) {
         ProjectEntity project = ProjectEntity::find( projectId );
         if ( project.members().isEmpty() ) {
             showWarning( tr( "There are no available project members to assign to the issue." ) );
@@ -84,24 +87,75 @@ bool IssueDialog::initialize( int typeId, int projectId )
         }
     }
 
+    if ( flags.testFlag( WithFolder ) ) {
+        bool folderExists = false;
+        foreach ( const FolderEntity& folder, FolderEntity::list() ) {
+            if ( folder.typeId() == typeId )
+                folderExists = true;
+        }
+        if ( !folderExists ) {
+            showWarning( tr( "There are no available folders of this type." ) );
+            showCloseButton();
+            setContentLayout( NULL, true );
+            return false;
+        }
+    }
+
     QGridLayout* layout = new QGridLayout();
+    int row = 0;
 
     QLabel* nameLabel = new QLabel( tr( "&Name:" ), this );
-    layout->addWidget( nameLabel, 0, 0 );
+    layout->addWidget( nameLabel, row, 0 );
 
     m_nameEdit = new InputLineEdit( this );
     m_nameEdit->setMaxLength( 80 );
     m_nameEdit->setRequired( true );
-    layout->addWidget( m_nameEdit, 0, 1 );
+    layout->addWidget( m_nameEdit, row++, 1 );
 
     nameLabel->setBuddy( m_nameEdit );
 
-    if ( !attributes.isEmpty() ) {
-        QGroupBox* attributeGroup = new QGroupBox( tr( "Attributes" ), this );
-        QVBoxLayout* attributeLayout = new QVBoxLayout( attributeGroup );
-        layout->addWidget( attributeGroup, 1, 0, 1, 2 );
+    if ( flags.testFlag( WithFolder ) ) {
+        QLabel* folderLabel = new QLabel( tr( "&Folder:" ), this );
+        layout->addWidget( folderLabel, row, 0 );
 
-        QScrollArea* attributeScroll = new QScrollArea( attributeGroup );
+        m_folderCombo = new SeparatorComboBox( this );
+        layout->addWidget( m_folderCombo, row++, 1 );
+
+        folderLabel->setBuddy( m_folderCombo );
+
+        m_folderCombo->addItem( tr( "Please Select" ), 0 );
+        m_folderCombo->addSeparator();
+
+        foreach ( const ProjectEntity& project, ProjectEntity::list() ) {
+            bool projectAdded = false;
+            foreach ( const FolderEntity& folder, project.folders() ) {
+                if ( folder.typeId() != typeId )
+                    continue;
+                if ( !projectAdded ) {
+                    m_folderCombo->addParentItem( project.name() );
+                    projectAdded = true;
+                }
+                m_folderCombo->addChildItem( folder.name(), folder.id() );
+            }
+        }
+
+        connect( m_folderCombo, SIGNAL( currentIndexChanged( int ) ), this, SLOT( currentFolderChanged() ) );
+    }
+
+    QTabWidget* tabWidget = NULL;
+
+    if ( !attributes.isEmpty() || flags.testFlag( WithDescription ) ) {
+        tabWidget = new QTabWidget( this );
+        layout->addWidget( tabWidget, row, 0, 1, 2 );
+    }
+
+    if ( !attributes.isEmpty() ) {
+        QWidget* attributeTab = new QWidget( tabWidget );
+        tabWidget->addTab( attributeTab, IconLoader::icon( "attribute" ), tr( "Attributes" ) );
+
+        QVBoxLayout* attributeLayout = new QVBoxLayout( attributeTab );
+
+        QScrollArea* attributeScroll = new QScrollArea( attributeTab );
         attributeScroll->setWidgetResizable( true );
         attributeLayout->addWidget( attributeScroll );
 
@@ -141,15 +195,24 @@ bool IssueDialog::initialize( int typeId, int projectId )
         }
 
         valuesLayout->setRowStretch( attributes.count() + 2, 1 );
-
-        setContentLayout( layout, false );
-    } else {
-        setContentLayout( layout, true );
     }
 
-    m_nameEdit->setFocus();
+    if ( flags.testFlag( WithDescription ) ) {
+        QWidget* descriptionTab = new QWidget( tabWidget );
+        tabWidget->addTab( descriptionTab, IconLoader::icon( "description-new" ), tr( "Description" ) );
 
-    resize( application->applicationSettings()->value( "IssueDialogSize", QSize( 500, 500 ) ).toSize() );
+        QVBoxLayout* descriptionLayout = new QVBoxLayout( descriptionTab );
+
+        m_descriptionEdit = new MarkupTextEdit( descriptionTab );
+        m_descriptionEdit->setRequired( false );
+        descriptionLayout->addWidget( m_descriptionEdit );
+    }
+
+    setContentLayout( layout, tabWidget == NULL );
+
+    setQueryCloseEnabled( true );
+
+    m_nameEdit->setFocus();
 
     return true;
 }
@@ -164,6 +227,21 @@ QString IssueDialog::issueName() const
     return m_nameEdit->inputValue();
 }
 
+void IssueDialog::setFolderId( int folderId )
+{
+    for ( int i = 0; i < m_folderCombo->count(); i++ ) {
+        if ( m_folderCombo->itemData( i ).toInt() == folderId ) {
+            m_folderCombo->setCurrentIndex( i );
+            break;
+        }
+    }
+}
+
+int IssueDialog::folderId() const
+{
+    return m_folderCombo->itemData( m_folderCombo->currentIndex() ).toInt();
+}
+
 void IssueDialog::setAttributeValue( int attributeId, const QString& value )
 {
     AbstractValueEditor* editor = m_editors.value( attributeId );
@@ -184,29 +262,39 @@ QList<int> IssueDialog::attributeIds() const
     return m_editors.keys();
 }
 
-AddIssueDialog::AddIssueDialog( int folderId, int cloneIssueId, QWidget* parent ) : IssueDialog( parent ),
-    m_folderId( folderId )
+void IssueDialog::setDescriptionText( const QString& text )
 {
-    FolderEntity folder = FolderEntity::find( folderId );
-    IssueEntity issue = IssueEntity::find( cloneIssueId );
+    m_descriptionEdit->setInputValue( text );
+}
 
-    if ( cloneIssueId != 0 ) {
-        setWindowTitle( tr( "Clone Issue" ) );
-        setPrompt( tr( "Clone issue <b>%1</b> as a new issue in folder <b>%2</b>:" ).arg( issue.name(), folder.name() ) );
-        setPromptPixmap( IconLoader::pixmap( "issue-clone", 22 ) );
-    } else {
-        setWindowTitle( tr( "Add Issue" ) );
-        setPrompt( tr( "Create a new issue in folder <b>%1</b>:" ).arg( folder.name() ) );
-        setPromptPixmap( IconLoader::pixmap( "issue-new", 22 ) );
-    }
+QString IssueDialog::descriptionText() const
+{
+    return m_descriptionEdit->inputValue();
+}
 
-    if ( !initialize( folder.typeId(), folder.projectId() ) )
-        return;
+void IssueDialog::setDescriptionFormat( TextFormat format )
+{
+    m_descriptionEdit->setTextFormat( format );
+}
 
-    if ( cloneIssueId != 0 )
-        setIssueName( issue.name() );
+TextFormat IssueDialog::descriptionFormat() const
+{
+    return m_descriptionEdit->textFormat();
+}
 
-    IssueTypeCache* cache = dataManager->issueTypeCache( folder.typeId() );
+void IssueDialog::currentFolderChanged()
+{
+    FolderEntity folder = FolderEntity::find( folderId() );
+
+    foreach ( AbstractValueEditor* editor, m_editors )
+        editor->setProjectId( folder.projectId() );
+}
+
+QMap<int, QString> IssueDialog::defaultAttributeValues()
+{
+    QMap<int, QString> values;
+
+    IssueTypeCache* cache = dataManager->issueTypeCache( m_typeId );
     QList<int> attributes = attributeIds();
 
     AttributeHelper helper;
@@ -219,15 +307,58 @@ AddIssueDialog::AddIssueDialog( int folderId, int cloneIssueId, QWidget* parent
 
         value = helper.convertInitialValue( info, value );
 
-        m_values.insert( attributeId, value );
-
-        if ( cloneIssueId != 0 ) {
-            ValueEntity entity = ValueEntity::find( cloneIssueId, attributeId );
-            setAttributeValue( attributeId, entity.value() );
-        } else {
-            setAttributeValue( attributeId, value );
-        }
+        values.insert( attributeId, value );
     }
+
+    return values;
+}
+
+void IssueDialog::executeAddIssueBatch( int folderId, const QMap<int, QString>& defaultValues )
+{
+    QString name = issueName();
+    IssueBatch* batch = new IssueBatch( folderId, name );
+
+    for ( QMap<int, QString>::const_iterator it = defaultValues.begin(); it != defaultValues.end(); ++it ) {
+        QString value = attributeValue( it.key() );
+        if ( value != it.value() )
+            batch->setValue( it.key(), value );
+    }
+
+    QString description = descriptionText();
+    if ( !description.isEmpty() )
+        batch->addDescription( description, descriptionFormat() );
+
+    m_isAdding = true;
+
+    executeBatch( batch );
+}
+
+bool IssueDialog::batchSuccessful( AbstractBatch* batch )
+{
+    if ( m_isAdding ) {
+        IssueBatch* issueBatch = (IssueBatch*)batch;
+        emit issueAdded( issueBatch->issueId(), issueBatch->folderId() );
+    }
+
+    return true;
+}
+
+AddIssueDialog::AddIssueDialog( int folderId ) : IssueDialog(),
+    m_folderId( folderId )
+{
+    FolderEntity folder = FolderEntity::find( folderId );
+
+    setWindowTitle( tr( "Add Issue" ) );
+    setPrompt( tr( "Create a new issue in folder <b>%1</b>:" ).arg( folder.name() ) );
+    setPromptPixmap( IconLoader::pixmap( "issue-new", 22 ) );
+
+    if ( !initialize( folder.typeId(), folder.projectId(), WithDescription ) )
+        return;
+
+    m_values = defaultAttributeValues();
+
+    for ( QMap<int, QString>::const_iterator it = m_values.begin(); it != m_values.end(); ++it )
+        setAttributeValue( it.key(), it.value() );
 }
 
 AddIssueDialog::~AddIssueDialog()
@@ -239,26 +370,90 @@ void AddIssueDialog::accept()
     if ( !validate() )
         return;
 
-    QString name = issueName();
-    IssueBatch* batch = new IssueBatch( m_folderId, name );
+    executeAddIssueBatch( m_folderId, m_values );
+}
 
-    for ( QMap<int, QString>::const_iterator it = m_values.begin(); it != m_values.end(); ++it ) {
-        QString value = attributeValue( it.key() );
-        if ( value != it.value() )
-            batch->setValue( it.key(), value );
+AddGlobalIssueDialog::AddGlobalIssueDialog( int typeId ) : IssueDialog()
+{
+    TypeEntity type = TypeEntity::find( typeId );
+
+    setWindowTitle( tr( "Add Issue" ) );
+    setPrompt( tr( "Create a new issue in the selected folder:" ) );
+    setPromptPixmap( IconLoader::pixmap( "issue-new", 22 ) );
+
+    if ( !initialize( typeId, 0, WithFolder | WithDescription ) )
+        return;
+
+    m_values = defaultAttributeValues();
+
+    for ( QMap<int, QString>::const_iterator it = m_values.begin(); it != m_values.end(); ++it )
+        setAttributeValue( it.key(), it.value() );
+}
+
+AddGlobalIssueDialog::~AddGlobalIssueDialog()
+{
+}
+
+void AddGlobalIssueDialog::accept()
+{
+    if ( !validate() )
+        return;
+
+    if ( folderId() == 0 ) {
+        showWarning( tr( "No folder selected." ) );
+        return;
     }
 
-    executeBatch( batch );
+    executeAddIssueBatch( folderId(), m_values );
 }
 
-bool AddIssueDialog::batchSuccessful( AbstractBatch* batch )
+CloneIssueDialog::CloneIssueDialog( int issueId ) : IssueDialog()
 {
-    m_issueId = ( (IssueBatch*)batch )->issueId();
+    IssueEntity issue = IssueEntity::find( issueId );
+    FolderEntity folder = issue.folder();
 
-    return true;
+    setWindowTitle( tr( "Clone Issue" ) );
+    setPrompt( tr( "Clone issue <b>%1</b> as a new issue in the selected folder:" ).arg( issue.name() ) );
+    setPromptPixmap( IconLoader::pixmap( "issue-clone", 22 ) );
+
+    if ( !initialize( folder.typeId(), folder.projectId(), WithFolder | WithDescription ) )
+        return;
+
+    setIssueName( issue.name() );
+    setFolderId( issue.folderId() );
+
+    DescriptionEntity description = issue.description();
+    if ( description.isValid() ) {
+        setDescriptionText( description.text() );
+        setDescriptionFormat( description.format() );
+    }
+
+    m_values = defaultAttributeValues();
+
+    for ( QMap<int, QString>::const_iterator it = m_values.begin(); it != m_values.end(); ++it ) {
+        ValueEntity entity = ValueEntity::find( issueId, it.key() );
+        setAttributeValue( it.key(), entity.value() );
+    }
 }
 
-EditIssueDialog::EditIssueDialog( int issueId, QWidget* parent ) : IssueDialog( parent ),
+CloneIssueDialog::~CloneIssueDialog()
+{
+}
+
+void CloneIssueDialog::accept()
+{
+    if ( !validate() )
+        return;
+
+    if ( folderId() == 0 ) {
+        showWarning( tr( "No folder selected." ) );
+        return;
+    }
+
+    executeAddIssueBatch( folderId(), m_values );
+}
+
+EditIssueDialog::EditIssueDialog( int issueId ) : IssueDialog(),
     m_issueId( issueId ),
     m_updateFolder( false )
 {
@@ -439,22 +634,6 @@ void MoveIssueDialog::accept()
     executeBatch( batch );
 }
 
-CloneIssueDialog::CloneIssueDialog( int issueId, QWidget* parent ) : TransferIssueDialog( parent )
-{
-    IssueEntity issue = IssueEntity::find( issueId );
-    FolderEntity oldFolder = issue.folder();
-
-    setWindowTitle( tr( "Clone Issue" ) );
-    setPrompt( tr( "Clone issue <b>%1</b> to a folder of the same type:" ).arg( issue.name() ) );
-    setPromptPixmap( IconLoader::pixmap( "issue-clone", 22 ) );
-
-    initialize( oldFolder.typeId(), oldFolder.id(), false );
-}
-
-CloneIssueDialog::~CloneIssueDialog()
-{
-}
-
 DeleteIssueDialog::DeleteIssueDialog( int issueId, QWidget* parent ) : CommandDialog( parent ),
     m_issueId( issueId )
 {
@@ -481,6 +660,104 @@ void DeleteIssueDialog::accept()
     executeBatch( batch );
 }
 
+AddCommentDialog::AddCommentDialog( int issueId ) : CommandDialog( NULL, Qt::Window ),
+    m_issueId( issueId )
+{
+    IssueEntity issue = IssueEntity::find( issueId );
+
+    setWindowTitle( tr( "Add Comment" ) );
+    setPrompt( tr( "Add comment to issue <b>%1</b>:" ).arg( issue.name() ) );
+    setPromptPixmap( IconLoader::pixmap( "comment", 22 ) );
+
+    QVBoxLayout* layout = new QVBoxLayout();
+
+    m_commentEdit = new MarkupTextEdit( this );
+    layout->addWidget( m_commentEdit );
+
+    setContentLayout( layout, false );
+
+    setQueryCloseEnabled( true );
+
+    m_commentEdit->setFocus();
+}
+
+AddCommentDialog::~AddCommentDialog()
+{
+}
+
+void AddCommentDialog::setQuote( const QString& title, const QString& text )
+{
+    QString quote = QString( "[quote %1]\n%2\n[/quote]\n\n" ).arg( title, text );
+
+    m_commentEdit->setInputValue( quote );
+    m_commentEdit->setTextFormat( TextWithMarkup );
+
+    m_commentEdit->goToEnd();
+}
+
+void AddCommentDialog::accept()
+{
+    if ( !validate() )
+        return;
+
+    IssueBatch* batch = new IssueBatch( m_issueId );
+    batch->addComment( m_commentEdit->inputValue(), m_commentEdit->textFormat() );
+
+    executeBatch( batch );
+}
+
+EditCommentDialog::EditCommentDialog( int commentId ) : CommandDialog( NULL, Qt::Window ),
+    m_commentId( commentId )
+{
+    ChangeEntity change = ChangeEntity::findComment( commentId );
+    m_issueId = change.issueId();
+    CommentEntity comment = change.comment();
+    m_oldText = comment.text();
+    m_oldFormat = comment.format();
+    QString identifier = QString( "#%1" ).arg( commentId );
+
+    setWindowTitle( tr( "Edit Comment" ) );
+    setPrompt( tr( "Edit comment <b>%1</b>:" ).arg( identifier ) );
+    setPromptPixmap( IconLoader::pixmap( "edit-modify", 22 ) );
+
+    QVBoxLayout* layout = new QVBoxLayout();
+
+    m_commentEdit = new MarkupTextEdit( this );
+    layout->addWidget( m_commentEdit );
+
+    setContentLayout( layout, false );
+
+    setQueryCloseEnabled( true );
+
+    m_commentEdit->setInputValue( m_oldText );
+    m_commentEdit->setTextFormat( m_oldFormat );
+
+    m_commentEdit->setFocus();
+}
+
+EditCommentDialog::~EditCommentDialog()
+{
+}
+
+void EditCommentDialog::accept()
+{
+    if ( !validate() )
+        return;
+
+    QString text = m_commentEdit->inputValue();
+    TextFormat format = m_commentEdit->textFormat();
+
+    if ( text == m_oldText && format == m_oldFormat ) {
+        QDialog::accept();
+        return;
+    }
+
+    IssueBatch* batch = new IssueBatch( m_issueId );
+    batch->editComment( m_commentId, text, format );
+
+    executeBatch( batch );
+}
+
 DeleteCommentDialog::DeleteCommentDialog( int commentId, QWidget* parent ) : CommandDialog( parent ),
     m_commentId( commentId )
 {
@@ -794,3 +1071,113 @@ void DeleteAttachmentDialog::accept()
 
     executeBatch( batch );
 }
+
+AddDescriptionDialog::AddDescriptionDialog( int issueId ) : CommandDialog( NULL, Qt::Window ),
+    m_issueId( issueId )
+{
+    IssueEntity issue = IssueEntity::find( issueId );
+
+    setWindowTitle( tr( "Add Description" ) );
+    setPrompt( tr( "Add description to issue <b>%1</b>:" ).arg( issue.name() ) );
+    setPromptPixmap( IconLoader::pixmap( "description-new", 22 ) );
+
+    QVBoxLayout* layout = new QVBoxLayout();
+
+    m_descriptionEdit = new MarkupTextEdit( this );
+    layout->addWidget( m_descriptionEdit );
+
+    setContentLayout( layout, false );
+
+    setQueryCloseEnabled( true );
+
+    m_descriptionEdit->setFocus();
+}
+
+AddDescriptionDialog::~AddDescriptionDialog()
+{
+}
+
+void AddDescriptionDialog::accept()
+{
+    if ( !validate() )
+        return;
+
+    IssueBatch* batch = new IssueBatch( m_issueId );
+    batch->addDescription( m_descriptionEdit->inputValue(), m_descriptionEdit->textFormat() );
+
+    executeBatch( batch );
+}
+
+EditDescriptionDialog::EditDescriptionDialog( int issueId ) : CommandDialog( NULL, Qt::Window ),
+    m_issueId( issueId )
+{
+    IssueEntity issue = IssueEntity::find( issueId );
+    DescriptionEntity description = issue.description();
+    m_oldText = description.text();
+    m_oldFormat = description.format();
+
+    setWindowTitle( tr( "Edit Description" ) );
+    setPrompt( tr( "Edit description of issue <b>%1</b>:" ).arg( issue.name() ) );
+    setPromptPixmap( IconLoader::pixmap( "edit-modify", 22 ) );
+
+    QVBoxLayout* layout = new QVBoxLayout();
+
+    m_descriptionEdit = new MarkupTextEdit( this );
+    layout->addWidget( m_descriptionEdit );
+
+    setContentLayout( layout, false );
+
+    setQueryCloseEnabled( true );
+
+    m_descriptionEdit->setInputValue( m_oldText );
+    m_descriptionEdit->setTextFormat( m_oldFormat );
+
+    m_descriptionEdit->setFocus();
+}
+
+EditDescriptionDialog::~EditDescriptionDialog()
+{
+}
+
+void EditDescriptionDialog::accept()
+{
+    if ( !validate() )
+        return;
+
+    QString text = m_descriptionEdit->inputValue();
+    TextFormat format = m_descriptionEdit->textFormat();
+
+    if ( text == m_oldText && format == m_oldFormat ) {
+        QDialog::accept();
+        return;
+    }
+
+    IssueBatch* batch = new IssueBatch( m_issueId );
+    batch->editDescription( text, format );
+
+    executeBatch( batch );
+}
+
+DeleteDescriptionDialog::DeleteDescriptionDialog( int issueId, QWidget* parent ) : CommandDialog( parent ),
+    m_issueId( issueId )
+{
+    IssueEntity issue = IssueEntity::find( issueId );
+
+    setWindowTitle( tr( "Delete Description" ) );
+    setPrompt( tr( "Are you sure you want to delete description of issue <b>%1</b>?" ).arg( issue.name() ) );
+    setPromptPixmap( IconLoader::pixmap( "edit-delete", 22 ) );
+
+    setContentLayout( NULL, true );
+}
+
+DeleteDescriptionDialog::~DeleteDescriptionDialog()
+{
+}
+
+void DeleteDescriptionDialog::accept()
+{
+    IssueBatch* batch = new IssueBatch( m_issueId );
+    batch->deleteDescription();
+
+    executeBatch( batch );
+}
