@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #ifndef ISSUEDIALOGS_H
 #define ISSUEDIALOGS_H
 
+#include "data/datamanager.h"
 #include "dialogs/commanddialog.h"
 
 #include <QMap>
@@ -27,6 +28,7 @@
 class InputLineEdit;
 class AbstractValueEditor;
 class SeparatorComboBox;
+class MarkupTextEdit;
 
 class QButtonGroup;
 class QLineEdit;
@@ -37,34 +39,72 @@ class QLineEdit;
 class IssueDialog : public CommandDialog
 {
     Q_OBJECT
-public:
+protected:
     /**
     * Constructor.
-    * @param parent The parent widget.
     */
-    IssueDialog( QWidget* parent );
+    IssueDialog();
 
     /**
     * Destructor.
     */
     ~IssueDialog();
 
+public:
+    enum Flag
+    {
+        WithFolder = 1,
+        WithDescription = 2
+    };
+
+    Q_DECLARE_FLAGS( Flags, Flag )
+
+protected: // overrides
+    bool batchSuccessful( AbstractBatch* batch );
+
+signals:
+    void issueAdded( int issueId, int folderId );
+
 protected:
-    bool initialize( int typeId, int projectId );
+    bool initialize( int typeId, int projectId, Flags flags = 0 );
 
     void setIssueName( const QString& name );
     QString issueName() const;
 
+    void setFolderId( int folderId );
+    int folderId() const;
+
     void setAttributeValue( int attributeId, const QString& value );
     QString attributeValue( int attributeId ) const;
 
     QList<int> attributeIds() const;
 
+    void setDescriptionText( const QString& text );
+    QString descriptionText() const;
+
+    void setDescriptionFormat( TextFormat format );
+    TextFormat descriptionFormat() const;
+
+    QMap<int, QString> defaultAttributeValues();
+
+    void executeAddIssueBatch( int folderId, const QMap<int, QString>& defaultValues );
+
+private slots:
+    void currentFolderChanged();
+
 private:
     InputLineEdit* m_nameEdit;
+    SeparatorComboBox* m_folderCombo;
     QMap<int, AbstractValueEditor*> m_editors;
+    MarkupTextEdit* m_descriptionEdit;
+
+    int m_typeId;
+
+    bool m_isAdding;
 };
 
+Q_DECLARE_OPERATORS_FOR_FLAGS( IssueDialog::Flags )
+
 /**
 * Dialog for adding a new issue.
 */
@@ -75,32 +115,70 @@ public:
     /**
     * Constructor.
     * @param folderId The identifier of the folder containing the issue.
-    * @param cloneIssueId Optional identifier of the issue to clone.
-    * @param parent The parent widget.
     */
-    AddIssueDialog( int folderId, int cloneIssueId, QWidget* parent );
+    AddIssueDialog( int folderId );
 
     /**
     * Destructor.
     */
     ~AddIssueDialog();
 
+public: // overrides
+    void accept();
+
+private:
+    int m_folderId;
+
+    QMap<int, QString> m_values;
+};
+
+/**
+* Dialog for adding a new issue to a selected folder.
+*/
+class AddGlobalIssueDialog : public IssueDialog
+{
+    Q_OBJECT
 public:
     /**
-    * Return the identifier of the created issue.
+    * Constructor.
+    * @param folderId The identifier of the type of the issue.
     */
-    int issueId() const { return m_issueId; }
+    AddGlobalIssueDialog( int typeId );
+
+    /**
+    * Destructor.
+    */
+    ~AddGlobalIssueDialog();
 
 public: // overrides
     void accept();
 
-protected: // overrides
-    bool batchSuccessful( AbstractBatch* batch );
+private:
+    QMap<int, QString> m_values;
+};
+
+/**
+* Dialog for cloning an issue in a selected folder.
+*/
+class CloneIssueDialog : public IssueDialog
+{
+    Q_OBJECT
+public:
+    /**
+    * Constructor.
+    * @param folderId The identifier of the issue to clone.
+    */
+    CloneIssueDialog( int issueId );
+
+    /**
+    * Destructor.
+    */
+    ~CloneIssueDialog();
+
+public: // overrides
+    void accept();
 
 private:
-    int m_folderId;
-    int m_issueId;
-
     QMap<int, QString> m_values;
 };
 
@@ -114,9 +192,8 @@ public:
     /**
     * Constructor.
     * @param issueId Identifier of the issue to edit.
-    * @param parent The parent widget.
     */
-    EditIssueDialog( int issueId, QWidget* parent );
+    EditIssueDialog( int issueId );
 
     /**
     * Destructor.
@@ -169,26 +246,6 @@ private:
     SeparatorComboBox* m_folderCombo;
 };
 
-/**
-* Dialog for selecting destination folder for cloned issue.
-*/
-class CloneIssueDialog : public TransferIssueDialog
-{
-    Q_OBJECT
-public:
-    /**
-    * Constructor.
-    * @param issueId Identifier of the isssue to clone.
-    * @param parent The parent widget.
-    */
-    CloneIssueDialog( int issueId, QWidget* parent );
-
-    /**
-    * Destructor.
-    */
-    ~CloneIssueDialog();
-};
-
 /**
 * Dialog for executing the <tt>MOVE ISSUE</tt> command.
 */
@@ -251,6 +308,67 @@ private:
     int m_issueId;
 };
 
+/**
+* Dialog for executing the <tt>ADD COMMENT</tt> command.
+*/
+class AddCommentDialog : public CommandDialog
+{
+    Q_OBJECT
+public:
+    /**
+    * Constructor.
+    * @param issueId Identifier of the issue.
+    */
+    AddCommentDialog( int issueId );
+
+    /**
+    * Destructor.
+    */
+    ~AddCommentDialog();
+
+public:
+    void setQuote( const QString& title, const QString& text );
+
+public: // overrides
+    void accept();
+
+private:
+    int m_issueId;
+
+    MarkupTextEdit* m_commentEdit;
+};
+
+/**
+* Dialog for executing the <tt>EDIT COMMENT</tt> command.
+*/
+class EditCommentDialog : public CommandDialog
+{
+    Q_OBJECT
+public:
+    /**
+    * Constructor.
+    * @param commentId Identifier of the comment.
+    */
+    EditCommentDialog( int commentId );
+
+    /**
+    * Destructor.
+    */
+    ~EditCommentDialog();
+
+public: // overrides
+    void accept();
+
+private:
+    int m_commentId;
+    int m_issueId;
+
+    QString m_oldText;
+    TextFormat m_oldFormat;
+
+    MarkupTextEdit* m_commentEdit;
+};
+
 /**
 * Dialog for executing the <tt>DELETE COMMENT</tt> command.
 */
@@ -418,4 +536,87 @@ private:
     int m_fileId;
 };
 
+/**
+* Dialog for executing the <tt>ADD DESCRIPTION</tt> command.
+*/
+class AddDescriptionDialog : public CommandDialog
+{
+    Q_OBJECT
+public:
+    /**
+    * Constructor.
+    * @param issueId Identifier of the issue.
+    */
+    AddDescriptionDialog( int issueId );
+
+    /**
+    * Destructor.
+    */
+    ~AddDescriptionDialog();
+
+public: // overrides
+    void accept();
+
+private:
+    int m_issueId;
+
+    MarkupTextEdit* m_descriptionEdit;
+};
+
+/**
+* Dialog for executing the <tt>EDIT DESCRIPTION</tt> command.
+*/
+class EditDescriptionDialog : public CommandDialog
+{
+    Q_OBJECT
+public:
+    /**
+    * Constructor.
+    * @param issueId Identifier of the issue.
+    */
+    EditDescriptionDialog( int issueId );
+
+    /**
+    * Destructor.
+    */
+    ~EditDescriptionDialog();
+
+public: // overrides
+    void accept();
+
+private:
+    int m_issueId;
+
+    QString m_oldText;
+    TextFormat m_oldFormat;
+
+    MarkupTextEdit* m_descriptionEdit;
+};
+
+/**
+* Dialog for executing the <tt>DELETE DESCRIPTION</tt> command.
+*/
+class DeleteDescriptionDialog : public CommandDialog
+{
+    Q_OBJECT
+public:
+    /**
+    * Constructor.
+    * @param issueId Identifier of the issue.
+    * @param parent The parent widget.
+    */
+    DeleteDescriptionDialog( int issueId, QWidget* parent );
+
+    /**
+    * Destructor.
+    */
+    ~DeleteDescriptionDialog();
+
+public: // overrides
+    void accept();
+
+private:
+    int m_issueId;
+};
+
 #endif
