@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -19,10 +19,8 @@
 
 #include "managealertsdialog.h"
 
-#include "application.h"
 #include "data/datamanager.h"
 #include "data/entities.h"
-#include "data/localsettings.h"
 #include "dialogs/alertdialogs.h"
 #include "models/alertsmodel.h"
 #include "utils/treeviewhelper.h"
@@ -36,13 +34,18 @@
 #include <QDialogButtonBox>
 #include <QMenu>
 
-ManageAlertsDialog::ManageAlertsDialog( int folderId, QWidget* parent ) : InformationDialog( parent ),
-    m_folderId( folderId )
+ManageAlertsDialog::ManageAlertsDialog( int folderId ) : InformationDialog( NULL, Qt::Window ),
+    m_model( NULL ),
+    m_selectedAlertId( 0 ),
+    m_selectedEditable( false )
 {
-    FolderEntity folder = FolderEntity::find( m_folderId );
-
     m_emailEnabled = dataManager->setting( "email_enabled" ).toInt();
 
+    if ( folderId != 0 )
+        m_canEditPublic = FolderEntity::isAdmin( folderId );
+    else
+        m_canEditPublic = dataManager->currentUserAccess() == AdminAccess;
+
     QAction* action;
 
     action = new QAction( IconLoader::icon( "alert-new" ), tr( "&Add Alert..." ), this );
@@ -50,12 +53,18 @@ ManageAlertsDialog::ManageAlertsDialog( int folderId, QWidget* parent ) : Inform
     connect( action, SIGNAL( triggered() ), this, SLOT( addAlert() ) );
     setAction( "addAlert", action );
 
+    if ( m_canEditPublic ) {
+        action = new QAction( IconLoader::overlayedIcon( "alert-new", "overlay-public" ), tr( "Add &Public Alert..." ), this );
+        connect( action, SIGNAL( triggered() ), this, SLOT( addPublicAlert() ) );
+        setAction( "addPublicAlert", action );
+    }
+
     action = new QAction( IconLoader::icon( "edit-delete" ), tr( "&Delete Alert" ), this );
     action->setShortcut( QKeySequence::Delete );
     connect( action, SIGNAL( triggered() ), this, SLOT( editDelete() ) );
     setAction( "editDelete", action );
 
-    if ( m_emailEnabled != 0 ) {
+    if ( m_emailEnabled ) {
         action = new QAction( IconLoader::icon( "edit-modify" ), tr( "&Modify Alert..." ), this );
         connect( action, SIGNAL( triggered() ), this, SLOT( editModify() ) );
         setAction( "editModify", action );
@@ -70,7 +79,6 @@ ManageAlertsDialog::ManageAlertsDialog( int folderId, QWidget* parent ) : Inform
 
     setWindowTitle( tr( "Manage Alerts" ) );
     setPromptPixmap( IconLoader::pixmap( "configure-alerts", 22 ) );
-    setPrompt( tr( "Edit alert settings for folder <b>%1</b>:" ).arg( folder.name() ) );
 
     QVBoxLayout* layout = new QVBoxLayout();
     layout->setSpacing( 4 );
@@ -85,50 +93,54 @@ ManageAlertsDialog::ManageAlertsDialog( int folderId, QWidget* parent ) : Inform
     TreeViewHelper helper( m_list );
     helper.initializeView( TreeViewHelper::NotSortable );
 
-    m_model = new AlertsModel( folderId, this );
-    m_list->setModel( m_model );
-
-    QList<int> widths;
-    widths << 150 << 80 << 80 << 80;
-    if ( m_emailEnabled != 0 )
-        widths.append( 150 );
-
-    helper.loadColumnWidths( "ManageAlertsDialogWidths", widths );
-
-    connect( m_list->selectionModel(), SIGNAL( selectionChanged( const QItemSelection&, const QItemSelection& ) ),
-        this, SLOT( updateActions() ) );
     connect( m_list, SIGNAL( doubleClicked( const QModelIndex& ) ),
         this, SLOT( doubleClicked( const QModelIndex& ) ) );
     connect( m_list, SIGNAL( customContextMenuRequested( const QPoint& ) ),
         this, SLOT( listContextMenu( const QPoint& ) ) );
 
-    connect( m_model, SIGNAL( layoutChanged() ), this, SLOT( updateActions() ) );
-    connect( m_model, SIGNAL( modelReset() ), this, SLOT( updateActions() ) );
-
     setContentLayout( layout, false );
 
-    resize( application->applicationSettings()->value( "ManageAlertsDialogSize", QSize( 600, 400 ) ).toSize() );
+    setDialogSizeKey( "ManageAlertsDialog" );
+
+    resize( 680, 400 );
 
     updateActions();
 }
 
 ManageAlertsDialog::~ManageAlertsDialog()
 {
-    application->applicationSettings()->setValue( "ManageAlertsDialogSize", size() );
-
-    TreeViewHelper helper( m_list );
-    helper.saveColumnWidths( "ManageAlertsDialogWidths" );
+    if ( m_model != NULL ) {
+        TreeViewHelper helper( m_list );
+        helper.saveColumnWidths( "ManageAlertsDialogWidths" );
+    }
 }
 
-void ManageAlertsDialog::addAlert()
+void ManageAlertsDialog::initializeList( AlertsModel* model )
 {
-    AddAlertDialog dialog( m_folderId, this );
-    dialog.exec();
+    m_model = model;
+
+    m_list->setModel( m_model );
+
+    TreeViewHelper helper( m_list );
+
+    QList<int> widths;
+    widths << 150 << 80 << 80 << 80;
+    if ( m_emailEnabled )
+        widths.append( 150 );
+    widths << 80;
+
+    helper.loadColumnWidths( "ManageAlertsDialogWidths", widths );
+
+    connect( m_model, SIGNAL( layoutChanged() ), this, SLOT( updateActions() ) );
+    connect( m_model, SIGNAL( modelReset() ), this, SLOT( updateActions() ) );
+
+    connect( m_list->selectionModel(), SIGNAL( selectionChanged( const QItemSelection&, const QItemSelection& ) ),
+        this, SLOT( updateActions() ) );
 }
 
 void ManageAlertsDialog::editDelete()
 {
-    if ( m_selectedAlertId != 0 ) {
+    if ( m_selectedEditable ) {
         DeleteAlertDialog dialog( m_selectedAlertId, this );
         dialog.exec();
     }
@@ -136,7 +148,7 @@ void ManageAlertsDialog::editDelete()
 
 void ManageAlertsDialog::editModify()
 {
-    if ( m_selectedAlertId != 0 && m_emailEnabled != 0 ) {
+    if ( m_selectedEditable && m_emailEnabled ) {
         ModifyAlertDialog dialog( m_selectedAlertId, this );
         dialog.exec();
     }
@@ -144,26 +156,30 @@ void ManageAlertsDialog::editModify()
 
 void ManageAlertsDialog::updateActions()
 {
-    FolderEntity folder = FolderEntity::find( m_folderId );
-
-    action( "addAlert" )->setEnabled( folder.isValid() );
-
     m_selectedAlertId = 0;
+    m_selectedEditable = false;
 
     TreeViewHelper helper( m_list );
     QModelIndex index = helper.selectedIndex();
 
-    if ( index.isValid() )
+    if ( index.isValid() ) {
         m_selectedAlertId = m_model->rowId( index );
+        if ( m_canEditPublic ) {
+            m_selectedEditable = true;
+        } else {
+            AlertEntity alert = AlertEntity::find( m_selectedAlertId );
+            m_selectedEditable = !alert.isPublic();
+        }
+    }
 
-    action( "editDelete" )->setEnabled( m_selectedAlertId != 0 );
-    if ( m_emailEnabled != 0 )
-        action( "editModify" )->setEnabled( m_selectedAlertId != 0 );
+    action( "editDelete" )->setEnabled( m_selectedEditable );
+    if ( m_emailEnabled )
+        action( "editModify" )->setEnabled( m_selectedEditable );
 }
 
 void ManageAlertsDialog::doubleClicked( const QModelIndex& index )
 {
-    if ( index.isValid() && m_emailEnabled != 0 ) {
+    if ( index.isValid() && m_selectedEditable && m_emailEnabled ) {
         int alertId = m_model->rowId( index );
 
         ModifyAlertDialog dialog( alertId, this );
@@ -190,3 +206,75 @@ void ManageAlertsDialog::listContextMenu( const QPoint& pos )
     if ( menu )
         menu->popup( m_list->viewport()->mapToGlobal( pos ) );
 }
+
+ManageFolderAlertsDialog::ManageFolderAlertsDialog( int folderId ) : ManageAlertsDialog( folderId ),
+    m_folderId( folderId )
+{
+    FolderEntity folder = FolderEntity::find( folderId );
+    setPrompt( tr( "Edit alert settings for folder <b>%1</b>:" ).arg( folder.name() ) );
+
+    AlertsModel* model = new AlertsModel( this );
+    model->initializeFolder( folderId );
+
+    initializeList( model );
+}
+
+ManageFolderAlertsDialog::~ManageFolderAlertsDialog()
+{
+}
+
+void ManageFolderAlertsDialog::addAlert()
+{
+    AddAlertDialog dialog( m_folderId, false, this );
+    dialog.exec();
+}
+
+void ManageFolderAlertsDialog::addPublicAlert()
+{
+    AddAlertDialog dialog( m_folderId, true, this );
+    dialog.exec();
+}
+
+void ManageFolderAlertsDialog::updateActions()
+{
+    FolderEntity folder = FolderEntity::find( m_folderId );
+    action( "addAlert" )->setEnabled( folder.isValid() );
+
+    ManageAlertsDialog::updateActions();
+}
+
+ManageGlobalAlertsDialog::ManageGlobalAlertsDialog( int typeId ) : ManageAlertsDialog( 0 ),
+    m_typeId( typeId )
+{
+    TypeEntity type = TypeEntity::find( typeId );
+    setPrompt( tr( "Edit alert settings for type <b>%1</b>:" ).arg( type.name() ) );
+
+    AlertsModel* model = new AlertsModel( this );
+    model->initializeGlobalList( typeId );
+
+    initializeList( model );
+}
+
+ManageGlobalAlertsDialog::~ManageGlobalAlertsDialog()
+{
+}
+
+void ManageGlobalAlertsDialog::addAlert()
+{
+    AddGlobalAlertDialog dialog( m_typeId, false, this );
+    dialog.exec();
+}
+
+void ManageGlobalAlertsDialog::addPublicAlert()
+{
+    AddGlobalAlertDialog dialog( m_typeId, true, this );
+    dialog.exec();
+}
+
+void ManageGlobalAlertsDialog::updateActions()
+{
+    TypeEntity type = TypeEntity::find( m_typeId );
+    action( "addAlert" )->setEnabled( type.isValid() );
+
+    ManageAlertsDialog::updateActions();
+}
