@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ class QTreeView;
 class QModelIndex;
 
 /**
-* Dialog for managing alerts.
+* Base dialog for managing alerts.
 */
 class ManageAlertsDialog : public InformationDialog, public XmlUi::Client
 {
@@ -38,34 +38,96 @@ public:
     /**
     * Constructor.
     * @param folderId Identifier of the folder.
-    * @param parent The parent widget.
     */
-    ManageAlertsDialog( int folderId, QWidget* parent );
+    ManageAlertsDialog( int folderId );
 
     /**
     * Destructor.
     */
     ~ManageAlertsDialog();
 
+protected:
+    void initializeList( AlertsModel* model );
+
+protected slots:
+    virtual void addAlert() = 0;
+    virtual void addPublicAlert() = 0;
+
+    virtual void updateActions();
+
 private slots:
-    void addAlert();
     void editDelete();
     void editModify();
 
-    void updateActions();
-
     void doubleClicked( const QModelIndex& index );
     void listContextMenu( const QPoint& pos );
 
 private:
-    int m_folderId;
-
     QTreeView* m_list;
     AlertsModel* m_model;
 
     bool m_emailEnabled;
+    bool m_canEditPublic;
 
     int m_selectedAlertId;
+    bool m_selectedEditable;
 };
 
+/**
+* Dialog for managing folder alerts.
+*/
+class ManageFolderAlertsDialog : public ManageAlertsDialog
+{
+    Q_OBJECT
+public:
+    /**
+    * Constructor.
+    * @param folderId Identifier of the folder.
+    */
+    ManageFolderAlertsDialog( int folderId );
+
+    /**
+    * Destructor.
+    */
+    ~ManageFolderAlertsDialog();
+
+protected: // overrides
+    void addAlert();
+    void addPublicAlert();
+
+    void updateActions();
+
+private:
+    int m_folderId;
+};
+
+/**
+* Dialog for managing global alerts.
+*/
+class ManageGlobalAlertsDialog : public ManageAlertsDialog
+{
+    Q_OBJECT
+public:
+    /**
+    * Constructor.
+    * @param typeId Identifier of the issue type.
+    */
+    ManageGlobalAlertsDialog( int typeId );
+
+    /**
+    * Destructor.
+    */
+    ~ManageGlobalAlertsDialog();
+
+protected: // overrides
+    void addAlert();
+    void addPublicAlert();
+
+    void updateActions();
+
+private:
+    int m_typeId;
+};
+
+
 #endif
