@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -19,10 +19,9 @@
 
 #include "membersdialog.h"
 
-#include "application.h"
 #include "data/datamanager.h"
 #include "data/entities.h"
-#include "data/localsettings.h"
+#include "dialogs/projectdialogs.h"
 #include "dialogs/userdialogs.h"
 #include "models/membersmodel.h"
 #include "utils/treeviewhelper.h"
@@ -34,9 +33,12 @@
 #include <QAction>
 #include <QTreeView>
 #include <QDialogButtonBox>
+#include <QPushButton>
+#include <QGroupBox>
+#include <QLineEdit>
 #include <QMenu>
 
-MembersDialog::MembersDialog( int projectId, QWidget* parent ) : InformationDialog( parent ),
+MembersDialog::MembersDialog( int projectId ) : InformationDialog( NULL, Qt::Window ),
     m_projectId( projectId )
 {
     ProjectEntity project = ProjectEntity::find( projectId );
@@ -64,19 +66,40 @@ MembersDialog::MembersDialog( int projectId, QWidget* parent ) : InformationDial
     XmlUi::Builder* builder = new XmlUi::Builder( this );
     builder->addClient( this );
 
-    setWindowTitle( tr( "Project Members" ) );
-    setPromptPixmap( IconLoader::pixmap( "view-members", 22 ) );
-    setPrompt( tr( "Members of project <b>%1</b>:" ).arg( project.name() ) );
+    setWindowTitle( tr( "Manage Permissions" ) );
+    setPromptPixmap( IconLoader::pixmap( "edit-access", 22 ) );
+    setPrompt( tr( "Edit permissions of project <b>%1</b>:" ).arg( project.name() ) );
 
     QVBoxLayout* layout = new QVBoxLayout();
-    layout->setSpacing( 4 );
+
+    QGroupBox* globalGroup = new QGroupBox( tr( "Global Access" ), this );
+    layout->addWidget( globalGroup );
+
+    QHBoxLayout* globalLayout = new QHBoxLayout( globalGroup );
+
+    m_globalEdit = new QLineEdit( globalGroup );
+    m_globalEdit->setReadOnly( true );
+    globalLayout->addWidget( m_globalEdit );
+
+    QPushButton* globalButton = new QPushButton( tr( "Change..." ), globalGroup );
+    globalButton->setIcon( IconLoader::icon( "edit-modify" ) );
+    globalButton->setIconSize( QSize( 16, 16 ) );
+    globalLayout->addWidget( globalButton );
+
+    connect( globalButton, SIGNAL( clicked() ), this, SLOT( changeGlobalAccess() ) );
+
+    layout->addSpacing( 5 );
+
+    QVBoxLayout* membersLayout = new QVBoxLayout();
+    membersLayout->setSpacing( 4 );
+    layout->addLayout( membersLayout );
 
     XmlUi::ToolStrip* strip = new XmlUi::ToolStrip( this );
     builder->registerToolStrip( "stripMembers", strip );
-    layout->addWidget( strip );
+    membersLayout->addWidget( strip );
 
     m_list = new QTreeView( this );
-    layout->addWidget( m_list );
+    membersLayout->addWidget( m_list );
 
     TreeViewHelper helper( m_list );
     helper.initializeView( TreeViewHelper::MultiSelect );
@@ -100,17 +123,26 @@ MembersDialog::MembersDialog( int projectId, QWidget* parent ) : InformationDial
 
     setContentLayout( layout, false );
 
-    resize( application->applicationSettings()->value( "MembersDialogSize", QSize( 350, 450 ) ).toSize() );
+    resize( 350, 450 );
 
+    dataManager->addObserver( this );
+
+    updateGlobalAccess();
     updateActions();
 }
 
 MembersDialog::~MembersDialog()
 {
-    application->applicationSettings()->setValue( "MembersDialogSize", size() );
-
     TreeViewHelper helper( m_list );
     helper.saveColumnWidths( "MembersDialogWidths" );
+
+    dataManager->removeObserver( this );
+}
+
+void MembersDialog::changeGlobalAccess()
+{
+    ChangeProjectAccessDialog dialog( m_projectId, this );
+    dialog.exec();
 }
 
 void MembersDialog::addMember()
@@ -131,6 +163,25 @@ void MembersDialog::removeMember()
     dialog.exec();
 }
 
+void MembersDialog::customEvent( QEvent* e )
+{
+    if ( e->type() == UpdateEvent::Type ) {
+        UpdateEvent* updateEvent = (UpdateEvent*)e;
+        if ( updateEvent->unit() == UpdateEvent::Projects )
+            updateGlobalAccess();
+    }
+}
+
+void MembersDialog::updateGlobalAccess()
+{
+    ProjectEntity project = ProjectEntity::find( m_projectId );
+
+    if ( project.isPublic() )
+        m_globalEdit->setText( tr( "Public project" ) );
+    else
+        m_globalEdit->setText( tr( "Regular project" ) );
+}
+
 void MembersDialog::updateActions()
 {
     bool isAdmin = ProjectEntity::isAdmin( m_projectId );
