@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@ class MembersModel;
 
 class QTreeView;
 class QModelIndex;
+class QLineEdit;
 
 /**
 * Dialog for managing project members.
@@ -38,16 +39,20 @@ public:
     /**
     * Constructor.
     * @param projectId Identifier of the project.
-    * @param parent The parent widget.
     */
-    MembersDialog( int projectId, QWidget* parent );
+    MembersDialog( int projectId );
 
     /**
     * Destructor.
     */
     ~MembersDialog();
 
+protected: // overrides
+    void customEvent( QEvent* e );
+
 private slots:
+    void changeGlobalAccess();
+
     void addMember();
     void changeAccess();
     void removeMember();
@@ -57,9 +62,14 @@ private slots:
     void doubleClicked( const QModelIndex& index );
     void listContextMenu( const QPoint& pos );
 
+private:
+    void updateGlobalAccess();
+
 private:
     int m_projectId;
 
+    QLineEdit* m_globalEdit;
+
     QTreeView* m_list;
     MembersModel* m_model;
 
