@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -19,10 +19,12 @@
 
 #include "preferencesdialog.h"
 
+#include "application.h"
 #include "commands/updatebatch.h"
 #include "commands/preferencesbatch.h"
 #include "data/datamanager.h"
 #include "data/entities.h"
+#include "models/issuedetailsgenerator.h"
 #include "utils/validator.h"
 #include "utils/formatter.h"
 #include "utils/iconloader.h"
@@ -35,19 +37,25 @@
 #include <QTabWidget>
 #include <QPushButton>
 #include <QCheckBox>
-#include <QGroupBox>
 #include <QButtonGroup>
 #include <QTimer>
 #include <QDateTime>
+#include <QGroupBox>
+
+static QString formatTimeZone( const QString& zone )
+{
+    QString name = zone;
+    name.replace( QChar( '_' ), QChar( ' ' ) );
+    name.replace( QLatin1String( "/" ), QLatin1String( " / " ) );
+    name.replace( QLatin1String( "St " ), QLatin1String( "St. " ) );
+    return name;
+}
 
 PreferencesDialog::PreferencesDialog( int userId, QWidget* parent ) : CommandDialog( parent ),
     m_userId( userId ),
-    m_initialized( false ),
     m_emailEdit( NULL ),
     m_detailsCheckBox( NULL ),
-    m_noReadCheckBox( NULL ),
-    m_daysGroup( NULL ),
-    m_hoursGroup( NULL )
+    m_noReadCheckBox( NULL )
 {
     UserEntity user = UserEntity::find( userId );
 
@@ -65,14 +73,14 @@ PreferencesDialog::PreferencesDialog( int userId, QWidget* parent ) : CommandDia
     m_tabWidget = new QTabWidget( this );
     layout->addWidget( m_tabWidget );
 
-    QWidget* generalTab = new QWidget( m_tabWidget );
-    m_tabWidget->addTab( generalTab, IconLoader::icon( "preferences" ), tr( "General" ) );
+    QWidget* regionalTab = new QWidget( m_tabWidget );
+    m_tabWidget->addTab( regionalTab, IconLoader::icon( "web" ), tr( "Regional" ) );
 
-    QVBoxLayout* generalLayout = new QVBoxLayout( generalTab );
+    QVBoxLayout* regionalTabLayout = new QVBoxLayout( regionalTab );
 
-    QGroupBox* regionalGroup = new QGroupBox( tr( "Regional Options" ), generalTab );
+    QGroupBox* regionalGroup = new QGroupBox( tr( "Regional Options" ), regionalTab );
     QGridLayout* regionalLayout = new QGridLayout( regionalGroup );
-    generalLayout->addWidget( regionalGroup );
+    regionalTabLayout->addWidget( regionalGroup );
 
     QLabel* noteRegionalLabel = new QLabel( tr( "The following settings only affect the Web Client and email notifications.\n"
         "The Desktop Client will always use the language configured in program settings and the local time zone." ), regionalGroup );
@@ -97,9 +105,9 @@ PreferencesDialog::PreferencesDialog( int userId, QWidget* parent ) : CommandDia
 
     regionalLayout->setColumnStretch( 2, 1 );
 
-    QGroupBox* formatsGroup = new QGroupBox( tr( "Formats" ), generalTab );
+    QGroupBox* formatsGroup = new QGroupBox( tr( "Formats" ), regionalTab );
     QGridLayout* formatsLayout = new QGridLayout( formatsGroup );
-    generalLayout->addWidget( formatsGroup );
+    regionalTabLayout->addWidget( formatsGroup );
 
     QLabel* noteFormatsLabel = new QLabel( tr( "Customize the format of numbers, date and time. "
         "Default formats depend on the selected language." ), regionalGroup );
@@ -139,9 +147,16 @@ PreferencesDialog::PreferencesDialog( int userId, QWidget* parent ) : CommandDia
 
     formatsLayout->setColumnStretch( 2, 1 );
 
-    QGroupBox* pageGroup = new QGroupBox( tr( "Page Size" ), generalTab );
+    regionalTabLayout->addStretch( 1 );
+
+    QWidget* viewTab = new QWidget( m_tabWidget );
+    m_tabWidget->addTab( viewTab, IconLoader::icon( "view" ), tr( "View" ) );
+
+    QVBoxLayout* viewTabLayout = new QVBoxLayout( viewTab );
+
+    QGroupBox* pageGroup = new QGroupBox( tr( "Page Size" ), viewTab );
     QGridLayout* pageLayout = new QGridLayout( pageGroup );
-    generalLayout->addWidget( pageGroup );
+    viewTabLayout->addWidget( pageGroup );
 
     QLabel* notePageLabel = new QLabel( tr( "The following settings only affect the Web Client." ), pageGroup );
     pageLayout->addWidget( notePageLabel, 0, 0, 1, 3 );
@@ -154,7 +169,7 @@ PreferencesDialog::PreferencesDialog( int userId, QWidget* parent ) : CommandDia
 
     folderPageLabel->setBuddy( m_folderPageComboBox );
 
-    m_folderPageComboBox->addItem( tr( "Default", "page size" ) );
+    m_folderPageComboBox->addItem( tr( "Default (%1)", "page size" ).arg( dataManager->setting( "folder_page_size" ) ) );
     m_folderPageComboBox->addSeparator();
     for ( int i = 5; i <= 25; i += 5 )
         m_folderPageComboBox->addItem( QString::number( i ), i );
@@ -165,7 +180,7 @@ PreferencesDialog::PreferencesDialog( int userId, QWidget* parent ) : CommandDia
     m_historyPageComboBox = new SeparatorComboBox( pageGroup );
     pageLayout->addWidget( m_historyPageComboBox, 2, 1 );
 
-    m_historyPageComboBox->addItem( tr( "Default", "page size" ) );
+    m_historyPageComboBox->addItem( tr( "Default (%1)", "page size" ).arg( dataManager->setting( "history_page_size" ) ) );
     m_historyPageComboBox->addSeparator();
     for ( int i = 10; i <= 50; i += 10 )
         m_historyPageComboBox->addItem( QString::number( i ), i );
@@ -174,7 +189,82 @@ PreferencesDialog::PreferencesDialog( int userId, QWidget* parent ) : CommandDia
 
     pageLayout->setColumnStretch( 2, 1 );
 
-    generalLayout->addStretch( 1 );
+    QGroupBox* viewGroup = new QGroupBox( tr( "View Settings" ), viewTab );
+    QGridLayout* viewLayout = new QGridLayout( viewGroup );
+    viewTabLayout->addWidget( viewGroup );
+
+    QLabel* noteViewLabel = new QLabel( tr( "Global view settings that affect all issue types." ), viewGroup );
+    viewLayout->addWidget( noteViewLabel, 0, 0, 1, 3 );
+
+    QLabel* orderLabel = new QLabel( tr( "Order of issue history:" ), viewGroup );
+    viewLayout->addWidget( orderLabel, 1, 0 );
+
+    m_orderComboBox = new SeparatorComboBox( viewGroup );
+    viewLayout->addWidget( m_orderComboBox, 1, 1 );
+
+    orderLabel->setBuddy( m_orderComboBox );
+
+    QMap<QString, QString> orderItems;
+    orderItems.insert( "asc", tr( "Oldest First" ) );
+    orderItems.insert( "desc", tr( "Newest First" ) );
+
+    QString defaultOrder = orderItems.value( dataManager->setting( "history_order" ) );
+
+    m_orderComboBox->addItem( tr( "Default (%1)", "order" ).arg( defaultOrder ) );
+    m_orderComboBox->addSeparator();
+    for ( QMap<QString, QString>::const_iterator it = orderItems.begin(); it != orderItems.end(); ++it )
+        m_orderComboBox->addItem( it.value(), it.key() );
+
+    QLabel* filterLabel = new QLabel( tr( "Default filter in issue history:" ), viewGroup );
+    viewLayout->addWidget( filterLabel, 2, 0 );
+
+    m_filterComboBox = new SeparatorComboBox( viewGroup );
+    viewLayout->addWidget( m_filterComboBox, 2, 1 );
+
+    filterLabel->setBuddy( m_filterComboBox );
+
+    QMap<int, QString> filterItems;
+    filterItems.insert( IssueDetailsGenerator::AllHistory, tr( "All History" ) );
+    filterItems.insert( IssueDetailsGenerator::CommentsAndFiles, tr( "Comments & Attachments" ) );
+
+    QString defaultFilter = filterItems.value( dataManager->setting( "history_filter" ).toInt() );
+
+    m_filterComboBox->addItem( tr( "Default (%1)", "filter" ).arg( defaultFilter ) );
+    m_filterComboBox->addSeparator();
+    for ( QMap<int, QString>::const_iterator it = filterItems.begin(); it != filterItems.end(); ++it )
+        m_filterComboBox->addItem( it.value(), it.key() );
+
+    viewLayout->setColumnStretch( 2, 1 );
+
+    QGroupBox* editGroup = new QGroupBox( tr( "Editing" ), viewTab );
+    QGridLayout* editLayout = new QGridLayout( editGroup );
+    viewTabLayout->addWidget( editGroup );
+
+    QLabel* editNoteLabel = new QLabel( tr( "The default format used for new comments and descriptions." ), editGroup );
+    editLayout->addWidget( editNoteLabel, 0, 0, 1, 3 );
+
+    QLabel* formatLabel = new QLabel( tr( "Default text format:" ), editGroup );
+    editLayout->addWidget( formatLabel, 1, 0 );
+
+    m_formatComboBox = new SeparatorComboBox( editGroup );
+    editLayout->addWidget( m_formatComboBox, 1, 1 );
+
+    formatLabel->setBuddy( m_formatComboBox );
+
+    QMap<int, QString> formatItems;
+    formatItems.insert( PlainText, tr( "Plain Text" ) );
+    formatItems.insert( TextWithMarkup, tr( "Text with Markup" ) );
+
+    QString defaultFormat = formatItems.value( dataManager->setting( "default_format" ).toInt() );
+
+    m_formatComboBox->addItem( tr( "Default (%1)", "format" ).arg( defaultFormat ) );
+    m_formatComboBox->addSeparator();
+    for ( QMap<int, QString>::const_iterator it = formatItems.begin(); it != formatItems.end(); ++it )
+        m_formatComboBox->addItem( it.value(), it.key() );
+
+    editLayout->setColumnStretch( 2, 1 );
+
+    viewTabLayout->addStretch( 1 );
 
     int emailEnabled = dataManager->setting( "email_enabled" ).toInt();
 
@@ -204,143 +294,18 @@ PreferencesDialog::PreferencesDialog( int userId, QWidget* parent ) : CommandDia
         QVBoxLayout* alertLayout = new QVBoxLayout( alertGroup );
         notifyLayout->addWidget( alertGroup, 3, 0, 1, 2 );
 
-        if ( dataManager->checkServerVersion( "1.0.2" ) ) {
-            m_detailsCheckBox = new QCheckBox( tr( "I&nclude issue details in notificatons and summary reports" ), alertGroup );
-            alertLayout->addWidget( m_detailsCheckBox );
-        }
+        m_detailsCheckBox = new QCheckBox( tr( "I&nclude issue details in notificatons and summary reports" ), alertGroup );
+        alertLayout->addWidget( m_detailsCheckBox );
 
         m_noReadCheckBox = new QCheckBox( tr( "&Do not notify about issues that I have already read" ), alertGroup );
         alertLayout->addWidget( m_noReadCheckBox );
 
-        QGroupBox* summaryGroup = new QGroupBox( tr( "Summary Schedule" ), notifyTab );
-        QVBoxLayout* summaryLayout = new QVBoxLayout( summaryGroup );
-        notifyLayout->addWidget( summaryGroup, 4, 0, 1, 2 );
-
-        QHBoxLayout* daysHeaderLayout = new QHBoxLayout();
-        summaryLayout->addLayout( daysHeaderLayout );
-
-        QLabel* daysLabel = new QLabel( tr( "Send on the following days:" ), summaryGroup );
-        daysHeaderLayout->addWidget( daysLabel );
-
-        daysHeaderLayout->addStretch( 1 );
-
-        QLabel* allDaysLabel = new QLabel( "<a href=\"#\">" + tr( "Select All" ) + "</a>", summaryGroup );
-        daysHeaderLayout->addWidget( allDaysLabel );
-
-        QLabel* noDaysLabel = new QLabel( "<a href=\"#\">" + tr( "Unselect All" ) + "</a>", summaryGroup );
-        daysHeaderLayout->addWidget( noDaysLabel );
-
-        connect( allDaysLabel, SIGNAL( linkActivated( const QString& ) ), this, SLOT( allDaysActivated() ) );
-        connect( noDaysLabel, SIGNAL( linkActivated( const QString& ) ), this, SLOT( noDaysActivated() ) );
-
-        QHBoxLayout* daysLayout = new QHBoxLayout();
-        summaryLayout->addLayout( daysLayout );
-
-        m_daysGroup = new QButtonGroup( this );
-        m_daysGroup->setExclusive( false );
-
-        QLocale currentLocale;
-        int firstDayOfWeek = dataManager->setting( "first_day_of_week" ).toInt();
-
-        for ( int i = 0; i < 7; i++ ) {
-            int day = ( i + firstDayOfWeek ) % 7;
-            QCheckBox* checkBox = new QCheckBox( currentLocale.dayName( day != 0 ? day : 7 ), summaryGroup );
-            m_daysGroup->addButton( checkBox, day );
-            daysLayout->addWidget( checkBox );
-        }
-
-        daysLayout->addStretch( 1 );
-
-        summaryLayout->addSpacing( 10 );
-
-        QHBoxLayout* hoursHeaderLayout = new QHBoxLayout();
-        summaryLayout->addLayout( hoursHeaderLayout );
-
-        QLabel* hoursLabel = new QLabel( tr( "Send at the following hours:" ), summaryGroup );
-        hoursHeaderLayout->addWidget( hoursLabel );
-
-        hoursHeaderLayout->addStretch( 1 );
-
-        QLabel* allHoursLabel = new QLabel( "<a href=\"#\">" + tr( "Select All" ) + "</a>", summaryGroup );
-        hoursHeaderLayout->addWidget( allHoursLabel );
-
-        QLabel* noHoursLabel = new QLabel( "<a href=\"#\">" + tr( "Unselect All" ) + "</a>", summaryGroup );
-        hoursHeaderLayout->addWidget( noHoursLabel );
-
-        connect( allHoursLabel, SIGNAL( linkActivated( const QString& ) ), this, SLOT( allHoursActivated() ) );
-        connect( noHoursLabel, SIGNAL( linkActivated( const QString& ) ), this, SLOT( noHoursActivated() ) );
-
-        QGridLayout* hoursLayout = new QGridLayout();
-        summaryLayout->addLayout( hoursLayout );
-
-        m_hoursGroup = new QButtonGroup( this );
-        m_hoursGroup->setExclusive( false );
-
-        Formatter formatter;
-
-        for ( int row = 0; row < 3; row++ ) {
-            for ( int col = 0; col < 8; col++ ) {
-                int hour = 8 * row + col;
-                QCheckBox* checkBox = new QCheckBox( formatter.formatTime( QTime( hour, 0 ) ), summaryGroup );
-                m_hoursGroup->addButton( checkBox, hour );
-                hoursLayout->addWidget( checkBox, row, col );
-            }
-        }
-
-        hoursLayout->setColumnStretch( hoursLayout->columnCount(), 1 );
-
-        summaryLayout->addSpacing( 10 );
-
-        QLabel* noteSummaryLabel = new QLabel( tr( "You will not receive summary emails if you do not select any day and hour." ), summaryGroup );
-        summaryLayout->addWidget( noteSummaryLabel );
-
         notifyLayout->setRowStretch( notifyLayout->rowCount(), 1 );
     }
 
-    setContentLayout( layout, true );
+    LanguageEntity defaultLanguage = LanguageEntity::find( dataManager->setting( "language" ) );
 
-    UpdateBatch* batch = new UpdateBatch( 0 );
-    batch->updateLocale();
-    batch->updatePreferences( userId );
-
-    executeBatch( batch, tr( "Loading preferences..." ) );
-}
-
-PreferencesDialog::~PreferencesDialog()
-{
-}
-
-bool PreferencesDialog::batchSuccessful( AbstractBatch* /*batch*/ )
-{
-    if ( !m_initialized ) {
-        initialize();
-        showInfo( tr( "Edit user preferences." ) );
-        return false;
-    }
-
-    return true;
-}
-
-bool PreferencesDialog::batchFailed( AbstractBatch* /*batch*/ )
-{
-    if ( !m_initialized )
-        return false;
-    return true;
-}
-
-void PreferencesDialog::fixGeometry()
-{
-    m_languageComboBox->updateGeometry();
-    m_numberComboBox->updateGeometry();
-    m_dateComboBox->updateGeometry();
-    m_timeComboBox->updateGeometry();
-    m_firstDayComboBox->updateGeometry();
-    m_timeZoneComboBox->updateGeometry();
-}
-
-void PreferencesDialog::initialize()
-{
-    m_languageComboBox->addItem( tr( "Default", "language" ) );
+    m_languageComboBox->addItem( tr( "Default (%1)", "language" ).arg( defaultLanguage.name() ) );
     m_languageComboBox->addSeparator();
 
     foreach ( const LanguageEntity& language, LanguageEntity::list() )
@@ -349,21 +314,23 @@ void PreferencesDialog::initialize()
     m_numberComboBox->addItem( tr( "Default", "format" ) );
     m_numberComboBox->addSeparator();
 
-    foreach ( const FormatEntity& format, FormatEntity::list( "number_format" ) ) {
-        DefinitionInfo info = DefinitionInfo::fromString( format.definition() );
+    QMap<QString, QString> numberFormats = application->formats( "number_format" );
+    for ( QMap<QString, QString>::const_iterator it = numberFormats.begin(); it != numberFormats.end(); ++it ) {
+        DefinitionInfo info = DefinitionInfo::fromString( it.value() );
         QString number = QLatin1String( "1" );
         number += info.metadata( "group-separator" ).toString();
         number += QLatin1String( "000" );
         number += info.metadata( "decimal-separator" ).toString();
         number += QLatin1String( "00" );
-        m_numberComboBox->addItem( number, format.key() );
+        m_numberComboBox->addItem( number, it.key() );
     }
 
     m_dateComboBox->addItem( tr( "Default", "format" ) );
     m_dateComboBox->addSeparator();
 
-    foreach ( const FormatEntity& format, FormatEntity::list( "date_format" ) ) {
-        DefinitionInfo info = DefinitionInfo::fromString( format.definition() );
+    QMap<QString, QString> dateFormats = application->formats( "date_format" );
+    for ( QMap<QString, QString>::const_iterator it = dateFormats.begin(); it != dateFormats.end(); ++it ) {
+        DefinitionInfo info = DefinitionInfo::fromString( it.value() );
         QMap<QChar, QString> parts;
         parts.insert( QChar( 'd' ), info.metadata( "pad-day" ).toBool() ? "dd" : "d" );
         parts.insert( QChar( 'm' ), info.metadata( "pad-month" ).toBool() ? "mm" : "m" );
@@ -375,14 +342,15 @@ void PreferencesDialog::initialize()
         date += parts.value( order.at( 1 ) );
         date += separator;
         date += parts.value( order.at( 2 ) );
-        m_dateComboBox->addItem( date, format.key() );
+        m_dateComboBox->addItem( date, it.key() );
     }
 
     m_timeComboBox->addItem( tr( "Default", "format" ) );
     m_timeComboBox->addSeparator();
 
-    foreach ( const FormatEntity& format, FormatEntity::list( "time_format" ) ) {
-        DefinitionInfo info = DefinitionInfo::fromString( format.definition() );
+    QMap<QString, QString> timeFormats = application->formats( "time_format" );
+    for ( QMap<QString, QString>::const_iterator it = timeFormats.begin(); it != timeFormats.end(); ++it ) {
+        DefinitionInfo info = DefinitionInfo::fromString( it.value() );
         int mode = info.metadata( "time-mode" ).toInt();
         QString time = ( mode == 12 ) ? "h" : "H";
         if ( info.metadata( "pad-hour" ).toBool() )
@@ -391,7 +359,7 @@ void PreferencesDialog::initialize()
         time += QLatin1String( "mm" );
         if ( mode == 12 )
             time += QLatin1String( " tt" );
-        m_timeComboBox->addItem( time, format.key() );
+        m_timeComboBox->addItem( time, it.key() );
     }
 
     m_firstDayComboBox->addItem( tr( "Default", "day of week" ) );
@@ -401,7 +369,9 @@ void PreferencesDialog::initialize()
     for ( int i = 0; i < 7; i++ )
         m_firstDayComboBox->addItem( currentLocale.dayName( i != 0 ? i : 7 ), i );
 
-    m_timeZoneComboBox->addItem( tr( "Default", "time zone" ) );
+    QString defaultZone = formatTimeZone( dataManager->setting( "time_zone" ) );
+
+    m_timeZoneComboBox->addItem( tr( "Default (%1)", "time zone" ).arg( defaultZone ) );
     m_timeZoneComboBox->addSeparator();
 
     QMap<int, QStringList> timeZones;
@@ -425,10 +395,7 @@ void PreferencesDialog::initialize()
         m_timeZoneComboBox->addParentItem( QString( "GMT%1 (%2)" ).arg( zone, time ) );
         for ( int i = 0; i < it.value().count(); i++ ) {
             QString zone = it.value().at( i );
-            QString name = zone;
-            name.replace( QChar( '_' ), QChar( ' ' ) );
-            name.replace( QLatin1String( "/" ), QLatin1String( " / " ) );
-            name.replace( QLatin1String( "St " ), QLatin1String( "St. " ) );
+            QString name = formatTimeZone( zone );
             m_timeZoneComboBox->addChildItem( name, zone );
         }
     }
@@ -453,18 +420,12 @@ void PreferencesDialog::initialize()
     m_folderPageComboBox->setCurrentIndex( index >= 2 ? index : 0 );
     index = m_historyPageComboBox->findData( m_preferences.value( "history_page_size" ) );
     m_historyPageComboBox->setCurrentIndex( index >= 2 ? index : 0 );
-
-    m_languageComboBox->setSizeAdjustPolicy( QComboBox::AdjustToContents );
-    m_numberComboBox->setSizeAdjustPolicy( QComboBox::AdjustToContents );
-    m_dateComboBox->setSizeAdjustPolicy( QComboBox::AdjustToContents );
-    m_timeComboBox->setSizeAdjustPolicy( QComboBox::AdjustToContents );
-    m_firstDayComboBox->setSizeAdjustPolicy( QComboBox::AdjustToContents );
-    m_timeZoneComboBox->setSizeAdjustPolicy( QComboBox::AdjustToContents );
-
-#if QT_VERSION < 0x040800
-    // work around QTBUG-2559
-    QTimer::singleShot( 25, this, SLOT( fixGeometry() ) );
-#endif
+    index = m_orderComboBox->findData( m_preferences.value( "history_order" ) );
+    m_orderComboBox->setCurrentIndex( index >= 2 ? index : 0 );
+    index = m_filterComboBox->findData( m_preferences.value( "history_filter" ) );
+    m_filterComboBox->setCurrentIndex( index >= 2 ? index : 0 );
+    index = m_formatComboBox->findData( m_preferences.value( "default_format" ) );
+    m_formatComboBox->setCurrentIndex( index >= 2 ? index : 0 );
 
     if ( m_emailEdit )
         m_emailEdit->setInputValue( m_preferences.value( "email" ) );
@@ -475,27 +436,11 @@ void PreferencesDialog::initialize()
     if ( m_noReadCheckBox )
         m_noReadCheckBox->setChecked( m_preferences.value( "notify_no_read" ).toInt() != 0 );
 
-    if ( m_daysGroup ) {
-        QStringList list = m_preferences.value( "summary_days" ).split( ',' );
-        for ( int i = 0; i < list.count(); i++ ) {
-            bool ok;
-            int day = list.at( i ).toInt( &ok );
-            if ( ok && day >= 0 && day < 7 )
-                m_daysGroup->button( day )->setChecked( true );
-        }
-    }
+    setContentLayout( layout, true );
+}
 
-    if ( m_hoursGroup ) {
-        QStringList list = m_preferences.value( "summary_hours" ).split( ',' );
-        for ( int i = 0; i < list.count(); i++ ) {
-            bool ok;
-            int day = list.at( i ).toInt( &ok );
-            if ( ok && day >= 0 && day < 24 )
-                m_hoursGroup->button( day )->setChecked( true );
-        }
-    }
-
-    m_initialized = true;
+PreferencesDialog::~PreferencesDialog()
+{
 }
 
 void PreferencesDialog::accept()
@@ -513,33 +458,18 @@ void PreferencesDialog::accept()
     preferences.insert( "time_zone", m_timeZoneComboBox->itemData( m_timeZoneComboBox->currentIndex() ).toString() );
     preferences.insert( "folder_page_size", m_folderPageComboBox->itemData( m_folderPageComboBox->currentIndex() ).toString() );
     preferences.insert( "history_page_size", m_historyPageComboBox->itemData( m_historyPageComboBox->currentIndex() ).toString() );
+    preferences.insert( "history_order", m_orderComboBox->itemData( m_orderComboBox->currentIndex() ).toString() );
+    preferences.insert( "history_filter", m_filterComboBox->itemData( m_filterComboBox->currentIndex() ).toString() );
+    preferences.insert( "default_format", m_formatComboBox->itemData( m_formatComboBox->currentIndex() ).toString() );
 
     if ( m_emailEdit )
         preferences.insert( "email", m_emailEdit->inputValue() );
 
     if ( m_detailsCheckBox )
-        preferences.insert( "notify_details", m_detailsCheckBox->isChecked() ? "1" : "0" );
+        preferences.insert( "notify_details", m_detailsCheckBox->isChecked() ? "1" : "" );
 
     if ( m_noReadCheckBox )
-        preferences.insert( "notify_no_read", m_noReadCheckBox->isChecked() ? "1" : "0" );
-
-    if ( m_daysGroup ) {
-        QStringList list;
-        for ( int i = 0; i < 7; i++ ) {
-            if ( m_daysGroup->button( i )->isChecked() )
-                list.append( QString::number( i ) );
-        }
-        preferences.insert( "summary_days", list.join( "," ) );
-    }
-
-    if ( m_hoursGroup ) {
-        QStringList list;
-        for ( int i = 0; i < 24; i++ ) {
-            if ( m_hoursGroup->button( i )->isChecked() )
-                list.append( QString::number( i ) );
-        }
-        preferences.insert( "summary_hours", list.join( "," ) );
-    }
+        preferences.insert( "notify_no_read", m_noReadCheckBox->isChecked() ? "1" : "" );
 
     SetPreferencesBatch* batch = NULL;
 
@@ -556,27 +486,3 @@ void PreferencesDialog::accept()
     else
         QDialog::accept();
 }
-
-void PreferencesDialog::allDaysActivated()
-{
-    for ( int i = 0; i < 7; i++ )
-        m_daysGroup->button( i )->setChecked( true );
-}
-
-void PreferencesDialog::noDaysActivated()
-{
-    for ( int i = 0; i < 7; i++ )
-        m_daysGroup->button( i )->setChecked( false );
-}
-
-void PreferencesDialog::allHoursActivated()
-{
-    for ( int i = 0; i < 24; i++ )
-        m_hoursGroup->button( i )->setChecked( true );
-}
-
-void PreferencesDialog::noHoursActivated()
-{
-    for ( int i = 0; i < 24; i++ )
-        m_hoursGroup->button( i )->setChecked( false );
-}
