@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,6 @@ class InputLineEdit;
 
 class QTabWidget;
 class QCheckBox;
-class QButtonGroup;
 
 /**
 * Dialog for modifying user preferences using <tt>SET PREFERENCE</tt> commands.
@@ -53,25 +52,9 @@ public:
 public: // overrides
     void accept();
 
-protected: // overrides
-    bool batchSuccessful( AbstractBatch* batch );
-    bool batchFailed( AbstractBatch* batch );
-
-private slots:
-    void fixGeometry();
-
-    void allDaysActivated();
-    void noDaysActivated();
-    void allHoursActivated();
-    void noHoursActivated();
-
-private:
-    void initialize();
-
 private:
     int m_userId;
 
-    bool m_initialized;
     QMap<QString, QString> m_preferences;
 
     QTabWidget* m_tabWidget;
@@ -87,11 +70,14 @@ private:
     SeparatorComboBox* m_folderPageComboBox;
     SeparatorComboBox* m_historyPageComboBox;
 
+    SeparatorComboBox* m_orderComboBox;
+    SeparatorComboBox* m_filterComboBox;
+
+    SeparatorComboBox* m_formatComboBox;
+
     InputLineEdit* m_emailEdit;
     QCheckBox* m_detailsCheckBox;
     QCheckBox* m_noReadCheckBox;
-    QButtonGroup* m_daysGroup;
-    QButtonGroup* m_hoursGroup;
 };
 
 #endif
