@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,10 +20,14 @@
 #ifndef PROJECTDIALOGS_H
 #define PROJECTDIALOGS_H
 
+#include "data/datamanager.h"
 #include "dialogs/commanddialog.h"
 
 class InputLineEdit;
+class MarkupTextEdit;
+
 class QComboBox;
+class QButtonGroup;
 
 /**
 * Dialog for executing the <tt>ADD PROJECT</tt> command.
@@ -34,9 +38,8 @@ class AddProjectDialog : public CommandDialog
 public:
     /**
     * Constructor.
-    * @param parent The parent widget.
     */
-    AddProjectDialog( QWidget* parent );
+    AddProjectDialog();
 
     /**
     * Destructor.
@@ -48,6 +51,8 @@ public: // overrides
 
 private:
     InputLineEdit* m_nameEdit;
+
+    MarkupTextEdit* m_descriptionEdit;
 };
 
 /**
@@ -229,4 +234,116 @@ private:
     bool m_force;
 };
 
+/**
+* Dialog for executing the <tt>ADD PROJECT DESCRIPTION</tt> command.
+*/
+class AddProjectDescriptionDialog : public CommandDialog
+{
+    Q_OBJECT
+public:
+    /**
+    * Constructor.
+    * @param projectId Identifier of the project.
+    */
+    AddProjectDescriptionDialog( int projectId );
+
+    /**
+    * Destructor.
+    */
+    ~AddProjectDescriptionDialog();
+
+public: // overrides
+    void accept();
+
+private:
+    int m_projectId;
+
+    MarkupTextEdit* m_descriptionEdit;
+};
+
+/**
+* Dialog for executing the <tt>EDIT PROJECT DESCRIPTION</tt> command.
+*/
+class EditProjectDescriptionDialog : public CommandDialog
+{
+    Q_OBJECT
+public:
+    /**
+    * Constructor.
+    * @param projectId Identifier of the project.
+    */
+    EditProjectDescriptionDialog( int projectId );
+
+    /**
+    * Destructor.
+    */
+    ~EditProjectDescriptionDialog();
+
+public: // overrides
+    void accept();
+
+private:
+    int m_projectId;
+
+    QString m_oldText;
+    TextFormat m_oldFormat;
+
+    MarkupTextEdit* m_descriptionEdit;
+};
+
+/**
+* Dialog for executing the <tt>DELETE PROJECT DESCRIPTION</tt> command.
+*/
+class DeleteProjectDescriptionDialog : public CommandDialog
+{
+    Q_OBJECT
+public:
+    /**
+    * Constructor.
+    * @param projectId Identifier of the project.
+    * @param parent The parent widget.
+    */
+    DeleteProjectDescriptionDialog( int projectId, QWidget* parent );
+
+    /**
+    * Destructor.
+    */
+    ~DeleteProjectDescriptionDialog();
+
+public: // overrides
+    void accept();
+
+private:
+    int m_projectId;
+};
+
+/**
+* Dialog for executing the <tt>SET PROJECT ACCESS</tt> command.
+*/
+class ChangeProjectAccessDialog : public CommandDialog
+{
+    Q_OBJECT
+public:
+    /**
+    * Constructor.
+    * @param projectId Identifier of the project.
+    * @param parent The parent widget.
+    */
+    ChangeProjectAccessDialog( int projectId, QWidget* parent );
+
+    /**
+    * Destructor.
+    */
+    ~ChangeProjectAccessDialog();
+
+public: // overrides
+    void accept();
+
+private:
+    int m_projectId;
+    int m_oldAccess;
+
+    QButtonGroup* m_accessGroup;
+};
+
 #endif
