@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -24,7 +24,8 @@
 #include "data/localsettings.h"
 #include "dialogs/messagebox.h"
 #include "models/reportgenerator.h"
-#include "utils/textwriter.h"
+#include "models/projectsummarygenerator.h"
+#include "utils/htmlwriter.h"
 #include "utils/csvwriter.h"
 #include "utils/iconloader.h"
 
@@ -33,7 +34,8 @@
 #include <QRadioButton>
 #include <QPushButton>
 #include <QDialogButtonBox>
-#include <QTextDocument>
+#include <QWebPage>
+#include <QWebFrame>
 #include <QPrintDialog>
 #include <QFileDialog>
 #include <QTextStream>
@@ -43,50 +45,66 @@
 #include <QPrintPreviewDialog>
 #include <QApplication>
 #include <QDesktopWidget>
+#include <QAction>
 
 ReportDialog::ReportDialog( SourceType source, ReportMode mode, QWidget* parent ) : CommandDialog( parent ),
     m_source( source ),
     m_mode( mode ),
     m_folderId( 0 ),
+    m_typeId( 0 ),
+    m_projectId( 0 ),
     m_history( IssueDetailsGenerator::NoHistory ),
-    m_document( NULL )
+    m_tableButton( NULL ),
+    m_fullTableButton( NULL ),
+    m_summaryButton( NULL ),
+    m_fullReportButton( NULL ),
+    m_page( NULL ),
+    m_pdfPrinter( NULL )
 {
-    QHBoxLayout* layout = new QHBoxLayout();
-
-    QVBoxLayout* optionsLayout = new QVBoxLayout();
-    layout->addLayout( optionsLayout );
-
     if ( source == FolderSource ) {
         m_tableButton = new QRadioButton( tr( "Table with visible columns only" ), this );
-        optionsLayout->addWidget( m_tableButton );
         m_fullTableButton = new QRadioButton( tr( "Table with all system and user columns" ), this );
-        optionsLayout->addWidget( m_fullTableButton );
-    } else {
-        m_tableButton = NULL;
-        m_fullTableButton = NULL;
     }
 
     if ( mode != ExportCsv ) {
-        m_summaryButton = new QRadioButton( tr( "Summary report including issue details" ), this );
-        optionsLayout->addWidget( m_summaryButton );
-    } else {
-        m_summaryButton = NULL;
+        if ( source == FolderSource )
+            m_summaryButton = new QRadioButton( tr( "Summary report including issue details" ), this );
+        if ( source == IssueSource ) {
+            m_summaryButton = new QRadioButton( tr( "Summary report without issue history" ), this );
+            m_fullReportButton = new QRadioButton( tr( "Full report including issue history" ), this );
+        }
     }
 
-    if ( mode != ExportCsv && source == IssueSource ) {
-        m_fullReportButton = new QRadioButton( tr( "Full report including issue details and history" ), this );
-        optionsLayout->addWidget( m_fullReportButton );
-    } else {
-        m_fullReportButton = NULL;
+    QVBoxLayout* optionsLayout = NULL;
+
+    if ( m_tableButton || m_fullTableButton || m_summaryButton || m_fullReportButton ) {
+        optionsLayout = new QVBoxLayout();
+        if ( m_tableButton )
+            optionsLayout->addWidget( m_tableButton );
+        if ( m_fullTableButton )
+            optionsLayout->addWidget( m_fullTableButton );
+        if ( m_summaryButton )
+            optionsLayout->addWidget( m_summaryButton );
+        if ( m_fullReportButton )
+            optionsLayout->addWidget( m_fullReportButton );
     }
 
-    if ( mode == Print ) {
-        QPushButton* previewButton = new QPushButton( tr( "&Print Preview..." ), this );
-        previewButton->setIcon( IconLoader::icon( "print-preview" ) );
-        previewButton->setIconSize( QSize( 16, 16 ) );
-        layout->addWidget( previewButton, 0, Qt::AlignBottom | Qt::AlignRight );
+    if ( optionsLayout || mode == Print ) {
+        QHBoxLayout* layout = new QHBoxLayout();
 
-        connect( previewButton, SIGNAL( clicked() ), this, SLOT( showPreview() ) );
+        if ( optionsLayout )
+            layout->addLayout( optionsLayout );
+
+        if ( mode == Print ) {
+            QPushButton* previewButton = new QPushButton( tr( "&Print Preview..." ), this );
+            previewButton->setIcon( IconLoader::icon( "print-preview" ) );
+            previewButton->setIconSize( QSize( 16, 16 ) );
+            layout->addWidget( previewButton, 0, Qt::AlignBottom | Qt::AlignRight );
+
+            connect( previewButton, SIGNAL( clicked() ), this, SLOT( showPreview() ) );
+        }
+
+        setContentLayout( layout, true );
     }
 
     if ( m_tableButton )
@@ -102,6 +120,9 @@ ReportDialog::ReportDialog( SourceType source, ReportMode mode, QWidget* parent
         case IssueSource:
             sourceName = tr( "issue details" );
             break;
+        case ProjectSource:
+            sourceName = tr( "project summary" );
+            break;
     }
 
     switch ( mode ) {
@@ -127,151 +148,209 @@ ReportDialog::ReportDialog( SourceType source, ReportMode mode, QWidget* parent
             break;
     }
 
-    setContentLayout( layout, true );
-
-    showInfo( tr( "Select type of report." ) );
+    showInfo( tr( "Create the report." ) );
 }
 
 ReportDialog::~ReportDialog()
 {
+    delete m_pdfPrinter;
+    m_pdfPrinter = NULL;
 }
 
 void ReportDialog::setIssue( int issueId )
 {
-    m_folderId = 0;
     m_issues.clear();
     m_issues.append( issueId );
 }
 
-void ReportDialog::setFolder( int folderId, const QList<int>& issues )
+void ReportDialog::setFolder( int folderId )
 {
     m_folderId = folderId;
+    m_typeId = 0;
+}
+
+void ReportDialog::setGlobalList( int typeId )
+{
+    m_typeId = typeId;
+    m_folderId = 0;
+}
+
+void ReportDialog::setIssues( const QList<int>& issues )
+{
     m_issues = issues;
 }
 
+void ReportDialog::setProject( int projectId )
+{
+    m_projectId = projectId;
+}
+
 void ReportDialog::setHistory( IssueDetailsGenerator::History history )
 {
     m_history = history;
 }
 
-void ReportDialog::setColumns( const QList<int>& currentColumns, const QList<int>& availableColumns )
+void ReportDialog::setCurrentColumns( const QList<int>& columns )
 {
-    m_currentColumns = currentColumns;
-    m_availableColumns = availableColumns;
+    m_currentColumns = columns;
+}
+
+void ReportDialog::setAvailableColumns( const QList<int>& columns )
+{
+    m_availableColumns = columns;
 }
 
 void ReportDialog::accept()
 {
-    bool result = false;
-
     switch ( m_mode ) {
         case Print:
-            result = print();
+            print();
             break;
         case ExportCsv:
-            result = exportCsv();
+            exportCsv();
             break;
         case ExportHtml:
-            result = exportHtml();
+            exportHtml();
             break;
         case ExportPdf:
-            result = exportPdf();
+            exportPdf();
             break;
     }
-
-    if ( result )
-        QDialog::accept();
 }
 
-bool ReportDialog::print()
+void ReportDialog::print()
 {
+    if ( m_page )
+        return;
+
     QPrinter* printer = application->printer();
     printer->setFromTo( 0, 0 );
 
     QPrintDialog dialog( printer, this );
 
     if ( dialog.exec() != QDialog::Accepted )
-        return false;
+        return;
 
-    QTextDocument document;
-    generateHtmlReport( &document );
+    QString html = generateHtmlReport( false );
 
-    document.print( printer );
+    m_page = new QWebPage( this );
 
-    return true;
+    connect( m_page->mainFrame(), SIGNAL( loadFinished( bool ) ), this, SLOT( printReady() ) );
+
+    m_page->mainFrame()->setHtml( html );
 }
 
-bool ReportDialog::exportCsv()
+void ReportDialog::printReady()
+{
+    QPrinter* printer = application->printer();
+
+    m_page->mainFrame()->print( printer );
+
+    m_page->deleteLater();
+    m_page = NULL;
+
+    QDialog::accept();
+}
+
+void ReportDialog::exportCsv()
 {
     QString fileName = getReportFileName( ".csv", tr( "CSV Files (*.csv)" ) );
 
     if ( fileName.isEmpty() )
-        return false;
+        return;
 
     QFile file( fileName );
     if ( !file.open( QIODevice::WriteOnly ) ) {
         MessageBox::warning( this, tr( "Warning" ), tr( "File could not be saved." ) );
-        return false;
+        return;
     }
 
     QTextStream stream( &file );
     stream.setCodec( QTextCodec::codecForName( "UTF-8" ) );
+    stream.setGenerateByteOrderMark( true );
 
-    generateCsvReport( stream );
+    stream << generateCsvReport();
 
-    return true;
+    QDialog::accept();
 }
 
-bool ReportDialog::exportHtml()
+void ReportDialog::exportHtml()
 {
     QString fileName = getReportFileName( ".html", tr( "HTML Files (*.html)" ) );
 
     if ( fileName.isEmpty() )
-        return false;
+        return;
 
     QFile file( fileName );
     if ( !file.open( QIODevice::WriteOnly ) ) {
         MessageBox::warning( this, tr( "Warning" ), tr( "File could not be saved." ) );
-        return false;
+        return;
     }
 
     QTextStream stream( &file );
     stream.setCodec( QTextCodec::codecForName( "UTF-8" ) );
 
-    QTextDocument document;
-    generateHtmlReport( &document );
+    stream << generateHtmlReport( true );
 
-    stream << document.toHtml( "UTF-8" );
-
-    return true;
+    QDialog::accept();
 }
 
-bool ReportDialog::exportPdf()
+void ReportDialog::exportPdf()
 {
+    if ( m_page )
+        return;
+
     QString fileName = getReportFileName( ".pdf", tr( "PDF Files (*.pdf)" ) );
 
     if ( fileName.isEmpty() )
-        return false;
+        return;
 
-    QPrinter printer( QPrinter::HighResolution );
-    printer.setOutputFileName( fileName );
-    printer.setOutputFormat( QPrinter::PdfFormat );
+    m_pdfPrinter = new QPrinter( QPrinter::HighResolution );
+    m_pdfPrinter->setOutputFileName( fileName );
+    m_pdfPrinter->setOutputFormat( QPrinter::PdfFormat );
 
-    QTextDocument document;
-    generateHtmlReport( &document );
+    QString html = generateHtmlReport( false );
 
-    document.print( &printer );
+    m_page = new QWebPage( this );
 
-    return true;
+    connect( m_page->mainFrame(), SIGNAL( loadFinished( bool ) ), this, SLOT( pdfReady() ) );
+
+    m_page->mainFrame()->setHtml( html );
+}
+
+void ReportDialog::pdfReady()
+{
+    m_page->mainFrame()->print( m_pdfPrinter );
+
+    delete m_pdfPrinter;
+    m_pdfPrinter = NULL;
+
+    m_page->deleteLater();
+    m_page = NULL;
+
+    QDialog::accept();
 }
 
 void ReportDialog::showPreview()
 {
+    if ( m_page )
+        return;
+
     QPrinter* printer = application->printer();
     printer->setFromTo( 0, 0 );
 
-    m_document = new QTextDocument( this );
-    generateHtmlReport( m_document );
+    QString html = generateHtmlReport( false );
+
+    m_page = new QWebPage( this );
+
+    connect( m_page->mainFrame(), SIGNAL( loadFinished( bool ) ), this, SLOT( previewReady() ) );
+
+    m_page->mainFrame()->setHtml( html );
+}
+
+void ReportDialog::previewReady()
+{
+    QPrinter* printer = application->printer();
 
     QPrintPreviewDialog dialog( printer, this );
     dialog.setWindowTitle( tr( "Print Preview" ) );
@@ -282,29 +361,32 @@ void ReportDialog::showPreview()
     else
         dialog.resize( QApplication::desktop()->screenGeometry( this ).size() * 4 / 5 );
 
-    connect( &dialog, SIGNAL( paintRequested( QPrinter* ) ), this, SLOT( paintRequested( QPrinter* ) ) );
+    QList<QAction*> list = dialog.findChildren<QAction*>( "fitWidthAction" );
+    if ( !list.isEmpty() )
+        list.first()->trigger();
+
+    connect( &dialog, SIGNAL( paintRequested( QPrinter* ) ), m_page->mainFrame(), SLOT( print( QPrinter* ) ) );
 
     int result = dialog.exec();
 
-    delete m_document;
-    m_document = NULL;
-
     settings->setValue( "PrintPreviewGeometry", dialog.saveGeometry() );
 
+    m_page->deleteLater();
+    m_page = NULL;
+
     if ( result == QDialog::Accepted )
         QDialog::accept();
 }
 
-void ReportDialog::paintRequested( QPrinter* printer )
-{
-    m_document->print( printer );
-}
-
-void ReportDialog::generateCsvReport( QTextStream& stream )
+QString ReportDialog::generateCsvReport()
 {
     ReportGenerator generator;
 
-    generator.setFolderSource( m_folderId, m_issues );
+    if ( m_folderId != 0 )
+        generator.setFolderSource( m_folderId, m_issues );
+    else if ( m_typeId != 0 )
+        generator.setGlobalListSource( m_typeId, m_issues );
+
     if ( m_tableButton->isChecked() )
         generator.setTableMode( m_currentColumns );
     else if ( m_fullTableButton->isChecked() )
@@ -313,28 +395,45 @@ void ReportDialog::generateCsvReport( QTextStream& stream )
     CsvWriter writer;
     generator.write( &writer );
 
-    stream << writer.toString();
+    return writer.toString();
 }
 
-void ReportDialog::generateHtmlReport( QTextDocument* document )
+QString ReportDialog::generateHtmlReport( bool embedded )
 {
-    ReportGenerator generator;
+    HtmlWriter writer;
+    writer.setEmbedded( embedded );
 
-    if ( m_source == FolderSource ) {
-        generator.setFolderSource( m_folderId, m_issues );
-        if ( m_tableButton->isChecked() )
-            generator.setTableMode( m_currentColumns );
-        else if ( m_fullTableButton->isChecked() )
-            generator.setTableMode( m_availableColumns );
-        else
-            generator.setSummaryMode( IssueDetailsGenerator::NoHistory );
-    } else if ( m_source == IssueSource && !m_issues.isEmpty() ) {
-        generator.setIssueSource( m_issues.first() );
-        generator.setSummaryMode( m_fullReportButton->isChecked() ? m_history : IssueDetailsGenerator::NoHistory );
+    if ( m_source == ProjectSource ) {
+        ProjectSummaryGenerator generator;
+        generator.setProject( m_projectId );
+
+        writer.setTitle( generator.title() );
+        generator.write( &writer, HtmlText::NoInternalLinks );
+    } else {
+        ReportGenerator generator;
+
+        if ( m_source == FolderSource ) {
+            if ( m_folderId != 0 )
+                generator.setFolderSource( m_folderId, m_issues );
+            else if ( m_typeId != 0 )
+                generator.setGlobalListSource( m_typeId, m_issues );
+
+            if ( m_tableButton->isChecked() )
+                generator.setTableMode( m_currentColumns );
+            else if ( m_fullTableButton->isChecked() )
+                generator.setTableMode( m_availableColumns );
+            else
+                generator.setSummaryMode( false, IssueDetailsGenerator::NoHistory );
+        } else if ( m_source == IssueSource && !m_issues.isEmpty() ) {
+            generator.setIssueSource( m_issues.first() );
+            generator.setSummaryMode( true, m_fullReportButton->isChecked() ? m_history : IssueDetailsGenerator::NoHistory );
+        }
+
+        writer.setTitle( generator.title() );
+        generator.write( &writer );
     }
 
-    TextWriter writer( document );
-    generator.write( &writer );
+    return writer.toHtml();
 }
 
 QString ReportDialog::getReportFileName( const QString& extension, const QString& filter )
