@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -23,10 +23,8 @@
 #include "dialogs/commanddialog.h"
 #include "models/issuedetailsgenerator.h"
 
-class QPrinter;
 class QRadioButton;
-class QTextDocument;
-class QTextStream;
+class QWebPage;
 
 /**
 * Dialog for printing or exporting a report.
@@ -44,6 +42,8 @@ public:
         IssueSource,
         /** Report based on a folder with issues. */
         FolderSource,
+        /** Report based on project summary. */
+        ProjectSource
     };
 
     /**
@@ -82,14 +82,34 @@ public:
     void setIssue( int issueId );
 
     /**
-    * Set the folder and issues used as the source for the report.
+    * Set the folder used as the source for the report.
     */
-    void setFolder( int folderId, const QList<int>& issues );
+    void setFolder( int folderId );
+    
+    /**
+    * Set the type of the global list used as the source for the report.
+    */
+    void setGlobalList( int typeId );
 
     /**
-    * Set current and all available columns for table reports.
+    * Set the issues displayed in the folder report.
     */
-    void setColumns( const QList<int>& currentColumns, const QList<int>& availableColumns );
+    void setIssues( const QList<int>& issues );
+
+    /**
+    * Set the project used as the source for the report.
+    */
+    void setProject( int projectId );
+
+    /**
+    * Set current columns for table reports.
+    */
+    void setCurrentColumns( const QList<int>& columns );
+
+    /**
+    * Set all available columns for table reports.
+    */
+    void setAvailableColumns( const QList<int>& columns );
 
     /**
     * Set type of issue history to be included for summary reports.
@@ -102,16 +122,18 @@ public: // overrides
 private slots:
     void showPreview();
 
-    void paintRequested( QPrinter* printer );
+    void previewReady();
+    void printReady();
+    void pdfReady();
 
 private:
-    bool print();
-    bool exportCsv();
-    bool exportHtml();
-    bool exportPdf();
+    void print();
+    void exportCsv();
+    void exportHtml();
+    void exportPdf();
 
-    void generateCsvReport( QTextStream& stream );
-    void generateHtmlReport( QTextDocument* document );
+    QString generateCsvReport();
+    QString generateHtmlReport( bool embedded );
 
     QString getReportFileName( const QString& extension, const QString& filter );
 
@@ -120,7 +142,9 @@ private:
     ReportMode m_mode;
 
     int m_folderId;
+    int m_typeId;
     QList<int> m_issues;
+    int m_projectId;
 
     QList<int> m_currentColumns;
     QList<int> m_availableColumns;
@@ -132,7 +156,9 @@ private:
     QRadioButton* m_summaryButton;
     QRadioButton* m_fullReportButton;
 
-    QTextDocument* m_document;
+    QWebPage* m_page;
+
+    QPrinter* m_pdfPrinter;
 };
 
 #endif
