@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,13 +20,13 @@
 #ifndef SSLDIALOGS_H
 #define SSLDIALOGS_H
 
-#if defined( HAVE_OPENSSL )
-
 #include "dialogs/informationdialog.h"
 #include "dialogs/commanddialog.h"
 
 #include <QSslError>
 
+#if !defined( QT_NO_OPENSSL )
+
 class PropertyPanel;
 
 class QListWidget;
@@ -120,6 +120,6 @@ private:
     QList<QSslCertificate> m_certificates;
 };
 
-#endif // defined( HAVE_OPENSSL )
+#endif // !defined( QT_NO_OPENSSL )
 
 #endif
