@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 #include "utils/errorhelper.h"
 #include "utils/iconloader.h"
 #include "widgets/inputlineedit.h"
+#include "widgets/separatorcombobox.h"
 
 #include <QLayout>
 #include <QLabel>
@@ -383,7 +384,7 @@ void ViewDialog::updateColumnsLayout()
     m_updatingLayout = false;
 }
 
-void ViewDialog::updateSortComboBox( int current /*= -1*/ )
+void ViewDialog::updateSortComboBox( int current )
 {
     if ( current < 0 )
         current = m_sortComboBox->itemData( m_sortComboBox->currentIndex() ).toInt();
@@ -1105,3 +1106,68 @@ void AttributeOrderDialog::updateLayout()
 
     m_updatingLayout = false;
 }
+
+InitialViewDialog::InitialViewDialog( int typeId, QWidget* parent ) : CommandDialog( parent ),
+    m_typeId( typeId ),
+    m_oldViewId( 0 )
+{
+    TypeEntity type = TypeEntity::find( typeId );
+
+    QList<ViewEntity> views = type.views();
+    QList<ViewEntity> publicViews;
+
+    foreach ( ViewEntity view, views ) {
+        if ( view.isPublic() )
+            publicViews.append( view );
+    }
+
+    IssueTypeCache* cache = dataManager->issueTypeCache( typeId );
+    m_oldViewId = cache->initialViewId();
+
+    setWindowTitle( tr( "Initial View" ) );
+    setPrompt( tr( "Select initial view for type <b>%1</b>:" ).arg( type.name() ) );
+    setPromptPixmap( IconLoader::pixmap( "edit-modify", 22 ) );
+
+    QHBoxLayout* layout = new QHBoxLayout();
+
+    QLabel* label = new QLabel( tr( "&View:" ), this );
+    layout->addWidget( label, 0 );
+
+    m_comboBox = new SeparatorComboBox( this );
+    m_comboBox->addItem( tr( "All Issues" ), 0 );
+
+    if ( !publicViews.isEmpty() ) {
+        m_comboBox->addSeparator();
+        foreach ( ViewEntity view, publicViews )
+            m_comboBox->addItem( view.name(), view.id() );
+    }
+
+    m_comboBox->setCurrentIndex( m_comboBox->findData( m_oldViewId ) );
+
+    layout->addWidget( m_comboBox, 1 );
+
+    label->setBuddy( m_comboBox );
+
+    setContentLayout( layout, true );
+
+    m_comboBox->setFocus();
+}
+
+InitialViewDialog::~InitialViewDialog()
+{
+}
+
+void InitialViewDialog::accept()
+{
+    int viewId = m_comboBox->itemData( m_comboBox->currentIndex() ).toInt();
+
+    if ( viewId == m_oldViewId ) {
+        QDialog::accept();
+        return;
+    }
+
+    ViewsBatch* batch = new ViewsBatch();
+    batch->setViewSetting( m_typeId, "initial_view", viewId != 0 ? QString::number( viewId ) : "" );
+
+    executeBatch( batch );
+}
