@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 
 class DefinitionInfo;
 class InputLineEdit;
+class SeparatorComboBox;
 
 class QCheckBox;
 class QComboBox;
@@ -378,4 +379,33 @@ private:
     bool m_updatingLayout;
 };
 
+/**
+* Dialog for selecting the initial view.
+*/
+class InitialViewDialog : public CommandDialog
+{
+    Q_OBJECT
+public:
+    /**
+    * Constructor.
+    * @param typeId Identifier of the type associated with view setting.
+    * @param parent The parent widget.
+    */
+    InitialViewDialog( int typeId, QWidget* parent );
+
+    /**
+    * Destructor.
+    */
+    ~InitialViewDialog();
+
+public: // overrides
+    void accept();
+
+private:
+    int m_typeId;
+    int m_oldViewId;
+
+    SeparatorComboBox* m_comboBox;
+};
+
 #endif
