@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include "data/entities.h"
 #include "data/issuetypecache.h"
 #include "data/localsettings.h"
+#include "dialogs/dialogmanager.h"
 #include "dialogs/viewdialogs.h"
 #include "models/viewsmodel.h"
 #include "utils/treeviewhelper.h"
@@ -42,13 +43,14 @@
 #include <QTreeView>
 #include <QMenu>
 
-ViewSettingsDialog::ViewSettingsDialog( int typeId, bool isPublic, QWidget* parent ) : InformationDialog( parent ),
+ViewSettingsDialog::ViewSettingsDialog( int typeId, bool isPublic ) : InformationDialog( NULL, Qt::Window ),
     m_typeId( typeId ),
     m_isPublic( isPublic ),
     m_selectedViewId( 0 ),
     m_orderEdit( NULL ),
     m_columnsEdit( NULL ),
-    m_sortByEdit( NULL )
+    m_sortByEdit( NULL ),
+    m_initialEdit( NULL )
 {
     QAction* action;
 
@@ -153,6 +155,22 @@ ViewSettingsDialog::ViewSettingsDialog( int typeId, bool isPublic, QWidget* pare
 
         connect( defaultButton, SIGNAL( clicked() ), this, SLOT( modifyDefaultView() ) );
 
+        QGroupBox* initialGroup = new QGroupBox( tr( "Initial View" ), this );
+        layout->addWidget( initialGroup );
+
+        QHBoxLayout* initialLayout = new QHBoxLayout( initialGroup );
+
+        m_initialEdit = new QLineEdit( initialGroup );
+        m_initialEdit->setReadOnly( true );
+        initialLayout->addWidget( m_initialEdit );
+
+        QPushButton* initialButton = new QPushButton( tr( "Modify..." ), initialGroup );
+        initialButton->setIcon( IconLoader::icon( "edit-modify" ) );
+        initialButton->setIconSize( QSize( 16, 16 ) );
+        initialLayout->addWidget( initialButton );
+
+        connect( initialButton, SIGNAL( clicked() ), this, SLOT( modifyInitialView() ) );
+
         layout->addSpacing( 5 );
     }
 
@@ -196,10 +214,7 @@ ViewSettingsDialog::ViewSettingsDialog( int typeId, bool isPublic, QWidget* pare
 
     setContentLayout( layout, false );
 
-    if ( isPublic )
-        resize( application->applicationSettings()->value( "ViewSettingsDialogSizePublic", QSize( 800, 550 ) ).toSize() );
-    else
-        resize( application->applicationSettings()->value( "ViewSettingsDialogSizePersonal", QSize( 800, 350 ) ).toSize() );
+    resize( 800, isPublic ? 550 : 350 );
 
     dataManager->addObserver( this );
 
@@ -209,11 +224,6 @@ ViewSettingsDialog::ViewSettingsDialog( int typeId, bool isPublic, QWidget* pare
 
 ViewSettingsDialog::~ViewSettingsDialog()
 {
-    if ( m_isPublic )
-        application->applicationSettings()->setValue( "ViewSettingsDialogSizePublic", size() );
-    else
-        application->applicationSettings()->setValue( "ViewSettingsDialogSizePersonal", size() );
-
     TreeViewHelper helper( m_list );
     helper.saveColumnWidths( "ViewSettingsDialogWidths" );
 
@@ -232,6 +242,12 @@ void ViewSettingsDialog::modifyDefaultView()
     dialog.exec();
 }
 
+void ViewSettingsDialog::modifyInitialView()
+{
+    InitialViewDialog dialog( m_typeId, this );
+    dialog.exec();
+}
+
 void ViewSettingsDialog::addView()
 {
     AddViewDialog dialog( m_typeId, m_isPublic, this );
@@ -278,7 +294,19 @@ void ViewSettingsDialog::editPublish()
 
 void ViewSettingsDialog::switchMode()
 {
-    done( SwitchMode );
+    if ( m_isPublic ) {
+        if ( dialogManager->activateDialog( "PersonalViewSettingsDialog", m_typeId ) )
+            return;
+        PersonalViewSettingsDialog* dialog = new PersonalViewSettingsDialog( m_typeId );
+        dialogManager->addDialog( dialog, m_typeId );
+        dialog->show();
+    } else {
+        if ( dialogManager->activateDialog( "PublicViewSettingsDialog", m_typeId ) )
+            return;
+        PublicViewSettingsDialog* dialog = new PublicViewSettingsDialog( m_typeId );
+        dialogManager->addDialog( dialog, m_typeId );
+        dialog->show();
+    }
 }
 
 void ViewSettingsDialog::customEvent( QEvent* e )
@@ -301,6 +329,8 @@ void ViewSettingsDialog::updateViewSettings()
     if ( m_isPublic ) {
         m_columnsEdit->setText( helper.columnNames( cache->viewColumns( cache->defaultView() ) ) );
         m_sortByEdit->setText( helper.sortOrderInfo( cache->viewSortOrder( cache->defaultView() ) ) );
+        if ( m_initialEdit )
+            m_initialEdit->setText( helper.viewName( cache->initialViewId() ) );
     }
 }
 
@@ -354,3 +384,19 @@ void ViewSettingsDialog::listContextMenu( const QPoint& pos )
     if ( menu )
         menu->popup( m_list->viewport()->mapToGlobal( pos ) );
 }
+
+PublicViewSettingsDialog::PublicViewSettingsDialog( int typeId ) : ViewSettingsDialog( typeId, true )
+{
+}
+
+PublicViewSettingsDialog::~PublicViewSettingsDialog()
+{
+}
+
+PersonalViewSettingsDialog::PersonalViewSettingsDialog( int typeId ) : ViewSettingsDialog( typeId, false )
+{
+}
+
+PersonalViewSettingsDialog::~PersonalViewSettingsDialog()
+{
+}
