@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -35,30 +35,24 @@ class QModelIndex;
 class ViewSettingsDialog : public InformationDialog, public XmlUi::Client
 {
     Q_OBJECT
-public:
+protected:
     /**
     * Constructor.
-    * @param parent The parent widget.
     */
-    ViewSettingsDialog( int typeId, bool isPublic, QWidget* parent );
+    ViewSettingsDialog( int typeId, bool isPublic );
 
     /**
     * Destructor.
     */
     ~ViewSettingsDialog();
 
-public:
-    enum ViewSettingsDialogCode
-    {
-        SwitchMode = 2
-    };
-
 protected: // overrides
     void customEvent( QEvent* e );
 
 private slots:
     void modifyOrder();
     void modifyDefaultView();
+    void modifyInitialView();
 
     void addView();
     void cloneView();
@@ -85,9 +79,26 @@ private:
     QLineEdit* m_orderEdit;
     QLineEdit* m_columnsEdit;
     QLineEdit* m_sortByEdit;
+    QLineEdit* m_initialEdit;
 
     QTreeView* m_list;
     ViewsModel* m_model;
 };
 
+class PublicViewSettingsDialog : public ViewSettingsDialog
+{
+    Q_OBJECT
+public:
+    PublicViewSettingsDialog( int typeId );
+    ~PublicViewSettingsDialog();
+};
+
+class PersonalViewSettingsDialog : public ViewSettingsDialog
+{
+    Q_OBJECT
+public:
+    PersonalViewSettingsDialog( int typeId );
+    ~PersonalViewSettingsDialog();
+};
+
 #endif
