@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,8 @@
 #include "data/datamanager.h"
 #include "data/entities.h"
 #include "data/localsettings.h"
+#include "dialogs/dialogmanager.h"
+#include "dialogs/messagebox.h"
 #include "dialogs/userdialogs.h"
 #include "dialogs/finditemdialog.h"
 #include "dialogs/preferencesdialog.h"
@@ -31,7 +33,9 @@
 #include "dialogs/connectioninfodialog.h"
 #include "utils/iconloader.h"
 #include "views/projectsview.h"
+#include "views/summaryview.h"
 #include "views/folderview.h"
+#include "views/globallistview.h"
 #include "views/issueview.h"
 #include "views/startview.h"
 #include "views/viewmanager.h"
@@ -53,10 +57,8 @@
 #include <QMenu>
 #include <QStatusBar>
 #include <QAccessible>
-
-#if defined( HAVE_OPENSSL )
+#include <QDesktopWidget>
 #include <QSslCipher>
-#endif
 
 #if defined( Q_WS_WIN )
 static const int TrayIconSize = 16;
@@ -66,12 +68,17 @@ static const int TrayIconSize = 22;
 
 MainWindow::MainWindow() :
     m_view( NULL ),
+    m_summaryView( NULL ),
     m_folderView( NULL ),
+    m_globalListView( NULL ),
     m_issueView( NULL ),
     m_activeView( NULL ),
+    m_stackedWidget( NULL ),
     m_folderPane( NULL ),
     m_issuePane( NULL ),
+    m_selectedProjectId( 0 ),
     m_selectedFolderId( 0 ),
+    m_selectedTypeId( 0 ),
     m_selectedIssueId( 0 ),
     m_currentViewId( 0 ),
     m_supressFilter( false )
@@ -165,10 +172,13 @@ MainWindow::MainWindow() :
     showStartPage();
 
     LocalSettings* settings = application->applicationSettings();
-    if ( settings->contains( "MainWindowGeometry" ) )
+    if ( settings->contains( "MainWindowGeometry" ) ) {
         restoreGeometry( settings->value( "MainWindowGeometry" ).toByteArray() );
-    else
-        resize( QSize( 750, 500 ) );
+    } else {
+        QRect available = QApplication::desktop()->availableGeometry( this );
+        resize( available.width() * 4 / 5, available.height() * 4 / 5 );
+        setWindowState( Qt::WindowMaximized );
+    }
 
     connect( settings, SIGNAL( settingsChanged() ), this, SLOT( settingsChanged() ) );
 
@@ -209,9 +219,15 @@ MainWindow::~MainWindow()
     delete m_view;
     m_view = NULL;
 
+    delete m_summaryView;
+    m_summaryView = NULL;
+
     delete m_folderView;
     m_folderView = NULL;
 
+    delete m_globalListView;
+    m_globalListView = NULL;
+
     delete m_issueView;
     m_issueView = NULL;
 }
@@ -238,7 +254,7 @@ void MainWindow::reconnect()
 
 void MainWindow::quit()
 {
-    if ( viewManager && !viewManager->queryCloseViews() )
+    if ( !queryCloseConnection() )
         return;
 
     qApp->quit();
@@ -246,10 +262,11 @@ void MainWindow::quit()
 
 void MainWindow::closeConnection()
 {
-    if ( !viewManager->queryCloseViews() )
+    if ( !queryCloseConnection() )
         return;
 
     viewManager->closeAllViews();
+    dialogManager->closeAllDialogs();
 
     storeViewState();
 
@@ -262,9 +279,15 @@ void MainWindow::closeConnection()
     delete m_view;
     m_view = NULL;
 
+    delete m_summaryView;
+    m_summaryView = NULL;
+
     delete m_folderView;
     m_folderView = NULL;
 
+    delete m_globalListView;
+    m_globalListView = NULL;
+
     delete m_issueView;
     m_issueView = NULL;
 
@@ -283,7 +306,9 @@ void MainWindow::closeConnection()
 
     builder()->resumeUpdate();
 
+    m_selectedProjectId = 0;
     m_selectedFolderId = 0;
+    m_selectedTypeId = 0;
     m_selectedIssueId = 0;
 
     showStartPage();
@@ -300,6 +325,22 @@ void MainWindow::closeConnection()
     m_userLabel->hide();
 }
 
+bool MainWindow::queryCloseConnection()
+{
+    if ( commandManager && commandManager->preventClose() ) {
+        MessageBox::warning( this, tr( "Warning" ), tr( "Connection cannot be closed because there are pending commands.\nPlease wait until these commands are completed." ) );
+        return false;
+    }
+
+    if ( viewManager && !viewManager->queryCloseViews() )
+        return false;
+
+    if ( dialogManager && !dialogManager->queryCloseDialogs() )
+        return false;
+
+    return true;
+}
+
 void MainWindow::showStartPage()
 {
     XmlUi::ToolStrip* strip = qobject_cast<XmlUi::ToolStrip*>( menuWidget() );
@@ -351,9 +392,16 @@ void MainWindow::connectionOpened()
 
     horizSplitter->addWidget( m_view->mainWidget() );
 
-    QSplitter* vertSplitter = new QSplitter( Qt::Vertical, horizSplitter );
+    m_stackedWidget = new QStackedWidget( horizSplitter );
 
-    m_folderPane = new PaneWidget( vertSplitter );
+    m_summaryView = new SummaryView( this, m_stackedWidget );
+    viewManager->addView( m_summaryView );
+
+    m_stackedWidget->addWidget( m_summaryView->mainWidget() );
+
+    QSplitter* vertSplitter = new QSplitter( Qt::Vertical, m_stackedWidget );
+
+    m_folderPane = new PaneWidget( vertSplitter ); // TODO: change API of the pane widget to allow adding more widgets
     m_folderPane->setPlaceholderText( tr( "No folder selected" ) );
     vertSplitter->addWidget( m_folderPane );
 
@@ -361,7 +409,13 @@ void MainWindow::connectionOpened()
     m_folderView->mainWidget()->setFocusPolicy( Qt::ClickFocus );
     viewManager->addView( m_folderView );
 
-    m_folderPane->setMainWidget( m_folderView->mainWidget() );
+    m_folderPane->addWidget( m_folderView->mainWidget() );
+
+    m_globalListView = new GlobalListView( this, m_folderPane );
+    m_globalListView->mainWidget()->setFocusPolicy( Qt::ClickFocus );
+    viewManager->addView( m_globalListView );
+
+    m_folderPane->addWidget( m_globalListView->mainWidget() );
 
     m_issuePane = new PaneWidget( vertSplitter );
     m_issuePane->setPlaceholderText( tr( "No issue selected" ) );
@@ -371,12 +425,16 @@ void MainWindow::connectionOpened()
     m_issueView->mainWidget()->setFocusPolicy( Qt::ClickFocus );
     viewManager->addView( m_issueView );
 
-    m_issuePane->setMainWidget( m_issueView->mainWidget() );
+    m_issuePane->addWidget( m_issueView->mainWidget() );
 
-    horizSplitter->addWidget( vertSplitter );
+    m_stackedWidget->addWidget( vertSplitter );
+
+    horizSplitter->addWidget( m_stackedWidget );
 
     setCentralWidget( horizSplitter );
     restoreViewState();
+
+    m_stackedWidget->setCurrentIndex( 1 );
     horizSplitter->show();
 
     updateActions( true );
@@ -386,7 +444,7 @@ void MainWindow::connectionOpened()
     connect( m_view, SIGNAL( statusChanged( const QPixmap&, const QString&, int ) ), this, SLOT( showStatus( const QPixmap&, const QString&, int ) ) );
     connect( m_view, SIGNAL( summaryChanged( const QPixmap&, const QString& ) ), this, SLOT( showSummary( const QPixmap&, const QString& ) ) );
 
-#if defined( HAVE_OPENSSL )
+#if !defined( QT_NO_OPENSSL )
     QSslCipher cipher = commandManager->sslConfiguration().sessionCipher();
     if ( !cipher.isNull() ) {
         m_encryptionLabel->setPixmap( IconLoader::pixmap( "edit-access" ) );
@@ -414,23 +472,35 @@ void MainWindow::connectionOpened()
     m_view->initialUpdate();
 
     connect( m_folderView, SIGNAL( enabledChanged( bool ) ), this, SLOT( folderEnabledChanged( bool ) ) );
+    connect( m_globalListView, SIGNAL( enabledChanged( bool ) ), this, SLOT( globalListEnabledChanged( bool ) ) );
     connect( m_issueView, SIGNAL( enabledChanged( bool ) ), this, SLOT( issueEnabledChanged( bool ) ) );
 
     connect( m_folderView, SIGNAL( captionChanged( const QString& ) ), this, SLOT( captionChanged( const QString& ) ) );
+    connect( m_globalListView, SIGNAL( captionChanged( const QString& ) ), this, SLOT( captionChanged( const QString& ) ) );
+    connect( m_summaryView, SIGNAL( captionChanged( const QString& ) ), this, SLOT( captionChanged( const QString& ) ) );
 
-    connect( m_view, SIGNAL( selectionChanged( int, int ) ), this, SLOT( selectionChanged( int, int ) ) );
+    connect( m_view, SIGNAL( selectionChanged( int, int, int ) ), this, SLOT( selectionChanged( int, int, int ) ) );
+    connect( m_view, SIGNAL( projectSelected( int ) ), this, SLOT( projectSelected( int ) ) );
 
     connect( m_folderView, SIGNAL( selectedIssueChanged( int ) ), this, SLOT( selectedIssueChanged( int ) ) );
     connect( m_folderView, SIGNAL( currentViewChanged( int ) ), this, SLOT( currentViewChanged( int ) ) );
+    connect( m_globalListView, SIGNAL( selectedIssueChanged( int ) ), this, SLOT( selectedIssueChanged( int ) ) );
+    connect( m_globalListView, SIGNAL( currentViewChanged( int ) ), this, SLOT( currentViewChanged( int ) ) );
 
     connect( m_issueView, SIGNAL( issueActivated( int, int ) ), this, SLOT( gotoIssue( int, int ) ), Qt::QueuedConnection );
     connect( m_folderView, SIGNAL( issueActivated( int, int ) ), this, SLOT( gotoIssue( int, int ) ), Qt::QueuedConnection );
+    connect( m_globalListView, SIGNAL( issueActivated( int, int ) ), this, SLOT( gotoIssue( int, int ) ), Qt::QueuedConnection );
+    connect( m_summaryView, SIGNAL( issueActivated( int, int ) ), this, SLOT( gotoIssue( int, int ) ), Qt::QueuedConnection );
+
     connect( m_folderView, SIGNAL( itemActivated( int ) ), this, SLOT( gotoItem( int ) ) );
+    connect( m_globalListView, SIGNAL( itemActivated( int ) ), this, SLOT( gotoItem( int ) ) );
 
     folderEnabledChanged( m_folderView->isEnabled() );
+    globalListEnabledChanged( m_folderView->isEnabled() );
     issueEnabledChanged( m_issueView->isEnabled() );
 
     m_folderView->initialUpdate();
+    m_globalListView->initialUpdate();
     m_issueView->initialUpdate();
 
     m_view->mainWidget()->setFocus();
@@ -439,10 +509,23 @@ void MainWindow::connectionOpened()
 void MainWindow::restoreViewState()
 {
     LocalSettings* settings = application->applicationSettings();
+
     if ( QSplitter* horizSplitter = qobject_cast<QSplitter*>( centralWidget() ) ) {
-        horizSplitter->restoreState( settings->value( "MainWindowHSplit" ).toByteArray() );
-        if ( QSplitter* vertSplitter = qobject_cast<QSplitter*>( horizSplitter->widget( 1 ) ) )
-            vertSplitter->restoreState( settings->value( "MainWindowVSplit" ).toByteArray() );
+        QByteArray horizData = settings->value( "MainWindowHSplit" ).toByteArray();
+
+        if ( !horizData.isEmpty() )
+            horizSplitter->restoreState( horizData );
+        else
+            horizSplitter->setSizes( QList<int>() << 350 << width() - 350 );
+
+        if ( QSplitter* vertSplitter = qobject_cast<QSplitter*>( m_stackedWidget->widget( 1 ) ) ) {
+            QByteArray vertData = settings->value( "MainWindowVSplit" ).toByteArray();
+
+            if ( !vertData.isEmpty() )
+                vertSplitter->restoreState( vertData );
+            else
+                vertSplitter->setSizes( QList<int>() << height() / 3 << height() * 2 / 3 );
+        }
     }
 }
 
@@ -451,7 +534,7 @@ void MainWindow::storeViewState()
     LocalSettings* settings = application->applicationSettings();
     if ( QSplitter* horizSplitter = qobject_cast<QSplitter*>( centralWidget() ) ) {
         settings->setValue( "MainWindowHSplit", horizSplitter->saveState() );
-        if ( QSplitter* vertSplitter = qobject_cast<QSplitter*>( horizSplitter->widget( 1 ) ) )
+        if ( QSplitter* vertSplitter = qobject_cast<QSplitter*>( m_stackedWidget->widget( 1 ) ) )
             settings->setValue( "MainWindowVSplit", vertSplitter->saveState() );
     }
 }
@@ -495,8 +578,12 @@ bool MainWindow::eventFilter( QObject* object, QEvent* e )
         View* view = NULL;
         if ( m_view->mainWidget() == widget )
             view = m_view;
+        else if ( m_summaryView && m_summaryView->mainWidget() == widget )
+            view = m_summaryView;
         else if ( m_folderView && m_folderView->mainWidget() == widget )
             view = m_folderView;
+        else if ( m_globalListView && m_globalListView->mainWidget() == widget )
+            view = m_globalListView;
         else if ( m_issueView && m_issueView->mainWidget() == widget )
             view = m_issueView;
 
@@ -542,7 +629,10 @@ void MainWindow::setActiveView( View* view )
 
 void MainWindow::folderEnabledChanged( bool enabled )
 {
-    m_folderPane->setMainWidgetVisible( enabled );
+    if ( enabled )
+        m_folderPane->setCurrentWidget( m_folderView->mainWidget() );
+    else if ( !m_globalListView->isEnabled() )
+        m_folderPane->showPlaceholder();
 
     if ( m_folderView == m_activeView ) {
         if ( enabled )
@@ -552,9 +642,27 @@ void MainWindow::folderEnabledChanged( bool enabled )
     }
 }
 
+void MainWindow::globalListEnabledChanged( bool enabled )
+{
+    if ( enabled )
+        m_folderPane->setCurrentWidget( m_globalListView->mainWidget() );
+    else if ( !m_folderView->isEnabled() )
+        m_folderPane->showPlaceholder();
+
+    if ( m_globalListView == m_activeView ) {
+        if ( enabled )
+           builder()->addClient( m_globalListView );
+        else
+            builder()->removeClient( m_globalListView );
+    }
+}
+
 void MainWindow::issueEnabledChanged( bool enabled )
 {
-    m_issuePane->setMainWidgetVisible( enabled );
+    if ( enabled )
+        m_issuePane->setCurrentWidget( m_issueView->mainWidget() );
+    else
+        m_issuePane->showPlaceholder();
 
     if ( m_issueView == m_activeView ) {
         if ( enabled )
@@ -564,15 +672,28 @@ void MainWindow::issueEnabledChanged( bool enabled )
     }
 }
 
-void MainWindow::selectionChanged( int folderId, int viewId )
+void MainWindow::selectionChanged( int folderId, int typeId, int viewId )
 {
-    if ( !m_supressFilter && ( m_selectedFolderId != folderId || m_currentViewId != viewId ) ) {
+    if ( !m_supressFilter && ( m_selectedFolderId != folderId || m_selectedTypeId != typeId || m_currentViewId != viewId || m_selectedProjectId != 0 ) ) {
+        m_selectedProjectId = 0;
         m_selectedFolderId = folderId;
+        m_selectedTypeId = typeId;
         m_currentViewId = viewId;
         m_selectionTimer->start();
     }
 }
 
+void MainWindow::projectSelected( int projectId )
+{
+    if ( m_selectedProjectId != projectId ) {
+        m_selectedProjectId = projectId;
+        m_selectedFolderId = 0;
+        m_selectedTypeId = 0;
+        m_currentViewId = 0;
+        m_selectionTimer->start();
+    }
+}
+
 void MainWindow::selectedIssueChanged( int issueId )
 {
     if ( m_selectedIssueId != issueId ) {
@@ -591,21 +712,45 @@ void MainWindow::currentViewChanged( int viewId )
 
 void MainWindow::updateSelection()
 {
-    m_supressFilter = true;
-    m_view->setSelection( m_selectedFolderId, m_currentViewId );
-    m_supressFilter = false;
+    if ( m_selectedProjectId != 0 ) {
+        m_stackedWidget->setCurrentIndex( 0 );
+    } else {
+        m_stackedWidget->setCurrentIndex( 1 );
 
-    if ( m_folderView->id() != m_selectedFolderId ) {
+        m_supressFilter = true;
+        m_view->setSelection( m_selectedFolderId, m_selectedTypeId, m_currentViewId );
+        m_supressFilter = false;
+    }
+
+    if ( m_summaryView->id() != m_selectedProjectId ) {
+        m_summaryView->setId( m_selectedProjectId );
+        m_summaryView->initialUpdate();
+    }
+
+    if ( m_folderView->id() != m_selectedFolderId || m_globalListView->id() != m_selectedTypeId ) {
         m_supressFilter = true;
 
-        m_folderView->setId( m_selectedFolderId );
-        m_folderView->initialUpdate();
+        if ( m_globalListView->id() != 0 && m_selectedTypeId == 0 ) {
+            m_globalListView->setId( m_selectedTypeId );
+            m_globalListView->initialUpdate();
+        }
+
+        if ( m_folderView->id() != m_selectedFolderId ) {
+            m_folderView->setId( m_selectedFolderId );
+            m_folderView->initialUpdate();
+        }
+
+        if ( m_globalListView->id() != m_selectedTypeId ) {
+            m_globalListView->setId( m_selectedTypeId );
+            m_globalListView->initialUpdate();
+        }
 
         m_supressFilter = false;
         m_selectedIssueId = 0;
     }
 
     m_folderView->setCurrentViewId( m_currentViewId );
+    m_globalListView->setCurrentViewId( m_currentViewId );
 
     if ( m_issueView->id() != m_selectedIssueId ) {
         m_issueView->setId( m_selectedIssueId );
@@ -665,20 +810,24 @@ void MainWindow::gotoIssue( int issueId, int itemId )
     IssueEntity issue = IssueEntity::find( issueId );
 
     if ( issue.isValid() ) {
-        int folderId = issue.folderId();
+        if ( m_selectedTypeId == issue.folder().typeId() ) {
+            m_globalListView->gotoIssue( issueId, itemId );
+        } else {
+            int folderId = issue.folderId();
 
-        if ( folderId != m_folderView->id() ) {
-            m_selectedFolderId = folderId;
-            m_currentViewId = 0;
-            m_view->setSelection( folderId, 0 );
-            m_folderView->setId( folderId );
-            m_folderView->initialUpdate();
+            if ( folderId != m_folderView->id() ) {
+                selectionChanged( folderId, 0, 0 );
+                updateSelection();
+            }
+
+            if ( issueId != m_issueView->id() )
+                m_folderView->gotoIssue( issueId, itemId );
+            else
+                m_issueView->gotoItem( itemId );
         }
 
-        if ( issueId != m_issueView->id() )
-            m_folderView->gotoIssue( issueId, itemId );
-        else
-            m_issueView->gotoItem( itemId );
+        if ( m_trayIcon->isVisible() )
+            showFromTray( false );
     } else {
         viewManager->openIssueView( issueId, itemId );
     }
@@ -704,33 +853,48 @@ void MainWindow::userPreferences()
 
 void MainWindow::trayIconActivated( QSystemTrayIcon::ActivationReason reason )
 {
-    if ( reason == QSystemTrayIcon::Trigger ) {
-        if ( isMinimized() ) {
-            // hide needed when changing desktop
-            hide();
-            showNormal();
-            raise();
-            activateWindow();
-        } else if ( !isVisible() ) {
-            show();
-            raise();
-            activateWindow();
-        } else {
-            hide();
-        }
-    }
+    if ( reason == QSystemTrayIcon::Trigger )
+        showFromTray( true );
 
     // workaround for [QTBUG-14807]
     if ( reason == QSystemTrayIcon::Context )
         m_trayIcon->contextMenu()->activateWindow();
 }
 
+void MainWindow::showFromTray( bool toggle )
+{
+    if ( isMinimized() ) {
+#if defined( Q_WS_WIN )
+        setWindowState( windowState() & ~Qt::WindowMinimized );
+#else
+        // hide needed when changing desktop
+        hide();
+        showNormal();
+#endif
+        raise();
+        activateWindow();
+    } else if ( !isVisible() ) {
+        show();
+        raise();
+        activateWindow();
+    } else if ( !toggle ) {
+        raise();
+        activateWindow();
+    } else {
+        hide();
+    }
+}
+
 void MainWindow::captionChanged( const QString& /*caption*/ )
 {
     QString caption = m_view->caption();
 
-    if ( m_folderView->isEnabled() )
+    if ( m_summaryView->isEnabled() )
+        caption = QString( "%1 - %2" ).arg( m_summaryView->caption(), caption );
+    else if ( m_folderView->isEnabled() )
         caption = QString( "%1 - %2" ).arg( m_folderView->caption(), caption );
+    else if ( m_globalListView->isEnabled() )
+        caption = QString( "%1 - %2" ).arg( m_globalListView->caption(), caption );
 
     setWindowTitle( tr( "%1 - WebIssues Desktop Client" ).arg( caption ) );
 }
@@ -740,7 +904,7 @@ void MainWindow::builderReset()
     m_trayIcon->setContextMenu( builder()->contextMenu( "menuTray" ) );
 }
 
-void MainWindow::showStatus( const QPixmap& pixmap, const QString& text, int icon /*= 0*/ )
+void MainWindow::showStatus( const QPixmap& pixmap, const QString& text, int icon )
 {
     m_statusLabel->setPixmap( pixmap );
     m_statusLabel->setText( text );
