@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -27,8 +27,9 @@
 #include <QPixmap>
 #include <QFont>
 
-AlertsModel::AlertsModel( int folderId, QObject* parent ) : BaseModel( parent ),
-    m_folderId( folderId )
+AlertsModel::AlertsModel( QObject* parent ) : BaseModel( parent ),
+    m_folderId( 0 ),
+    m_typeId( 0 )
 {
     appendModel( new QSqlQueryModel( this ) );
 
@@ -38,6 +39,7 @@ AlertsModel::AlertsModel( int folderId, QObject* parent ) : BaseModel( parent ),
     columnMapping << 2 << 3 << 4 << 5;
     if ( emailEnabled )
         columnMapping << 6;
+    columnMapping << 7;
     setColumnMapping( 0, columnMapping );
 
     setHeaderData( 0, Qt::Horizontal, tr( "Name" ) );
@@ -46,6 +48,7 @@ AlertsModel::AlertsModel( int folderId, QObject* parent ) : BaseModel( parent ),
     setHeaderData( 3, Qt::Horizontal, tr( "Modified" ) );
     if ( emailEnabled )
         setHeaderData( 4, Qt::Horizontal, tr( "Email Type" ) );
+    setHeaderData( 5, Qt::Horizontal, tr( "Is Public" ) );
 
     refresh();
 }
@@ -54,7 +57,23 @@ AlertsModel::~AlertsModel()
 {
 }
 
-QVariant AlertsModel::data( const QModelIndex& index, int role /*= Qt::DisplayRole*/ ) const
+void AlertsModel::initializeFolder( int folderId )
+{
+    m_folderId = folderId;
+    m_typeId = 0;
+
+    refresh();
+}
+
+void AlertsModel::initializeGlobalList( int typeId )
+{
+    m_typeId = typeId;
+    m_folderId = 0;
+
+    refresh();
+}
+
+QVariant AlertsModel::data( const QModelIndex& index, int role ) const
 {
     int level = levelOf( index );
     int row = mappedRow( index );
@@ -67,7 +86,7 @@ QVariant AlertsModel::data( const QModelIndex& index, int role /*= Qt::DisplayRo
             return ( viewId != 0 ) ? value.toString() : tr( "All Issues" );
         }
 
-        if ( index.column() == 4 ) {
+        if ( mappedColumn( index ) == 6 ) {
             int email = value.toInt();
             if ( email == ImmediateNotificationEmail )
                 return tr( "Immediate notifications" );
@@ -78,17 +97,25 @@ QVariant AlertsModel::data( const QModelIndex& index, int role /*= Qt::DisplayRo
             return tr( "None" );
         }
 
+        if ( mappedColumn( index ) == 7 )
+            return value.toBool() ? tr( "Yes" ) : tr( "No" );
+
         return value;
     }
 
     if ( role == Qt::DecorationRole && index.column() == 0 ) {
+        QString name = "alert";
         int unread = rawData( level, row, 4 ).toInt();
-        if ( unread > 0 )
-            return IconLoader::pixmap( "alert-unread" );
-        int modified = rawData( level, row, 5 ).toInt();
-        if ( modified > 0 )
-            return IconLoader::pixmap( "alert-modified" );
-        return IconLoader::pixmap( "alert" );
+        if ( unread > 0 ) {
+            name = "alert-unread";
+        } else {
+            int modified = rawData( level, row, 5 ).toInt();
+            if ( modified > 0 )
+                name = "alert-modified";
+        }
+        if ( rawData( level, row, 7 ).toBool() )
+            return IconLoader::overlayedPixmap( name, "overlay-public" );
+        return IconLoader::pixmap( name );
     }
 
     if ( role == Qt::FontRole && index.column() >= 1 && index.column() <= 3 ) {
@@ -105,16 +132,22 @@ QVariant AlertsModel::data( const QModelIndex& index, int role /*= Qt::DisplayRo
 
 void AlertsModel::refresh()
 {
-    QString query = "SELECT a.alert_id, v.view_id, v.view_name, ac.total_count, ac.new_count, ac.modified_count, a.alert_email"
+    QString query = "SELECT a.alert_id, v.view_id, v.view_name, ac.total_count, ac.new_count, ac.modified_count, a.alert_email, a.is_public"
         " FROM alerts AS a"
         " LEFT OUTER JOIN views AS v ON v.view_id = a.view_id"
-        " LEFT OUTER JOIN alerts_cache AS ac ON ac.alert_id = a.alert_id"
-        " WHERE a.folder_id = ?"
-        " ORDER BY v.view_name COLLATE LOCALE ASC";
+        " LEFT OUTER JOIN alerts_cache AS ac ON ac.alert_id = a.alert_id";
+    if ( m_folderId != 0 )
+        query += " WHERE a.folder_id = ?";
+    else if ( m_typeId != 0 )
+        query += " WHERE a.type_id = ?";
+    query += " ORDER BY v.view_name COLLATE LOCALE ASC";
 
     QSqlQuery sqlQuery;
     sqlQuery.prepare( query );
-    sqlQuery.addBindValue( m_folderId );
+    if ( m_folderId != 0 )
+        sqlQuery.addBindValue( m_folderId );
+    else if ( m_typeId != 0 )
+        sqlQuery.addBindValue( m_typeId );
     sqlQuery.exec();
 
     modelAt( 0 )->setQuery( sqlQuery );
