@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -31,16 +31,26 @@ class AlertsModel : public BaseModel
 public:
     /**
     * Constructor.
-    * @param folderId Identifier of the folder.
     * @param parent The parent object.
     */
-    AlertsModel( int folderId, QObject* parent );
+    AlertsModel( QObject* parent );
 
     /**
     * Destructor.
     */
     ~AlertsModel();
 
+public:
+    /**
+    * Set the folder containing alerts.
+    */
+    void initializeFolder( int folderId );
+
+    /**
+    * Set the type of the global list of alerts.
+    */
+    void initializeGlobalList( int typeId );
+
 public: // overrides
     QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const;
 
@@ -52,6 +62,7 @@ private:
 
 private:
     int m_folderId;
+    int m_typeId;
 };
 
 #endif
