@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,11 +20,11 @@
 #include "foldermodel.h"
 
 #include "data/datamanager.h"
+#include "data/entities.h"
 #include "data/issuetypecache.h"
 #include "models/querygenerator.h"
 #include "models/issuedetailsgenerator.h"
 #include "utils/formatter.h"
-#include "utils/textwriter.h"
 #include "utils/viewsettingshelper.h"
 #include "utils/iconloader.h"
 
@@ -34,8 +34,8 @@
 #include <QTextDocument>
 #include <QPixmap>
 
-FolderModel::FolderModel( int folderId, QObject* parent ) : BaseModel( parent ),
-    m_folderId( folderId ),
+FolderModel::FolderModel( QObject* parent ) : BaseModel( parent ),
+    m_folderId( 0 ),
     m_viewId( 0 ),
     m_typeId( 0 ),
     m_forceColumns( false ),
@@ -48,6 +48,20 @@ FolderModel::~FolderModel()
 {
 }
 
+void FolderModel::initializeFolder( int folderId )
+{
+    m_folderId = folderId;
+    m_viewId = 0;
+    m_typeId = 0;
+}
+
+void FolderModel::initializeGlobalList( int typeId )
+{
+    m_typeId = typeId;
+    m_folderId = 0;
+    m_viewId = 0;
+}
+
 void FolderModel::setView( int viewId, bool resort )
 {
     m_viewId = viewId;
@@ -73,7 +87,7 @@ void FolderModel::setSearchText( int column, const QString& text )
     generateQueries( false );
 }
 
-QVariant FolderModel::data( const QModelIndex& index, int role /*= Qt::DisplayRole*/ ) const
+QVariant FolderModel::data( const QModelIndex& index, int role ) const
 {
     int level = levelOf( index );
     int row = mappedRow( index );
@@ -97,6 +111,8 @@ QVariant FolderModel::data( const QModelIndex& index, int role /*= Qt::DisplayRo
                 Formatter formatter;
                 return formatter.formatDateTime( dateTime, true );
             }
+            case Column_Location:
+                return rawData( level, row, m_columns.count() + 3 ).toString() + QString::fromUtf8( " — " ) + value.toString();
             default:
                 if ( !value.isNull() ) {
                     int column = m_columns.value( index.column() );
@@ -111,13 +127,27 @@ QVariant FolderModel::data( const QModelIndex& index, int role /*= Qt::DisplayRo
     }
 
     if ( role == Qt::DecorationRole && index.column() == 1 ) {
+        QString name, overlay;
         int readId = rawData( level, row, 2, Qt::DisplayRole ).toInt();
-        if ( readId == 0 )
-            return IconLoader::pixmap( "issue-unread" );
-        int stampId = rawData( level, row, 1, Qt::DisplayRole ).toInt();
-        if ( readId < stampId )
-            return IconLoader::pixmap( "issue-modified" );
-        return IconLoader::pixmap( "issue" );
+        if ( readId == 0 ) {
+            name = "issue-unread";
+        } else {
+            int stampId = rawData( level, row, 1, Qt::DisplayRole ).toInt();
+            if ( readId < stampId )
+                name = "issue-modified";
+            else
+                name = "issue";
+        }
+        bool emailEnabled = dataManager->setting( "email_enabled" ).toInt();
+        if ( emailEnabled ) {
+            int subscriptionId = rawData( level, row, 3, Qt::DisplayRole ).toInt();
+            if ( subscriptionId != 0 )
+                overlay = "overlay-subscribed";
+        }
+        if ( !overlay.isEmpty() )
+            return IconLoader::overlayedPixmap( name, overlay );
+        else
+            return IconLoader::pixmap( name );
     }
 
     if ( role == Qt::FontRole ) {
@@ -137,25 +167,16 @@ QVariant FolderModel::data( const QModelIndex& index, int role /*= Qt::DisplayRo
         }
     }
 
-    if ( role == Qt::ToolTipRole ) {
-        int issueId = rowId( index );
-
-        QTextDocument document;
-        TextWriter writer( &document, TextWriter::UseSmallHeaders );
-
-        IssueDetailsGenerator generator;
-        generator.setIssue( issueId, IssueDetailsGenerator::NoHistory );
-        generator.write( &writer );
-
-        return document.toHtml( "UTF-8" );
-    }
-
     return QVariant();
 }
 
 void FolderModel::generateQueries( bool resort )
 {
-    QueryGenerator generator( m_folderId, m_viewId );
+    QueryGenerator generator;
+    if ( m_folderId != 0 )
+        generator.initializeFolder( m_folderId, m_viewId );
+    else
+        generator.initializeGlobalList( m_typeId, m_viewId );
 
     if ( !m_searchText.isEmpty() )
         generator.setSearchText( m_searchColumn, m_searchText );
@@ -186,10 +207,18 @@ void FolderModel::generateQueries( bool resort )
 void FolderModel::updateQueries()
 {
     if ( !m_query.isEmpty() ) {
-        QString column = m_sortColumns.value( sortColumn() );
+        QStringList columns = m_sortColumns.value( sortColumn() );
         QString order = ( sortOrder() == Qt::AscendingOrder ) ? "ASC" : "DESC";
 
-        m_order = QString( "%1 %2" ).arg( column, order );
+        QStringList parts;
+        foreach ( const QString& part, columns )
+            parts.append( QString( "%1 %2" ).arg( part, order ) );
+
+        int id = m_columns.value( sortColumn() );
+        if ( id != Column_ID && id != Column_CreatedDate )
+            parts.append( "i.issue_id ASC" );
+
+        m_order = parts.join( ", " );
 
         refresh();
     }
@@ -217,8 +246,13 @@ void FolderModel::updateEvent( UpdateEvent* e )
     switch ( e->unit() ) {
         case UpdateEvent::Folder:
         case UpdateEvent::IssueList:
-            if ( e->id() == m_folderId )
+            if ( m_folderId == 0 ) {
+                FolderEntity folder = FolderEntity::find( e->id() );
+                if ( folder.typeId() == m_typeId )
+                    refresh();
+            } else if ( e->id() == m_folderId ) {
                 refresh();
+            }
             break;
 
         case UpdateEvent::Users:
