@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@ enum Column
     Column_CreatedBy,
     Column_ModifiedDate,
     Column_ModifiedBy,
+    Column_Location,
 
     /**
     * The value added to attribute identifier to create user defined columns.
@@ -43,7 +44,7 @@ enum Column
 };
 
 /**
-* Model for a list of issues in a folder.
+* Model for a list of issues in a folder or global list.
 */
 class FolderModel : public BaseModel
 {
@@ -51,10 +52,9 @@ class FolderModel : public BaseModel
 public:
     /**
     * Constructor.
-    * @param folderId Identifier of the folder.
     * @param parent The parent object.
     */
-    FolderModel( int folderId, QObject* parent );
+    FolderModel( QObject* parent );
 
     /**
     * Destructor.
@@ -62,6 +62,16 @@ public:
     ~FolderModel();
 
 public:
+    /**
+    * Set the folder containing issues.
+    */
+    void initializeFolder( int folderId );
+
+    /**
+    * Set the type of the global list of issues.
+    */
+    void initializeGlobalList( int typeId );
+
     /**
     * Fill the model based on the view with given identifier or 0 if
     * the default view should be used.
@@ -111,7 +121,7 @@ private:
     QList<QVariant> m_arguments;
 
     QList<int> m_columns;
-    QStringList m_sortColumns;
+    QList<QStringList> m_sortColumns;
 };
 
 #endif
