@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,15 +20,18 @@
 #ifndef ISSUEDETAILSGENERATOR_H
 #define ISSUEDETAILSGENERATOR_H
 
-#include "utils/textwithlinks.h"
+#include "utils/htmltext.h"
 
 #include <QObject>
 #include <QList>
 
-class TextWriter;
+class HtmlWriter;
 class IssueEntity;
 class ChangeEntity;
 class FileEntity;
+class ValueEntity;
+class DescriptionEntity;
+class CommentEntity;
 
 /**
 * Class providing issue details to the TextWriter.
@@ -64,40 +67,46 @@ public:
     /**
     * Set the issue to provide details for.
     * @param issueId Idenitifier of the issue.
+    * @param description @c true if the description should be included.
     * @param history Type of issue history to be included.
     */
-    void setIssue( int issueId, History history );
+    void setIssue( int issueId, bool description, History history );
 
     /**
     * Output the issue details to the writer.
     * @param writer The text document writer to output the details to.
     * @param flags Optional flags affecting extracting of links.
     */
-    void write( TextWriter* writer, TextWithLinks::Flags flags = 0 );
+    void write( HtmlWriter* writer, HtmlText::Flags flags = 0 );
 
     int commentsCount() const { return m_commentsCount; }
 
     int filesCount() const { return m_filesCount; }
 
 private:
-    void writeProperties( TextWriter* writer, const IssueEntity& issue );
-    void writeAttributes( TextWriter* writer, const IssueEntity& issue, TextWithLinks::Flags flags );
-    void writeHistory( TextWriter* writer, const IssueEntity& issue, TextWithLinks::Flags flags );
+    void writeProperties( HtmlWriter* writer, const IssueEntity& issue );
+    void writeAttributes( HtmlWriter* writer, const QList<ValueEntity>& values, HtmlText::Flags flags );
+    void writeHistory( HtmlWriter* writer, const IssueEntity& issue, HtmlText::Flags flags );
 
     QString formatStamp( const ChangeEntity& change );
 
-    TextWithLinks formatChange( const ChangeEntity& change, TextWithLinks::Flags flags );
-    TextWithLinks formatFile( const FileEntity& file, TextWithLinks::Flags flags );
+    HtmlText formatChange( const ChangeEntity& change, HtmlText::Flags flags );
+    HtmlText formatFile( const FileEntity& file, HtmlText::Flags flags );
 
-    TextWithLinks historyLinks( TextWithLinks::Flags flags );
+    HtmlText historyLinks( HtmlText::Flags flags );
 
-    bool checkChangeLinks( const ChangeEntity& change );
-    TextWithLinks changeLinks( const ChangeEntity& change, TextWithLinks::Flags flags );
+    HtmlText descriptionLinks( const DescriptionEntity& description, HtmlText::Flags flags );
+    HtmlText changeLinks( const ChangeEntity& change, HtmlText::Flags flags );
+
+    HtmlText descriptionText( const DescriptionEntity& description, HtmlText::Flags flags );
+    HtmlText commentText( const CommentEntity& comment, HtmlText::Flags flags );
 
 private:
     int m_issueId;
+    bool m_description;
     History m_history;
 
+    bool m_isOwner;
     bool m_isAdmin;
 
     int m_commentsCount;
