@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ MembersModel::~MembersModel()
 {
 }
 
-QVariant MembersModel::data( const QModelIndex& index, int role /*= Qt::DisplayRole*/ ) const
+QVariant MembersModel::data( const QModelIndex& index, int role ) const
 {
     int level = levelOf( index );
     int row = mappedRow( index );
@@ -83,7 +83,7 @@ void MembersModel::updateQueries()
             break;
 
         case 1:
-            m_order = QString( "user_access %1" ).arg( order );
+            m_order = QString( "project_access %1" ).arg( order );
             break;
     }
 
