@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -40,6 +40,17 @@ public:
     */
     ~ProjectsModel();
 
+public:
+    enum Level
+    {
+        AllProjects,
+        Types,
+        GlobalAlerts,
+        Projects,
+        Folders,
+        Alerts
+    };
+
 public: // overrides
     QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const;
 
@@ -52,6 +63,7 @@ private:
     void refresh();
 
 private:
+    QString m_typesOrder;
     QString m_projectsOrder;
     QString m_foldersOrder;
     QString m_alertsOrder;
