@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -28,29 +28,31 @@
 #include <QSqlQuery>
 #include <QDateTime>
 
-QueryGenerator::QueryGenerator( int folderId, int viewId ) :
-    m_folderId( folderId ),
+QueryGenerator::QueryGenerator() :
+    m_folderId( 0 ),
     m_typeId( 0 ),
+    m_viewId( 0 ),
     m_searchColumn( -1 ),
     m_sortColumn( -1 ),
     m_sortOrder( Qt::AscendingOrder ),
     m_valid( false )
 {
-    QSqlQuery sqlQuery;
-    if ( viewId != 0 ) {
-        sqlQuery.prepare( "SELECT f.type_id, v.view_def"
-            " FROM folders AS f"
-            " JOIN views AS v ON v.type_id = f.type_id"
-            " WHERE f.folder_id = ? AND v.view_id = ?" );
-        sqlQuery.addBindValue( folderId );
-        sqlQuery.addBindValue( viewId );
-    } else {
-        sqlQuery.prepare( "SELECT f.type_id"
-            " FROM folders AS f"
-            " WHERE f.folder_id = ?" );
-        sqlQuery.addBindValue( folderId );
-    }
+}
 
+QueryGenerator::~QueryGenerator()
+{
+}
+
+void QueryGenerator::initializeFolder( int folderId, int viewId )
+{
+    m_folderId = folderId;
+    m_viewId = viewId;
+
+    QSqlQuery sqlQuery;
+    sqlQuery.prepare( "SELECT f.type_id"
+        " FROM folders AS f"
+        " WHERE f.folder_id = ?" );
+    sqlQuery.addBindValue( folderId );
     sqlQuery.exec();
 
     if ( !sqlQuery.next() )
@@ -58,15 +60,41 @@ QueryGenerator::QueryGenerator( int folderId, int viewId ) :
 
     m_typeId = sqlQuery.value( 0 ).toInt();
 
+    initializeCommon( false );
+}
+
+void QueryGenerator::initializeGlobalList( int typeId, int viewId )
+{
+    m_typeId = typeId;
+    m_viewId = viewId;
+
+    initializeCommon( true );
+}
+
+void QueryGenerator::initializeCommon( bool withLocation )
+{
     IssueTypeCache* cache = dataManager->issueTypeCache( m_typeId );
 
     DefinitionInfo info;
-    if ( viewId != 0 )
-        info = DefinitionInfo::fromString( sqlQuery.value( 1 ).toString() );
-    else
-        info = cache->defaultView();
 
-    m_columns = cache->viewColumns( info );
+    if ( m_viewId != 0 ) {
+        QSqlQuery sqlQuery;
+        sqlQuery.prepare( "SELECT v.view_def"
+            " FROM views AS v"
+            " WHERE v.view_id = ? AND v.type_id = ?" );
+        sqlQuery.addBindValue( m_viewId );
+        sqlQuery.addBindValue( m_typeId );
+        sqlQuery.exec();
+
+        if ( !sqlQuery.next() )
+            return;
+
+        info = DefinitionInfo::fromString( sqlQuery.value( 0 ).toString() );
+    } else {
+        info = cache->defaultView();
+    }
+
+    m_columns = cache->viewColumns( info, withLocation );
     m_filters = cache->viewFilters( info );
 
     QPair<int, Qt::SortOrder> order = cache->viewSortOrder( info );
@@ -74,10 +102,6 @@ QueryGenerator::QueryGenerator( int folderId, int viewId ) :
     m_sortOrder = order.second;
 }
 
-QueryGenerator::~QueryGenerator()
-{
-}
-
 void QueryGenerator::setSearchText( int column, const QString& text )
 {
     m_searchColumn = column;
@@ -116,6 +140,7 @@ QString QueryGenerator::generateSelect( bool allColumns )
     result.append( "i.issue_id" );
     result.append( "i.stamp_id" );
     result.append( "s.read_id" );
+    result.append( "s.subscription_id" );
 
     if ( allColumns ) {
         foreach ( int column, m_columns ) {
@@ -137,6 +162,9 @@ QString QueryGenerator::generateSelect( bool allColumns )
                 case Column_ModifiedBy:
                     result.append( "um.user_name" );
                     break;
+                case Column_Location:
+                    result.append( "f.folder_name" );
+                    break;
                 default:
                     if ( column > Column_UserDefined )
                         result.append( QString( "a%1.attr_value" ).arg( column - Column_UserDefined ) );
@@ -145,6 +173,9 @@ QString QueryGenerator::generateSelect( bool allColumns )
                     break;
             }
         }
+
+        if ( m_folderId == 0 )
+            result.append( "p.project_name" );
     }
 
     return result.join( ", " );
@@ -155,6 +186,12 @@ QString QueryGenerator::generateJoins( bool allColumns )
     QStringList joins;
     joins.append( "issues AS i" );
 
+    if ( m_folderId == 0 ) {
+        joins.append( "INNER JOIN folders AS f ON f.folder_id = i.folder_id" );
+        if ( allColumns )
+            joins.append( "INNER JOIN projects AS p ON p.project_id = f.project_id" );
+    }
+
     joins.append( "LEFT OUTER JOIN issue_states AS s ON s.issue_id = i.issue_id AND s.user_id = ?" );
     m_arguments.append( dataManager->currentUserId() );
 
@@ -198,8 +235,13 @@ QString QueryGenerator::generateConditions()
 {
     QStringList conditions;
 
-    conditions.append( "i.folder_id = ?" );
-    m_arguments.append( m_folderId );
+    if ( m_folderId != 0 ) {
+        conditions.append( "i.folder_id = ?" );
+        m_arguments.append( m_folderId );
+    } else {
+        conditions.append( "f.type_id = ?" );
+        m_arguments.append( m_typeId );
+    }
 
     IssueTypeCache* cache = dataManager->issueTypeCache( m_typeId );
 
@@ -247,6 +289,11 @@ QString QueryGenerator::generateConditions()
                 break;
         }
 
+        if ( value.isEmpty() ) {
+            conditions.append( makeNullCondition( expression, type ) );
+            continue;
+        }
+
         switch ( column ) {
             case Column_ID:
                 conditions.append( makeNumericCondition( expression, type, value.toInt() ) );
@@ -351,6 +398,17 @@ QString QueryGenerator::makeStringCondition( const QString& expression, const QS
     return QString();
 }
 
+QString QueryGenerator::makeNullCondition( const QString& expression, const QString& type )
+{
+    if ( type == QLatin1String( "EQ" ) )
+        return QString( "%1 IS NULL" ).arg( expression );
+    if ( type == QLatin1String( "NEQ" ) )
+        return QString( "%1 IS NOT NULL" ).arg( expression );
+
+    m_valid = false;
+    return QString();
+}
+
 QString QueryGenerator::makeNumericCondition( const QString& expression, const QString& type, const QVariant& value )
 {
     m_arguments.append( value );
@@ -408,32 +466,37 @@ QString QueryGenerator::makeDateCondition( const QString& expression, const QStr
     return QString();
 }
 
-QStringList QueryGenerator::sortColumns() const
+QList<QStringList> QueryGenerator::sortColumns() const
 {
-    QStringList result;
+    QList<QStringList> result;
 
     IssueTypeCache* cache = dataManager->issueTypeCache( m_typeId );
 
     if ( m_valid ) {
         foreach ( int column, m_columns ) {
+            QStringList columns;
             switch ( column ) {
                 case Column_ID:
-                    result.append( "i.issue_id" );
+                    columns.append( "i.issue_id" );
                     break;
                 case Column_Name:
-                    result.append( "i.issue_name COLLATE LOCALE" );
+                    columns.append( "i.issue_name COLLATE LOCALE" );
                     break;
                 case Column_CreatedDate:
-                    result.append( "i.issue_id" );
+                    columns.append( "i.issue_id" );
                     break;
                 case Column_ModifiedDate:
-                    result.append( "i.stamp_id" );
+                    columns.append( "i.stamp_id" );
                     break;
                 case Column_CreatedBy:
-                    result.append( "uc.user_name COLLATE LOCALE" );
+                    columns.append( "uc.user_name COLLATE LOCALE" );
                     break;
                 case Column_ModifiedBy:
-                    result.append( "um.user_name COLLATE LOCALE" );
+                    columns.append( "um.user_name COLLATE LOCALE" );
+                    break;
+                case Column_Location:
+                    columns.append( "p.project_name COLLATE LOCALE" );
+                    columns.append( "f.folder_name COLLATE LOCALE" );
                     break;
                 default:
                     if ( column > Column_UserDefined ) {
@@ -442,13 +505,13 @@ QStringList QueryGenerator::sortColumns() const
                             case TextAttribute:
                             case EnumAttribute:
                             case UserAttribute:
-                                result.append( QString( "a%1.attr_value COLLATE LOCALE" ).arg( column - Column_UserDefined ) );
+                                columns.append( QString( "a%1.attr_value COLLATE LOCALE" ).arg( column - Column_UserDefined ) );
                                 break;
                             case NumericAttribute:
-                                result.append( QString( "CAST( a%1.attr_value AS REAL )" ).arg( column - Column_UserDefined ) );
+                                columns.append( QString( "CAST( a%1.attr_value AS REAL )" ).arg( column - Column_UserDefined ) );
                                 break;
                             case DateTimeAttribute:
-                                result.append( QString( "CAST( STRFTIME( '%s', a%1.attr_value ) AS INTEGER )" ).arg( column - Column_UserDefined ) );
+                                columns.append( QString( "CAST( STRFTIME( '%s', a%1.attr_value ) AS INTEGER )" ).arg( column - Column_UserDefined ) );
                                 break;
                             default:
                                 break;
@@ -456,6 +519,7 @@ QStringList QueryGenerator::sortColumns() const
                     }
                     break;
             }
+            result.append( columns );
         }
     }
 
@@ -467,7 +531,7 @@ QList<int> QueryGenerator::columnMapping() const
     QList<int> result;
 
     if ( m_valid ) {
-        int index = 3;
+        int index = 4;
 
         foreach ( int column, m_columns ) {
             if ( column == Column_ID )
