@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -35,10 +35,8 @@ class QueryGenerator : public QObject
 public:
     /**
     * Constructor.
-    * @param folderId Identifier of the folder.
-    * @param viewId Identifier of the view or 0 to use the default view.
     */
-    QueryGenerator( int folderId, int viewId );
+    QueryGenerator();
 
     /**
     * Destructor.
@@ -46,6 +44,16 @@ public:
     ~QueryGenerator();
 
 public:
+    /**
+    * Set the folder containing issues.
+    */
+    void initializeFolder( int folderId, int viewId );
+
+    /**
+    * Set the type of the global list of issues.
+    */
+    void initializeGlobalList( int typeId, int viewId );
+
     /**
     * Set the quick search text for the list.
     */
@@ -81,7 +89,7 @@ public:
     /**
     * Return the list of sort expressions for each column.
     */
-    QStringList sortColumns() const;
+    QList<QStringList> sortColumns() const;
 
     /**
     * Return the column mapping for the view.
@@ -99,6 +107,8 @@ public:
     Qt::SortOrder sortOrder() const { return m_sortOrder; }
 
 private:
+    void initializeCommon( bool withLocation );
+
     QString generateSelect( bool allColumns );
     QString generateJoins( bool allColumns );
     QString generateConditions();
@@ -106,6 +116,7 @@ private:
     QString convertUserValue( const QString& value ) const;
     QDateTime convertDateTimeValue( const QString& value, bool local ) const;
 
+    QString makeNullCondition( const QString& expression, const QString& type );
     QString makeStringCondition( const QString& expression, const QString& type, const QString& value );
     QString makeNumericCondition( const QString& expression, const QString& type, const QVariant& value );
     QString makeDateCondition( const QString& expression, const QString& type, const QDateTime& value );
@@ -113,6 +124,7 @@ private:
 private:
     int m_folderId;
     int m_typeId;
+    int m_viewId;
 
     QList<int> m_columns;
 
