@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -25,12 +25,14 @@
 #include "data/entities.h"
 #include "models/issuedetailsgenerator.h"
 #include "models/foldermodel.h"
-#include "utils/textwriter.h"
+#include "utils/htmlwriter.h"
 #include "utils/csvwriter.h"
 
 ReportGenerator::ReportGenerator() :
     m_folderId( 0 ),
+    m_typeId( 0 ),
     m_summary( false ),
+    m_description( false ),
     m_history( IssueDetailsGenerator::NoHistory )
 {
 }
@@ -44,12 +46,29 @@ void ReportGenerator::setIssueSource( int issueId )
     m_folderId = 0;
     m_issues.clear();
     m_issues.append( issueId );
+
+    IssueEntity issue = IssueEntity::find( issueId );
+    m_title = issue.name();
 }
 
 void ReportGenerator::setFolderSource( int folderId, const QList<int>& issues )
 {
     m_folderId = folderId;
+    m_typeId = 0;
     m_issues = issues;
+
+    FolderEntity folder = FolderEntity::find( folderId );
+    m_title = folder.name();
+}
+
+void ReportGenerator::setGlobalListSource( int typeId, const QList<int>& issues )
+{
+    m_typeId = typeId;
+    m_folderId = 0;
+    m_issues = issues;
+
+    TypeEntity type = TypeEntity::find( typeId );
+    m_title = type.name();
 }
 
 void ReportGenerator::setTableMode( const QList<int>& columns )
@@ -58,19 +77,24 @@ void ReportGenerator::setTableMode( const QList<int>& columns )
     m_summary = false;
 }
 
-void ReportGenerator::setSummaryMode( IssueDetailsGenerator::History history )
+void ReportGenerator::setSummaryMode( bool description, IssueDetailsGenerator::History history )
 {
     m_summary = true;
+    m_description = description;
     m_history = history;
 }
 
-void ReportGenerator::write( TextWriter* writer )
+void ReportGenerator::write( HtmlWriter* writer )
 {
-    if ( m_folderId != 0 && !m_summary ) {
-        FolderEntity folder = FolderEntity::find( m_folderId );
-        writer->writeBlock( folder.name(), TextWriter::Header1Block );
+    if ( m_folderId != 0 || m_typeId != 0 )
+        writer->writeBlock( m_title, HtmlWriter::Header2Block );
 
-        FolderModel model( m_folderId, NULL );
+    if ( !m_summary ) {
+        FolderModel model( NULL );
+        if ( m_folderId != 0 )
+            model.initializeFolder( m_folderId );
+        else if ( m_typeId != 0 )
+            model.initializeGlobalList( m_typeId );
         model.setColumns( m_columns );
 
         QStringList headers;
@@ -83,32 +107,34 @@ void ReportGenerator::write( TextWriter* writer )
         for ( int i = 0; i < m_issues.count(); i++ ) {
             QModelIndex index = model.findIndex( 0, m_issues.at( i ), 0 );
             if ( index.isValid() ) {
-                QList<TextWithLinks> cells;
+                QList<HtmlText> cells;
                 for ( int j = 0; j < m_columns.count(); j++ ) {
                     QString text = model.data( model.index( index.row(), j ), Qt::DisplayRole ).toString();
-                    cells.append( TextWithLinks::parse( text, TextWithLinks::NoInternalLinks ) );
+                    cells.append( HtmlText::parse( text, HtmlText::NoInternalLinks ) );
                 }
                 writer->appendTableRow( cells );
             }
         }
 
         writer->endTable();
-    }
-
-    if ( m_summary ) {
+    } else {
         IssueDetailsGenerator generator;
 
         for ( int i = 0; i < m_issues.count(); i++ ) {
-            generator.setIssue( m_issues.at( i ), m_history );
-            generator.write( writer, TextWithLinks::NoInternalLinks );
+            generator.setIssue( m_issues.at( i ), m_description,  m_history );
+            generator.write( writer, HtmlText::NoInternalLinks );
         }
     }
 }
 
 void ReportGenerator::write( CsvWriter* writer )
 {
-    if ( m_folderId != 0 && !m_summary ) {
-        FolderModel model( m_folderId, NULL );
+    if ( !m_summary ) {
+        FolderModel model( NULL );
+        if ( m_folderId != 0 )
+            model.initializeFolder( m_folderId );
+        else if ( m_typeId != 0 )
+            model.initializeGlobalList( m_typeId );
         model.setColumns( m_columns );
 
         QStringList headers;
