@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 #include "issuedetailsgenerator.h"
 
-class TextWriter;
+class HtmlWriter;
 class CsvWriter;
 class FolderRow;
 class IssueRow;
@@ -33,7 +33,7 @@ class QDateTime;
 * Class for generating  reports.
 *
 * This class exctracts the information about a folder or an issue and outputs it
-* to the ReportWriter or CsvWriter.
+* to the HtmlWriter or CsvWriter.
 */
 class ReportGenerator : public QObject
 {
@@ -57,12 +57,19 @@ public:
     void setIssueSource( int issueId );
 
     /**
-    * Set report source to multiple issues.
+    * Set report source to multiple issues in a folder.
     * @param folderId Identifier of the folder containing the issues.
     * @param issues Identifiers of issues to be included in the report.
     */
     void setFolderSource( int folderId, const QList<int>& issues );
 
+    /**
+    * Set report source to multiple issues in a global list.
+    * @param typeId Identifier of the type of global list containing the issues.
+    * @param issues Identifiers of issues to be included in the report.
+    */
+    void setGlobalListSource( int typeId, const QList<int>& issues );
+
     /**
     * Set report mode to table of issues.
     * @param columns Identifiers of columns of the table.
@@ -71,15 +78,21 @@ public:
 
     /**
     * Set report mode to summary of issue(s).
+    * @param description @c true if the description should be included.
     * @param history Type of issue history to be included.
     */
-    void setSummaryMode( IssueDetailsGenerator::History history );
+    void setSummaryMode( bool description, IssueDetailsGenerator::History history );
+
+    /**
+    * Return the title of the report.
+    */
+    QString title() const { return m_title; }
 
     /**
     * Write the report as a text document.
     * @param writer The text document writer to output the report to.
     */
-    void write( TextWriter* writer );
+    void write( HtmlWriter* writer );
 
     /**
     * Write the report as a CSV file.
@@ -89,11 +102,15 @@ public:
 
 private:
     int m_folderId;
+    int m_typeId;
     QList<int> m_issues;
 
     QList<int> m_columns;
     bool m_summary;
+    bool m_description;
     IssueDetailsGenerator::History m_history;
+
+    QString m_title;
 };
 
 #endif
