@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -26,23 +26,23 @@
 class SqlTreeModelNode
 {
 public:
-    SqlTreeModelNode( int level = 0, int index = 0 ) :
-        m_level( level ),
+    SqlTreeModelNode( int index = 0 ) :
         m_index( index )
     {
     }
 
 public:
-    int m_level;
     int m_index;
+    QList<int> m_levels;
     QList<int> m_rows;
 };
 
 class SqlTreeModelLevel
 {
 public:
-    SqlTreeModelLevel( QSqlQueryModel* model ) :
-        m_model( model )
+    SqlTreeModelLevel( QSqlQueryModel* model, int parentLevel ) :
+        m_model( model ),
+        m_parentLevel( parentLevel )
     {
     }
 
@@ -61,6 +61,8 @@ public:
 public:
     QSqlQueryModel* m_model;
 
+    int m_parentLevel;
+
     QList<int> m_columnMapping;
 
     QVector<int> m_ids;
@@ -101,7 +103,7 @@ public:
     SqlTreeModelNode m_root;
 };
 
-SqlTreeModel::SqlTreeModel( QObject* parent /*= NULL*/ ) : QAbstractItemModel( parent ),
+SqlTreeModel::SqlTreeModel( QObject* parent ) : QAbstractItemModel( parent ),
     d( new SqlTreeModelPrivate( this ) )
 {
 }
@@ -113,7 +115,12 @@ SqlTreeModel::~SqlTreeModel()
 
 void SqlTreeModel::appendModel( QSqlQueryModel* model )
 {
-    d->m_levelData.append( new SqlTreeModelLevel( model ) );
+    insertModel( model, d->m_levelData.count() - 1 );
+}
+
+void SqlTreeModel::insertModel( QSqlQueryModel* model, int parentLevel )
+{
+    d->m_levelData.append( new SqlTreeModelLevel( model, parentLevel ) );
     d->m_columns = -1;
 }
 
@@ -168,6 +175,7 @@ void SqlTreeModel::updateData()
 
     foreach ( SqlTreeModelLevel* levelData, d->m_levelData )
         levelData->clear();
+    d->m_root.m_levels.clear();
     d->m_root.m_rows.clear();
 
     for ( int level = 0; level < d->m_levelData.count(); level++ ) {
@@ -180,7 +188,7 @@ void SqlTreeModel::updateData()
         int count = model->rowCount();
 
         levelData->m_ids.resize( count );
-        if ( level > 0 )
+        if ( levelData->m_parentLevel >= 0 )
             levelData->m_parentIds.resize( count );
 
         for ( int row = 0; row < count; row++ ) {
@@ -189,13 +197,13 @@ void SqlTreeModel::updateData()
 
             SqlTreeModelNode* node;
 
-            if ( level == 0 ) {
+            if ( levelData->m_parentLevel < 0 ) {
                 node = &d->m_root;
             } else {
                 int parentId = model->data( model->index( row, 1 ) ).toInt();
                 levelData->m_parentIds[ row ] = parentId;
 
-                SqlTreeModelLevel* parentLevelData = d->m_levelData.at( level - 1 );
+                SqlTreeModelLevel* parentLevelData = d->m_levelData.at( levelData->m_parentLevel );
 
                 int parentRow = parentLevelData->m_ids.indexOf( parentId );
                 if ( parentRow < 0 )
@@ -204,11 +212,12 @@ void SqlTreeModel::updateData()
                 node = parentLevelData->m_nodes.value( parentRow );
 
                 if ( !node ) {
-                    node = new SqlTreeModelNode( level, parentRow );
+                    node = new SqlTreeModelNode( parentRow );
                     parentLevelData->m_nodes.insert( parentRow, node ); 
                 }
             }
 
+            node->m_levels.append( level );
             node->m_rows.append( row );
         }
     }
@@ -235,7 +244,7 @@ int SqlTreeModel::levelOf( const QModelIndex& index ) const
     if ( !node )
         return -1;
 
-    return node->m_level;
+    return node->m_levels.value( index.row(), -1 );
 }
 
 int SqlTreeModel::mappedRow( const QModelIndex& index ) const
@@ -291,7 +300,7 @@ int SqlTreeModel::rowParentId( const QModelIndex& index ) const
     return levelData->m_parentIds.at( row );
 }
 
-QVariant SqlTreeModel::rawData( int level, int row, int column, int role /*= Qt::DisplayRole*/ ) const
+QVariant SqlTreeModel::rawData( int level, int row, int column, int role ) const
 {
     if ( level < 0 || row < 0 || column < 0 )
         return QVariant();
@@ -315,12 +324,12 @@ QModelIndex SqlTreeModel::findIndex( int level, int id, int column ) const
 
     const SqlTreeModelNode* node;
 
-    if ( level == 0 ) {
+    if ( levelData->m_parentLevel < 0 ) {
         node = &d->m_root;
     } else {
         int parentId = levelData->m_parentIds.at( row );
 
-        SqlTreeModelLevel* parentLevelData = d->m_levelData.at( level - 1 );
+        SqlTreeModelLevel* parentLevelData = d->m_levelData.at( levelData->m_parentLevel );
 
         int parentRow = parentLevelData->m_ids.indexOf( parentId );
         if ( parentRow < 0 )
@@ -331,11 +340,12 @@ QModelIndex SqlTreeModel::findIndex( int level, int id, int column ) const
             return QModelIndex();
     }
 
-    int nodeRow = node->m_rows.indexOf( row );
-    if ( nodeRow < 0 )
-        return QModelIndex();
+    for ( int i = 0; i < node->m_rows.count(); i++ ) {
+        if ( node->m_rows.at( i ) == row && node->m_levels.at( i ) == level )
+            return createIndex( i, column, (void*)node );
+    }
 
-    return createIndex( nodeRow, column, (void*)node );
+    return QModelIndex();
 }
 
 const SqlTreeModelNode* SqlTreeModelPrivate::findNode( const QModelIndex& parent ) const
@@ -356,18 +366,18 @@ const SqlTreeModelNode* SqlTreeModelPrivate::findNode( const QModelIndex& parent
     return levelData->m_nodes.value( row );
 }
 
-int SqlTreeModel::columnCount( const QModelIndex& /*parent*/ /*= QModelIndex()*/ ) const
+int SqlTreeModel::columnCount( const QModelIndex& /*parent*/ ) const
 {
     return qMax( d->m_columns, 0 );
 }
 
-int SqlTreeModel::rowCount( const QModelIndex& parent /*= QModelIndex()*/ ) const
+int SqlTreeModel::rowCount( const QModelIndex& parent ) const
 {
     const SqlTreeModelNode* node = d->findNode( parent );
     return node ? node->m_rows.count() : 0;
 }
 
-QModelIndex SqlTreeModel::index( int row, int column, const QModelIndex& parent /*= QModelIndex()*/ ) const
+QModelIndex SqlTreeModel::index( int row, int column, const QModelIndex& parent ) const
 {
     const SqlTreeModelNode* node = d->findNode( parent );
     if ( !node || row < 0 || row >= node->m_rows.count() )
@@ -384,50 +394,54 @@ QModelIndex SqlTreeModel::parent( const QModelIndex& index ) const
     if ( !node )
         return QModelIndex();
 
-    int level = node->m_level;
-    if ( level < 1 )
+    int level = node->m_levels.value( index.row(), -1 );
+
+    SqlTreeModelLevel* levelData = d->m_levelData.at( level );
+    if ( levelData->m_parentLevel < 0 )
         return QModelIndex();
 
     int row = node->m_index;
 
+    SqlTreeModelLevel* parentLevelData = d->m_levelData.at( levelData->m_parentLevel );
+
     const SqlTreeModelNode* parentNode;
 
-    if ( level == 1 ) {
+    if ( parentLevelData->m_parentLevel < 0 ) {
         parentNode = &d->m_root;
     } else {
-        SqlTreeModelLevel* levelData = d->m_levelData.at( level - 1 );
-        int parentId = levelData->m_parentIds.at( row );
+        int parentId = parentLevelData->m_parentIds.at( row );
 
-        SqlTreeModelLevel* parentLevelData = d->m_levelData.at( level - 2 );
+        SqlTreeModelLevel* grandParentLevelData = d->m_levelData.at( parentLevelData->m_parentLevel );
 
-        int parentRow = parentLevelData->m_ids.indexOf( parentId );
+        int parentRow = grandParentLevelData->m_ids.indexOf( parentId );
         if ( parentRow < 0 )
             return QModelIndex();
 
-        parentNode = parentLevelData->m_nodes.value( parentRow );
+        parentNode = grandParentLevelData->m_nodes.value( parentRow );
         if ( !parentNode )
             return QModelIndex();
     }
 
-    int nodeRow = parentNode->m_rows.indexOf( row );
-    if ( nodeRow < 0 )
-        return QModelIndex();
+    for ( int i = 0; i < parentNode->m_rows.count(); i++ ) {
+        if ( parentNode->m_rows.at( i ) == row && parentNode->m_levels.at( i ) == levelData->m_parentLevel )
+            return createIndex( i, 0, (void*)parentNode );
+    }
 
-    return createIndex( nodeRow, 0, (void*)parentNode );
+    return QModelIndex();
 }
 
-QVariant SqlTreeModel::data( const QModelIndex& index, int role /*= Qt::DisplayRole*/ ) const
+QVariant SqlTreeModel::data( const QModelIndex& index, int role ) const
 {
     return rawData( levelOf( index ), mappedRow( index ), mappedColumn( index ), role );
 }
 
-bool SqlTreeModel::setHeaderData( int section, Qt::Orientation orientation, const QVariant &value, int role /*= Qt::EditRole*/ )
+bool SqlTreeModel::setHeaderData( int section, Qt::Orientation orientation, const QVariant &value, int role )
 {
     if ( orientation != Qt::Horizontal || section < 0 )
         return false;
 
     if ( d->m_headers.size() <= section )
-        d->m_headers.resize( qMax( section, 16 ) );
+        d->m_headers.resize( qMax( section + 1, 16 ) );
 
     d->m_headers[ section ][ role ] = value;
 
@@ -436,7 +450,7 @@ bool SqlTreeModel::setHeaderData( int section, Qt::Orientation orientation, cons
     return true;
 }
 
-QVariant SqlTreeModel::headerData( int section, Qt::Orientation orientation, int role /*= Qt::DisplayRole*/ ) const
+QVariant SqlTreeModel::headerData( int section, Qt::Orientation orientation, int role ) const
 {
     if ( orientation == Qt::Horizontal ) {
         QVariant value = d->m_headers.value( section ).value( role );
@@ -456,7 +470,7 @@ QVariant SqlTreeModel::headerData( int section, Qt::Orientation orientation, int
     return QAbstractItemModel::headerData( section, orientation, role );
 }
 
-void SqlTreeModel::setSort( int column, Qt::SortOrder order /*= Qt::AscendingOrder*/ )
+void SqlTreeModel::setSort( int column, Qt::SortOrder order )
 {
     d->m_sortColumn = column;
     d->m_sortOrder = order;
@@ -472,7 +486,7 @@ Qt::SortOrder SqlTreeModel::sortOrder() const
     return d->m_sortOrder;
 }
 
-void SqlTreeModel::sort( int column, Qt::SortOrder order /*= Qt::AscendingOrder*/ )
+void SqlTreeModel::sort( int column, Qt::SortOrder order )
 {
     if ( d->m_sortColumn != column || d->m_sortOrder != order ) {
         setSort( column, order );
