@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -57,6 +57,13 @@ public:
     */
     void appendModel( QSqlQueryModel* model );
 
+    /**
+    * Insert the SQL model at the specified parent level.
+    * @param model The SQL model to append.
+    * @param parentLevel The parent level.
+    */
+    void insertModel( QSqlQueryModel* model, int parentLevel = -1 );
+
     /**
     * Return the SQL model at the given level.
     * @param level The level of the tree (numbered from zero).
