@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ DefinitionInfo::~DefinitionInfo()
 
 void DefinitionInfo::setMetadata( const QString& key, const QVariant& value )
 {
-    if ( !value.isNull() )
+    if ( value.isValid() )
         m_metadata.insert( key, value );
     else
         m_metadata.remove( key );
