@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -138,6 +138,18 @@ QString ErrorHelper::errorMessage( ErrorCode code ) const
             return tr( "Concurrency error; please try again" );
         case ConstraintConflict:
             return tr( "One of the dependent objects no longer exists" );
+        case EmailAlreadyExists:
+            return tr( "Another user already uses this email address" );
+        case UnknownDescription:
+            return tr( "Description does not exist" );
+        case DescriptionAlreadyExists:
+            return tr( "Description already exists" );
+        case InvalidTextFormat:
+            return tr( "Text format is invalid" );
+        case UnknownSubscription:
+            return tr( "Subscription does not exist" );
+        case SubscriptionAlreadyExists:
+            return tr( "Subscription already exists" );
         default:
             return QString();
     }
