@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,6 @@
 
 #include "networkproxyfactory.h"
 
-#if !defined( NO_PROXY_FACTORY )
-
 #include "application.h"
 #include "data/localsettings.h"
 
@@ -57,5 +55,3 @@ QList<QNetworkProxy> NetworkProxyFactory::queryProxy( const QNetworkProxyQuery&
 
     return QList<QNetworkProxy>() << QNetworkProxy( type, hostName, port );
 }
-
-#endif // !defined( NO_PROXY_FACTORY )
