@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,14 +20,6 @@
 #ifndef NETWORKPROXYFACTORY_H
 #define NETWORKPROXYFACTORY_H
 
-#include <QtGlobal>
-
-#if ( QT_VERSION < 0x040500 )
-#define NO_PROXY_FACTORY
-#endif
-
-#if !defined( NO_PROXY_FACTORY )
-
 #include <QNetworkProxyFactory>
 
 class NetworkProxyFactory : public QNetworkProxyFactory
@@ -40,6 +32,4 @@ public: // overrides
     QList<QNetworkProxy> queryProxy( const QNetworkProxyQuery& query );
 };
 
-#endif // !defined( NO_PROXY_FACTORY )
-
 #endif
