@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -74,7 +74,7 @@ TreeViewHelper::~TreeViewHelper()
 {
 }
 
-void TreeViewHelper::initializeView( ViewFlags flags /*= 0*/ )
+void TreeViewHelper::initializeView( ViewFlags flags )
 {
     m_view->setSortingEnabled( ( flags & NotSortable ) == 0 );
     m_view->setRootIsDecorated( ( flags & TreeStyle ) != 0 );
