@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 
 #include "data/datamanager.h"
 #include "data/issuetypecache.h"
+#include "data/entities.h"
 #include "models/foldermodel.h"
 #include "utils/attributehelper.h"
 
@@ -58,6 +59,8 @@ QString ViewSettingsHelper::columnName( int column ) const
             return tr( "Modified Date" );
         case Column_ModifiedBy:
             return tr( "Modified By" );
+        case Column_Location:
+            return tr( "Location" );
         default:
             if ( column > Column_UserDefined ) {
                 IssueTypeCache* cache = dataManager->issueTypeCache( m_typeId );
@@ -162,3 +165,13 @@ QString ViewSettingsHelper::operatorName( const QString& type ) const
         return tr( "in list" );
     return QString();
 }
+
+QString ViewSettingsHelper::viewName( int viewId ) const
+{
+    if ( viewId != 0 ) {
+        ViewEntity view = ViewEntity::find( viewId );
+        if ( view.isValid() )
+            return view.name();
+    }
+    return tr( "All Issues" );
+}
