@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -70,10 +70,15 @@ public:
     QString filtersInfo( const QList<DefinitionInfo>& filters ) const;
 
     /**
-    * Return the user-friendly name of the operato
+    * Return the user-friendly name of the operator.
     */
     QString operatorName( const QString& type ) const;
 
+    /**
+    * Return the name of the view or All Issues.
+    */
+    QString viewName( int viewId ) const;
+
 private:
     int m_typeId;
 };
