@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include "data/entities.h"
 #include "data/updateevent.h"
 #include "data/localsettings.h"
+#include "dialogs/dialogmanager.h"
 #include "dialogs/issuedialogs.h"
 #include "dialogs/finditemdialog.h"
 #include "dialogs/checkmessagebox.h"
@@ -35,7 +36,7 @@
 #include "models/issuedetailsgenerator.h"
 #include "utils/datetimehelper.h"
 #include "utils/treeviewhelper.h"
-#include "utils/textwriter.h"
+#include "utils/htmlwriter.h"
 #include "utils/formatter.h"
 #include "utils/iconloader.h"
 #include "views/viewmanager.h"
@@ -43,7 +44,6 @@
 #include "xmlui/builder.h"
 
 #include <QLayout>
-#include <QTextBrowser>
 #include <QAction>
 #include <QMenu>
 #include <QFileDialog>
@@ -55,20 +55,18 @@
 #include <QScrollBar>
 #include <QPushButton>
 #include <QTimer>
-
-#if defined( Q_WS_WIN )
-#include <qt_windows.h>
-#undef MessageBox
-#endif
+#include <QWebView>
+#include <QWebFrame>
 
 IssueView::IssueView( QObject* parent, QWidget* parentWidget ) : View( parent ),
-    m_document( NULL ),
-    m_gotoItemId( 0 ),
     m_folderId( 0 ),
     m_typeId( 0 ),
     m_isRead( false ),
+    m_isSubscribed( false ),
     m_history( IssueDetailsGenerator::AllHistory ),
-    m_lockedIssueId( 0 )
+    m_isFindEnabled( false ),
+    m_lockedIssueId( 0 ),
+    m_loading( false )
 {
     QAction* action;
 
@@ -86,6 +84,10 @@ IssueView::IssueView( QObject* parent, QWidget* parentWidget ) : View( parent ),
     connect( action, SIGNAL( triggered() ), this, SLOT( addAttachment() ), Qt::QueuedConnection );
     setAction( "addAttachment", action );
 
+    action = new QAction( IconLoader::icon( "description-new" ), tr( "Add &Description..." ), this );
+    connect( action, SIGNAL( triggered() ), this, SLOT( addDescription() ), Qt::QueuedConnection );
+    setAction( "addDescription", action );
+
     action = new QAction( IconLoader::icon( "edit-modify" ), tr( "&Edit Attributes..." ), this );
     action->setShortcut( tr( "F2" ) );
     connect( action, SIGNAL( triggered() ), this, SLOT( editIssue() ), Qt::QueuedConnection );
@@ -180,6 +182,10 @@ IssueView::IssueView( QObject* parent, QWidget* parentWidget ) : View( parent ),
     connect( action, SIGNAL( triggered() ), this, SLOT( markAsRead() ), Qt::QueuedConnection );
     setAction( "markAsRead", action );
 
+    action = new QAction( IconLoader::icon( "issue-subscribe" ), tr( "Subscribe" ), this );
+    connect( action, SIGNAL( triggered() ), this, SLOT( subscribe() ), Qt::QueuedConnection );
+    setAction( "subscribe", action );
+
     setTitle( "sectionAdd", tr( "Add" ) );
     setTitle( "sectionIssue", tr( "Issue" ) );
     setTitle( "sectionEdit", tr( "Edit" ) );
@@ -193,31 +199,33 @@ IssueView::IssueView( QObject* parent, QWidget* parentWidget ) : View( parent ),
 
     loadXmlUiFile( ":/resources/issueview.xml" );
 
-    QWidget* main = new QWidget( parentWidget );
+    QFrame* main = new QFrame( parentWidget );
+    main->setFrameStyle( QFrame::StyledPanel | QFrame::Sunken );
+
     QVBoxLayout* mainLayout = new QVBoxLayout( main );
     mainLayout->setMargin( 0 );
     mainLayout->setSpacing( 0 );
 
-    m_browser = new QTextBrowser( main );
+    m_browser = new QWebView( main );
     m_browser->setContextMenuPolicy( Qt::CustomContextMenu );
+    m_browser->page()->setLinkDelegationPolicy( QWebPage::DelegateAllLinks );
 
     QPalette palette = m_browser->palette();
-    palette.setBrush( QPalette::Base, QColor( 0xff, 0xff, 0xff ) );
-    palette.setBrush( QPalette::Text, QColor( 0x49, 0x49, 0x49 ) );
     palette.setBrush( QPalette::Inactive, QPalette::Highlight, palette.brush( QPalette::Active, QPalette::Highlight ) );
     palette.setBrush( QPalette::Inactive, QPalette::HighlightedText, palette.brush( QPalette::Active, QPalette::HighlightedText ) );
     m_browser->setPalette( palette );
 
-    mainLayout->addWidget( m_browser );
+    m_browser->setTextSizeMultiplier( application->textSizeMultiplier() );
 
-    m_browser->addAction( this->action( "findNext" ) );
-    m_browser->addAction( this->action( "findPrevious" ) );
+    mainLayout->addWidget( m_browser, 1 );
 
     connect( m_browser, SIGNAL( customContextMenuRequested( const QPoint& ) ),
         this, SLOT( historyContextMenu( const QPoint& ) ) );
-    connect( m_browser, SIGNAL( anchorClicked( const QUrl& ) ), this, SLOT( anchorClicked( const QUrl& ) ) );
+    connect( m_browser, SIGNAL( linkClicked( const QUrl& ) ), this, SLOT( linkClicked( const QUrl& ) ) );
     connect( m_browser, SIGNAL( selectionChanged() ), this, SLOT( updateActions() ) );
 
+    connect( m_browser->page()->mainFrame(), SIGNAL( loadFinished( bool ) ), this, SLOT( scrollToAnchor() ) );
+
     m_findBar = new FindBar( main );
     m_findBar->setBoundWidget( m_browser );
     m_findBar->setAutoFillBackground( true );
@@ -241,11 +249,6 @@ IssueView::IssueView( QObject* parent, QWidget* parentWidget ) : View( parent ),
     m_populateTimer->setSingleShot( true );
 
     connect( m_populateTimer, SIGNAL( timeout() ), this, SLOT( populateDetails() ) );
-
-    connect( application->applicationSettings(), SIGNAL( settingsChanged() ), this, SLOT( populateDetails() ) );
-
-    LocalSettings* settings = application->applicationSettings();
-    m_history = (IssueDetailsGenerator::History)settings->value( "IssueHistoryFilter", (int)IssueDetailsGenerator::AllHistory ).toInt();
 }
 
 IssueView::~IssueView()
@@ -265,6 +268,10 @@ void IssueView::initialUpdate()
 {
     cleanUp();
 
+    QString filter = dataManager->preferenceOrSetting( "history_filter" );
+    if ( !filter.isEmpty() )
+        m_history = (IssueDetailsGenerator::History)filter.toInt();
+
     setAccess( checkDataAccess(), true );
 
     if ( id() != 0 ) {
@@ -288,7 +295,7 @@ Access IssueView::checkDataAccess()
         return NoAccess;
 
     if ( dataManager->currentUserAccess() != AdminAccess ) {
-        MemberEntity member = MemberEntity::find( folder.projectId(), dataManager->currentUserId() );
+        MemberEntity member = MemberEntity::findEffective( folder.projectId(), dataManager->currentUserId() );
         if ( !member.isValid() )
             return NoAccess;
     }
@@ -315,7 +322,7 @@ void IssueView::enableView()
 
 void IssueView::disableView()
 {
-    m_browser->clear();
+    m_browser->setHtml( QString() );
     m_findBar->hide();
 
     updateCaption();
@@ -323,22 +330,26 @@ void IssueView::disableView()
 
 void IssueView::updateAccess( Access access )
 {
+    bool emailEnabled = dataManager->setting( "email_enabled" ).toInt();
+
     action( "moveIssue" )->setVisible( access == AdminAccess );
     action( "deleteIssue" )->setVisible( access == AdminAccess );
+    action( "addDescription" )->setVisible( access == AdminAccess || IssueEntity::isOwner( id() ) );
+    action( "subscribe" )->setVisible( emailEnabled );
 }
 
 void IssueView::gotoItem( int itemId )
 {
     if ( itemId == id() ) {
-        m_browser->verticalScrollBar()->setSliderPosition( 0 );
+        m_browser->page()->mainFrame()->setScrollPosition( QPoint( 0, 0 ) );
         return;
     }
 
-    if ( isUpdating() )
-        m_gotoItemId = itemId;
-
-    if ( IssueEntity::findItem( itemId ) == id() )
-        m_browser->scrollToAnchor( QString( "id%1" ).arg( itemId ) );
+    if ( IssueEntity::findItem( itemId ) == id() ) {
+        m_scrollAnchor = QString( "item%1" ).arg( itemId );
+        if ( !m_loading )
+            scrollToAnchor();
+    }
 }
 
 void IssueView::updateCaption()
@@ -356,13 +367,16 @@ void IssueView::updateActions()
 {
     m_isFindEnabled = m_findBar->isFindEnabled();
 
-    bool hasSelection = m_browser->textCursor().hasSelection();
+    // NOTE: hasSelection() is currently broken and always returns true, so using this workaround
+    bool hasSelection = m_browser->pageAction( QWebPage::Copy )->isEnabled();
 
     bool linkNotEmpty = !m_actionLink.isEmpty();
 
     IssueEntity issue = IssueEntity::find( id() );
     m_isRead = issue.isValid() ? issue.readId() >= issue.stampId() : false;
+    m_isSubscribed = issue.isValid() ? issue.subscriptionId() != 0 : false;
 
+    action( "addDescription" )->setEnabled( !issue.description().isValid() );
     action( "editCopy" )->setEnabled( hasSelection );
     action( "findNext" )->setEnabled( m_isFindEnabled );
     action( "findPrevious" )->setEnabled( m_isFindEnabled );
@@ -376,6 +390,9 @@ void IssueView::updateActions()
 
     action( "markAsRead" )->setText( m_isRead ? tr( "Mark As Unread" ) : tr( "Mark As Read" ) );
     action( "markAsRead" )->setIcon( IconLoader::icon( m_isRead ? "issue-unread" : "issue" ) );
+
+    action( "subscribe" )->setText( m_isSubscribed ? tr( "Unsubscribe" ) : tr( "Subscribe" ) );
+    action( "subscribe" )->setIcon( IconLoader::icon( m_isSubscribed ? "issue-unsubscribe" : "issue-subscribe" ) );
 }
 
 void IssueView::initialUpdateIssue()
@@ -424,7 +441,21 @@ void IssueView::cascadeUpdateIssue()
 void IssueView::addComment()
 {
     if ( isEnabled() )
-        viewManager->openCommentView( id() );
+        addComment( QString(), QString() );
+}
+
+void IssueView::addComment( const QString& title, const QString& text )
+{
+    if ( dialogManager->activateDialog( "AddCommentDialog", id() ) )
+        return;
+
+    AddCommentDialog* dialog = new AddCommentDialog( id() );
+    dialogManager->addDialog( dialog, id() );
+
+    if ( !title.isEmpty() )
+        dialog->setQuote( title, text );
+
+    dialog->show();
 }
 
 void IssueView::addAttachment()
@@ -459,31 +490,37 @@ void IssueView::addAttachment()
 void IssueView::editIssue()
 {
     if ( isEnabled() ) {
-        EditIssueDialog dialog( id(), mainWidget() );
-        dialog.exec();
+        if ( dialogManager->activateDialog( "EditIssueDialog", id() ) )
+            return;
+        EditIssueDialog* dialog = new EditIssueDialog( id() );
+        dialogManager->addDialog( dialog, id() );
+        dialog->show();
     }
 }
 
 void IssueView::cloneIssue()
 {
     if ( isEnabled() ) {
-        CloneIssueDialog cloneDialog( id(), mainWidget() );
-        if ( cloneDialog.exec() == QDialog::Accepted ) {
-            int folderId = cloneDialog.folderId();
+        if ( dialogManager->activateDialog( "CloneIssueDialog", id() ) )
+            return;
 
-            AddIssueDialog addDialog( folderId, id(), mainWidget() );
-            if ( addDialog.exec() == QDialog::Accepted ) {
-                int issueId = addDialog.issueId();
+        CloneIssueDialog* dialog = new CloneIssueDialog( id() );
+        dialogManager->addDialog( dialog, id() );
 
-                if ( viewManager->isStandAlone( this ) )
-                    viewManager->openIssueView( issueId );
-                else
-                    emit issueActivated( issueId, issueId );
-            }
-        }
+        connect( dialog, SIGNAL( issueAdded( int, int ) ), this, SLOT( issueAdded( int ) ) );
+
+        dialog->show();
     }
 }
 
+void IssueView::issueAdded( int issueId )
+{
+    if ( viewManager->isStandAlone( this ) )
+        viewManager->openIssueView( issueId );
+    else
+        emit issueActivated( issueId, issueId );
+}
+
 void IssueView::moveIssue()
 {
     if ( isEnabled() && IssueEntity::isAdmin( id() ) ) {
@@ -502,6 +539,17 @@ void IssueView::deleteIssue()
     }
 }
 
+void IssueView::addDescription()
+{
+    if ( isEnabled() ) {
+        if ( dialogManager->activateDialog( "AddDescriptionDialog", id() ) )
+            return;
+        AddDescriptionDialog* dialog = new AddDescriptionDialog( id() );
+        dialogManager->addDialog( dialog, id() );
+        dialog->show();
+    }
+}
+
 void IssueView::markAsRead()
 {
     if ( isEnabled() ) {
@@ -519,16 +567,29 @@ void IssueView::markAsRead()
     }
 }
 
+void IssueView::subscribe()
+{
+    if ( isEnabled() ) {
+        if ( m_isSubscribed ) {
+            DeleteSubscriptionDialog dialog( id(), mainWidget() );
+            dialog.exec();
+        } else {
+            AddSubscriptionDialog dialog( id(), mainWidget() );
+            dialog.exec();
+        }
+    }
+}
+
 void IssueView::copy()
 {
     if ( isEnabled() )
-        m_browser->copy();
+        m_browser->triggerPageAction( QWebPage::Copy );
 }
 
 void IssueView::selectAll()
 {
     if ( isEnabled() )
-        m_browser->selectAll();
+        m_browser->triggerPageAction( QWebPage::SelectAll );
 }
 
 void IssueView::find()
@@ -543,13 +604,13 @@ void IssueView::find()
 void IssueView::findText( const QString& text )
 {
     if ( isEnabled() )
-        findText( text, m_browser->textCursor().selectionStart(), m_findBar->flags() );
+        findText( text, m_findBar->isCaseSensitive() ? QWebPage::FindCaseSensitively : 0 );
 }
 
 void IssueView::findNext()
 {
     if ( isEnabled() && m_isFindEnabled ) {
-        findText( m_findBar->text(), m_browser->textCursor().selectionStart() + 1, m_findBar->flags() );
+        findText( m_findBar->text(), m_findBar->isCaseSensitive() ? QWebPage::FindCaseSensitively : 0 );
         m_findBar->selectAll();
     }
 }
@@ -557,45 +618,20 @@ void IssueView::findNext()
 void IssueView::findPrevious()
 {
     if ( isEnabled() && m_isFindEnabled ) {
-        findText( m_findBar->text(), m_browser->textCursor().selectionStart(), m_findBar->flags() | QTextDocument::FindBackward );
+        findText( m_findBar->text(), ( m_findBar->isCaseSensitive() ? QWebPage::FindCaseSensitively : 0 ) | QTextDocument::FindBackward );
         m_findBar->selectAll();
     }
 }
 
-void IssueView::findText( const QString& text, int from, QTextDocument::FindFlags flags )
+void IssueView::findText( const QString& text, int flags )
 {
-    QTextCursor found;
     bool warn = false;
 
-    if ( !text.isEmpty() ) {
-        found = m_browser->document()->find( text, from, flags );
-
-        if ( found.isNull() ) {
-            if ( flags & QTextDocument::FindBackward ) {
-                QTextCursor end( m_browser->document() );
-                end.movePosition( QTextCursor::End );
-                from = end.position();
-            } else {
-                from = 0;
-            }
-
-            found = m_browser->document()->find( text, from, flags );
-
-            if ( found.isNull() )
-                warn = true;
-        }
-    }
-
-    if ( found.isNull() ) {
-        found = m_browser->textCursor();
-        found.setPosition( found.selectionStart() );
-    }
+    if ( !text.isEmpty() )
+        warn = !m_browser->findText( text, (QWebPage::FindFlags)flags | QWebPage::FindWrapsAroundDocument );
 
     m_findBar->show();
     m_findBar->setFocus();
-
-    m_browser->setTextCursor( found );
-
     m_findBar->showWarning( warn );
 }
 
@@ -619,30 +655,30 @@ bool IssueView::eventFilter( QObject* obj, QEvent* e )
 void IssueView::openAttachment()
 {
     if ( isEnabled() && !m_actionLink.isEmpty() )
-        handleAttachment( QUrl( m_actionLink ).host().toInt(), ActionOpen );
+        handleAttachment( m_actionLink.host().toInt(), ActionOpen );
 }
 
 void IssueView::saveAttachment()
 {
     if ( isEnabled() && !m_actionLink.isEmpty() )
-        handleAttachment( QUrl( m_actionLink ).host().toInt(), ActionSaveAs );
+        handleAttachment( m_actionLink.host().toInt(), ActionSaveAs );
 }
 
 void IssueView::openLink()
 {
     if ( isEnabled() && !m_actionLink.isEmpty() )
-        anchorClicked( QUrl( m_actionLink ) );
+        linkClicked( m_actionLink );
 }
 
 void IssueView::copyLink()
 {
     if ( isEnabled() && !m_actionLink.isEmpty() ) {
-        QString url = m_actionLink;
+        QString link = m_actionLink.toString();
 
-        if ( url.startsWith( "mailto:" ) )
-            url = url.mid( 7 );
+        if ( link.startsWith( "mailto:", Qt::CaseInsensitive ) )
+            link = link.mid( 7 );
 
-        QApplication::clipboard()->setText( url, QClipboard::Clipboard );
+        QApplication::clipboard()->setText( link, QClipboard::Clipboard );
     }
 }
 
@@ -700,11 +736,6 @@ void IssueView::updateEvent( UpdateEvent* e )
             updateActions();
     }
 
-    if ( isEnabled() && m_gotoItemId != 0 && e->unit() == UpdateEvent::Issue && e->id() == id() ) {
-        gotoItem( m_gotoItemId );
-        m_gotoItemId = 0;
-    }
-
     if ( id() != 0 && m_folderId != 0 && e->unit() == UpdateEvent::Folder && e->id() == m_folderId )
         cascadeUpdateIssue();
 }
@@ -723,25 +754,18 @@ void IssueView::populateDetails()
 
     QApplication::setOverrideCursor( Qt::WaitCursor );
 
-    int pos = m_browser->verticalScrollBar()->sliderPosition();
+    QPoint pos = m_browser->page()->mainFrame()->scrollPosition();
 
     IssueDetailsGenerator generator;
-    generator.setIssue( id(), m_history );
+    generator.setIssue( id(), true, m_history );
 
-    if ( m_document )
-        m_document->clear();
-
-    QTextDocument* document = new QTextDocument( m_browser );
-
-    TextWriter writer( document );
+    HtmlWriter writer;
     generator.write( &writer );
 
-    m_browser->setDocument( document );
+    m_loading = true;
+    m_browser->setHtml( writer.toHtml() );
 
-    delete m_document;
-    m_document = document;
-
-    m_browser->verticalScrollBar()->setSliderPosition( pos );
+    m_browser->page()->mainFrame()->setScrollPosition( pos );
 
     QStringList status;
     if ( m_history != IssueDetailsGenerator::OnlyFiles )
@@ -753,40 +777,56 @@ void IssueView::populateDetails()
     QApplication::restoreOverrideCursor();
 }
 
-void IssueView::linkContextMenu( const QString& link, const QPoint& pos )
+void IssueView::scrollToAnchor()
+{
+    m_loading = false;
+
+    if ( !m_scrollAnchor.isEmpty() ) {
+        m_browser->page()->mainFrame()->scrollToAnchor( m_scrollAnchor );
+        m_scrollAnchor.clear();
+    }
+}
+
+bool IssueView::linkContextMenu( const QUrl& link, const QPoint& pos )
 {
     m_actionLink = link;
     updateActions();
 
-    QUrl url( link );
-
     QString menuName;
-    if ( url.scheme() == QLatin1String( "id" ) )
+    QString scheme = link.scheme().toLower();
+
+    if ( scheme == QLatin1String( "id" ) )
         menuName = "menuLinkItem";
-    else if ( url.scheme() == QLatin1String( "attachment" ) )
+    else if ( scheme == QLatin1String( "attachment" ) )
         menuName = "menuLinkAttachment";
-    else if ( url.scheme() == QLatin1String( "mailto" ) )
+    else if ( scheme == QLatin1String( "mailto" ) )
         menuName = "menuLinkEmail";
-    else if ( url.scheme() == QLatin1String( "command" ) )
-        menuName = "menuHistory";
-    else
+    else if ( scheme != QLatin1String( "command" ) )
         menuName = "menuLink";
 
-    QMenu* menu = builder()->contextMenu( menuName );
-    if ( menu )
-        menu->exec( pos );
+    if ( !menuName.isEmpty() ) {
+        QMenu* menu = builder()->contextMenu( menuName );
+        if ( menu ) {
+            menu->exec( pos );
+            return true;
+        }
+    }
+
+    return false;
 }
 
 void IssueView::historyContextMenu( const QPoint& pos )
 {
-    QString link = m_browser->anchorAt( pos );
+    QWebHitTestResult result = m_browser->page()->mainFrame()->hitTestContent( pos );
+    QUrl link = result.linkUrl();
+
     if ( !link.isEmpty() ) {
-        linkContextMenu( link, m_browser->mapToGlobal( pos ) );
-        return;
+        if ( linkContextMenu( link, m_browser->mapToGlobal( pos ) ) )
+            return;
     }
 
     QString menuName;
-    if ( m_browser->textCursor().hasSelection() )
+    if ( m_browser->pageAction( QWebPage::Copy )->isEnabled() )
         menuName = "menuSelection";
     else
         menuName = "menuHistory";
@@ -796,38 +836,21 @@ void IssueView::historyContextMenu( const QPoint& pos )
         menu->popup( m_browser->mapToGlobal( pos ) );
 }
 
-void IssueView::anchorClicked( const QUrl& url )
+void IssueView::linkClicked( const QUrl& url )
 {
-    int pos = m_browser->verticalScrollBar()->sliderPosition();
-    m_browser->setSource( QUrl() );
-    m_browser->verticalScrollBar()->setSliderPosition( pos );
+    QString scheme = url.scheme().toLower();
 
-    if ( url.scheme() == QLatin1String( "id" ) ) {
+    if ( scheme == QLatin1String( "id" ) ) {
         int itemId = url.host().toInt();
         findItem( itemId );
-    } else if ( url.scheme() == QLatin1String( "attachment" ) ) {
+    } else if ( scheme == QLatin1String( "attachment" ) ) {
         int attachmentId = url.host().toInt();
         handleAttachment( attachmentId );
-    } else if ( url.scheme() == QLatin1String( "command" ) ) {
+    } else if ( scheme == QLatin1String( "command" ) ) {
         int argument = url.path().mid( 1 ).toInt();
         handleCommand( url.host(), argument );
     } else {
-#if defined( Q_WS_WIN )
-        if ( url.scheme() == QLatin1String( "file" ) ) {
-            if ( url.isValid() ) {
-                QString path = url.path();
-                if ( path.startsWith( QLatin1Char( '/' ) ) )
-                    path = path.mid( 1 );
-                path = QDir::toNativeSeparators( path );
-                QString host = url.host();
-                if ( !host.isEmpty() )
-                    path = QLatin1String( "\\\\" ) + host + QLatin1String( "\\" ) + path;
-                if ( !path.isEmpty() )
-                    ShellExecute( mainWidget()->effectiveWinId(), NULL, (LPCTSTR)path.utf16(), NULL, NULL, SW_NORMAL );
-            }
-        } else
-#endif
-        QDesktopServices::openUrl( url );
+        Application::openUrl( mainWidget(), url );
     }
 }
 
@@ -835,10 +858,22 @@ void IssueView::handleCommand( const QString& command, int argument )
 {
     if ( command == QLatin1String( "filter" ) ) {
         m_history = (IssueDetailsGenerator::History)argument;
-        application->applicationSettings()->setValue( "IssueHistoryFilter", (int)m_history );
         populateDetails();
+    } else if ( command == QLatin1String( "edit-description" ) ) {
+        if ( dialogManager->activateDialog( "EditDescriptionDialog", id() ) )
+            return;
+        EditDescriptionDialog* dialog = new EditDescriptionDialog( id() );
+        dialogManager->addDialog( dialog, id() );
+        dialog->show();
+    } else if ( command == QLatin1String( "delete-description" ) ) {
+        DeleteDescriptionDialog dialog( id(), mainWidget() );
+        dialog.exec();
     } else if ( command == QLatin1String( "edit-comment" ) ) {
-        viewManager->openCommentView( argument );
+        if ( dialogManager->activateDialog( "EditCommentDialog", argument ) )
+            return;
+        EditCommentDialog* dialog = new EditCommentDialog( argument );
+        dialogManager->addDialog( dialog, argument );
+        dialog->show();
     } else if ( command == QLatin1String( "edit-file" ) ) {
         EditAttachmentDialog dialog( argument, mainWidget() );
         dialog.exec();
@@ -848,21 +883,19 @@ void IssueView::handleCommand( const QString& command, int argument )
     } else if ( command == QLatin1String( "delete-file" ) ) {
         DeleteAttachmentDialog dialog( argument, mainWidget() );
         dialog.exec();
+    } else if ( command == QLatin1String( "reply-description" ) ) {
+        addComment( tr( "Description" ), IssueEntity::find( id() ).description().text() );
+    } else if ( command == QLatin1String( "reply-comment" ) ) {
+        addComment( tr( "Comment #%1" ).arg( argument ), ChangeEntity::findComment( argument ).comment().text() );
     }
 }
 
 void IssueView::findItem( int itemId )
 {
-    int issueId = IssueEntity::findItem( itemId );
+    int issueId = FindItemDialog::getFindItem( mainWidget(), itemId );
 
-    if ( issueId == 0 ) {
-        FindItemDialog dialog( mainWidget() );
-        dialog.findItem( itemId );
-        if ( dialog.exec() == QDialog::Accepted )
-            issueId = dialog.issueId();
-        else
-            return;
-    }
+    if ( issueId == 0 )
+        return;
 
     if ( issueId == id() )
         gotoItem( itemId );
