@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,8 @@
 #include "data/datamanager.h"
 #include "data/entities.h"
 #include "data/localsettings.h"
+#include "data/issuetypecache.h"
+#include "dialogs/dialogmanager.h"
 #include "dialogs/projectdialogs.h"
 #include "dialogs/membersdialog.h"
 #include "dialogs/managealertsdialog.h"
@@ -55,10 +57,10 @@ ProjectsView::ProjectsView( QObject* parent, QWidget* parentWidget ) : View( par
     connect( action, SIGNAL( triggered() ), this, SLOT( updateProjects() ), Qt::QueuedConnection );
     setAction( "updateProjects", action );
 
-    action = new QAction( IconLoader::icon( "view-members" ), tr( "Project &Members..." ), this );
-    action->setIconText( tr( "Members" ) );
-    connect( action, SIGNAL( triggered() ), this, SLOT( showMembers() ), Qt::QueuedConnection );
-    setAction( "showMembers", action );
+    action = new QAction( IconLoader::icon( "edit-access" ), tr( "&Manage Permissions..." ), this );
+    action->setIconText( tr( "Permissions" ) );
+    connect( action, SIGNAL( triggered() ), this, SLOT( managePermissions() ), Qt::QueuedConnection );
+    setAction( "managePermissions", action );
 
     if ( m_systemAdmin ) {
         action = new QAction( IconLoader::icon( "project-new" ), tr( "Add &Project..." ), this );
@@ -88,11 +90,21 @@ ProjectsView::ProjectsView( QObject* parent, QWidget* parentWidget ) : View( par
     connect( action, SIGNAL( triggered() ), this, SLOT( moveFolder() ), Qt::QueuedConnection );
     setAction( "moveFolder", action );
 
+    action = new QAction( IconLoader::icon( "project" ), tr( "&Open Project" ), this );
+    action->setShortcut( QKeySequence::Open );
+    connect( action, SIGNAL( triggered() ), this, SLOT( openProject() ), Qt::QueuedConnection );
+    setAction( "openProject", action );
+
     action = new QAction( IconLoader::icon( "folder-open" ), tr( "&Open Folder" ), this );
     action->setShortcut( QKeySequence::Open );
     connect( action, SIGNAL( triggered() ), this, SLOT( openFolder() ), Qt::QueuedConnection );
     setAction( "openFolder", action );
 
+    action = new QAction( IconLoader::icon( "folder-open" ), tr( "&Open List" ), this );
+    action->setShortcut( QKeySequence::Open );
+    connect( action, SIGNAL( triggered() ), this, SLOT( openGlobalList() ), Qt::QueuedConnection );
+    setAction( "openGlobalList", action );
+
     action = new QAction( IconLoader::icon( "configure-alerts" ), tr( "&Manage Alerts..." ), this );
     connect( action, SIGNAL( triggered() ), this, SLOT( manageAlerts() ), Qt::QueuedConnection );
     setAction( "manageAlerts", action );
@@ -100,7 +112,10 @@ ProjectsView::ProjectsView( QObject* parent, QWidget* parentWidget ) : View( par
     setTitle( "sectionAdd", tr( "Add" ) );
     setTitle( "sectionProjects", tr( "Projects" ) );
 
+    setDefaultMenuAction( "menuProject", "openProject" );
+    setDefaultMenuAction( "menuProjectAdmin", "openProject" );
     setDefaultMenuAction( "menuFolder", "openFolder" );
+    setDefaultMenuAction( "menuGlobalList", "openGlobalList" );
 
     loadXmlUiFile( ":/resources/projectsview.xml" );
 
@@ -167,7 +182,7 @@ Access ProjectsView::checkDataAccess()
 
 void ProjectsView::updateAccess( Access /*access*/ )
 {
-    action( "showMembers" )->setVisible( m_anyProjectAdmin );
+    action( "managePermissions" )->setVisible( m_anyProjectAdmin );
     action( "addFolder" )->setVisible( m_anyProjectAdmin );
     action( "editRename" )->setVisible( m_systemAdmin || m_anyProjectAdmin );
     action( "editDelete" )->setVisible( m_systemAdmin || m_anyProjectAdmin );
@@ -226,14 +241,12 @@ void ProjectsView::cascadeUpdateFolders()
     UpdateBatch* batch = NULL;
 
     foreach ( const FolderEntity& folder, FolderEntity::list() ) {
-        if ( !folder.alerts().isEmpty() ) {
-            if ( dataManager->folderUpdateNeeded( folder.id() ) ) {
-                if ( !batch ) {
-                    batch = new UpdateBatch( -20 );
-                    batch->setIfNeeded( true );
-                }
-                batch->updateFolder( folder.id() );
+        if ( dataManager->folderUpdateNeeded( folder.id() ) ) {
+            if ( !batch ) {
+                batch = new UpdateBatch( -20 );
+                batch->setIfNeeded( true );
             }
+            batch->updateFolder( folder.id() );
         }
     }
 
@@ -251,10 +264,12 @@ void ProjectsView::updateActions()
 {
     m_selectedProjectId = 0;
     m_selectedFolderId = 0;
+    m_selectedTypeId = 0;
     m_selectedViewId = 0;
 
     m_currentProjectId = 0;
     m_currentFolderId = 0;
+    m_currentTypeId = 0;
 
     TreeViewHelper helper( m_list );
     QModelIndex index = helper.selectedIndex();
@@ -262,32 +277,46 @@ void ProjectsView::updateActions()
     if ( index.isValid() ) {
         int level = m_model->levelOf( index );
         int rowId = m_model->rowId( index );
-        if ( level == 0 ) {
+        if ( level == ProjectsModel::Types ) {
+            m_selectedTypeId = rowId;
+            m_currentTypeId = rowId;
+            IssueTypeCache* cache = dataManager->issueTypeCache( rowId );
+            m_selectedViewId = cache->initialViewId();
+        } if ( level == ProjectsModel::Projects ) {
             m_selectedProjectId = rowId;
             m_currentProjectId = rowId;
-        } else if ( level == 1 ) {
+        } else if ( level == ProjectsModel::Folders ) {
             m_selectedFolderId = rowId;
             m_currentFolderId = rowId;
             FolderEntity folder = FolderEntity::find( rowId );
             m_currentProjectId = folder.projectId();
-        } else {
+            IssueTypeCache* cache = dataManager->issueTypeCache( folder.typeId() );
+            m_selectedViewId = cache->initialViewId();
+        } else if ( level == ProjectsModel::Alerts ) {
             AlertEntity alert = AlertEntity::find( rowId );
             FolderEntity folder = alert.folder();
             m_selectedViewId = alert.viewId();
             m_currentFolderId = folder.id();
             m_currentProjectId = folder.projectId();
+        } else if ( level == ProjectsModel::GlobalAlerts ) {
+            AlertEntity alert = AlertEntity::find( rowId );
+            TypeEntity type = alert.type();
+            m_selectedViewId = alert.viewId();
+            m_currentTypeId = type.id();
         }
     }
 
     m_currentProjectAdmin = ProjectEntity::isAdmin( m_currentProjectId );
 
-    action( "showMembers" )->setEnabled( m_selectedProjectId && m_currentProjectAdmin );
+    action( "managePermissions" )->setEnabled( m_selectedProjectId && m_currentProjectAdmin );
+    action( "openProject" )->setEnabled( m_selectedProjectId != 0 );
     action( "openFolder" )->setEnabled( m_selectedFolderId != 0 );
+    action( "openGlobalList" )->setEnabled( m_selectedTypeId != 0 );
     action( "addFolder" )->setEnabled( m_currentProjectId != 0 && m_currentProjectAdmin );
     action( "editRename" )->setEnabled( ( m_selectedProjectId != 0 && m_systemAdmin ) || ( m_selectedFolderId != 0 && m_currentProjectAdmin ) );
     action( "editDelete" )->setEnabled( ( m_selectedProjectId != 0 && m_systemAdmin ) || ( m_selectedFolderId != 0 && m_currentProjectAdmin ) );
     action( "moveFolder" )->setEnabled( m_selectedFolderId != 0 && m_currentProjectAdmin );
-    action( "manageAlerts" )->setEnabled( m_currentFolderId != 0 );
+    action( "manageAlerts" )->setEnabled( m_currentFolderId != 0 || m_currentTypeId != 0 );
 
     action( "editRename" )->setText( m_selectedFolderId != 0 ? tr( "&Rename Folder..." ) : tr( "&Rename Project..." ) );
     action( "editDelete" )->setText( m_selectedFolderId != 0 ? tr( "&Delete Folder" ) : tr( "&Delete Project" ) );
@@ -297,35 +326,69 @@ void ProjectsView::updateSelection()
 {
     updateActions();
 
-    emit selectionChanged( m_currentFolderId, m_selectedViewId );
+    if ( m_selectedProjectId != 0 )
+        emit projectSelected( m_selectedProjectId );
+    else
+        emit selectionChanged( m_currentFolderId, m_currentTypeId, m_selectedViewId );
 }
 
-void ProjectsView::setSelection( int folderId, int viewId )
+void ProjectsView::setSelection( int folderId, int typeId, int viewId )
 {
-    if ( m_currentFolderId == folderId && m_selectedViewId == viewId )
+    if ( m_currentFolderId == folderId && m_currentTypeId == typeId && m_selectedViewId == viewId )
         return;
 
-    if ( viewId != 0 ) {
-        FolderEntity folder = FolderEntity::find( folderId );
-        foreach ( const AlertEntity& alert, folder.alerts() ) {
-            if ( alert.viewId() == viewId ) {
-                QModelIndex index = m_model->findIndex( 2, alert.id(), 0 );
-                if ( index.isValid() ) {
-                    m_list->selectionModel()->setCurrentIndex( index, QItemSelectionModel::Current );
-                    m_list->selectionModel()->select( index, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
-                    return;
+    if ( typeId != 0 ) {
+        TypeEntity type = TypeEntity::find( typeId );
+        IssueTypeCache* cache = dataManager->issueTypeCache( typeId );
+        int initialViewId = cache->initialViewId();
+
+        if ( viewId != initialViewId ) {
+            foreach ( const AlertEntity& alert, type.alerts() ) {
+                if ( alert.viewId() == viewId ) {
+                    QModelIndex index = m_model->findIndex( ProjectsModel::GlobalAlerts, alert.id(), 0 );
+                    if ( index.isValid() ) {
+                        m_list->selectionModel()->setCurrentIndex( index, QItemSelectionModel::Current );
+                        m_list->selectionModel()->select( index, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
+                        return;
+                    }
+                    break;
                 }
-                break;
             }
         }
-    }
 
-    QModelIndex index = m_model->findIndex( 1, folderId, 0 );
-    if ( index.isValid() ) {
-        m_list->selectionModel()->setCurrentIndex( index, QItemSelectionModel::Current );
-        m_list->selectionModel()->select( index, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
-    } else {
-        m_list->clearSelection();
+        QModelIndex index = m_model->findIndex( ProjectsModel::Types, typeId, 0 );
+        if ( index.isValid() ) {
+            m_list->selectionModel()->setCurrentIndex( index, QItemSelectionModel::Current );
+            m_list->selectionModel()->select( index, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
+        } else {
+            m_list->clearSelection();
+        }
+    } else if ( folderId != 0 ) {
+        FolderEntity folder = FolderEntity::find( folderId );
+        IssueTypeCache* cache = dataManager->issueTypeCache( folder.typeId() );
+        int initialViewId = cache->initialViewId();
+
+        if ( viewId != initialViewId ) {
+            foreach ( const AlertEntity& alert, folder.alerts() ) {
+                if ( alert.viewId() == viewId ) {
+                    QModelIndex index = m_model->findIndex( ProjectsModel::Alerts, alert.id(), 0 );
+                    if ( index.isValid() ) {
+                        m_list->selectionModel()->setCurrentIndex( index, QItemSelectionModel::Current );
+                        m_list->selectionModel()->select( index, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
+                        return;
+                    }
+                    break;
+                }
+            }
+        }
+
+        QModelIndex index = m_model->findIndex( ProjectsModel::Folders, folderId, 0 );
+        if ( index.isValid() ) {
+            m_list->selectionModel()->setCurrentIndex( index, QItemSelectionModel::Current );
+            m_list->selectionModel()->select( index, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
+        } else {
+            m_list->clearSelection();
+        }
     }
 }
 
@@ -346,19 +409,25 @@ void ProjectsView::updateProjects()
     }
 }
 
-void ProjectsView::showMembers()
+void ProjectsView::managePermissions()
 {
     if ( m_selectedProjectId != 0 && m_currentProjectAdmin ) {
-        MembersDialog dialog( m_selectedProjectId, mainWidget() );
-        dialog.exec();
+        if ( dialogManager->activateDialog( "MembersDialog", m_selectedProjectId ) )
+            return;
+        MembersDialog* dialog = new MembersDialog( m_selectedProjectId );
+        dialogManager->addDialog( dialog, m_selectedProjectId );
+        dialog->show();
     }
 }
 
 void ProjectsView::addProject()
 {
     if ( m_systemAdmin ) {
-        AddProjectDialog dialog( mainWidget() );
-        dialog.exec();
+        if ( dialogManager->activateDialog( "AddProjectDialog" ) )
+            return;
+        AddProjectDialog* dialog = new AddProjectDialog();
+        dialogManager->addDialog( dialog );
+        dialog->show();
     }
 }
 
@@ -403,17 +472,38 @@ void ProjectsView::moveFolder()
     }
 }
 
+void ProjectsView::openProject()
+{
+    if ( m_selectedProjectId != 0  )
+        viewManager->openSummaryView( m_selectedProjectId );
+}
+
 void ProjectsView::openFolder()
 {
     if ( m_selectedFolderId != 0  )
         viewManager->openFolderView( m_selectedFolderId );
 }
 
+void ProjectsView::openGlobalList()
+{
+    if ( m_selectedTypeId != 0  )
+        viewManager->openGlobalListView( m_selectedTypeId );
+}
+
 void ProjectsView::manageAlerts()
 {
     if ( m_currentFolderId != 0  ) {
-        ManageAlertsDialog dialog( m_currentFolderId, mainWidget() );
-        dialog.exec();
+        if ( dialogManager->activateDialog( "ManageFolderAlertsDialog", m_currentFolderId ) )
+            return;
+        ManageFolderAlertsDialog* dialog = new ManageFolderAlertsDialog( m_currentFolderId );
+        dialogManager->addDialog( dialog, m_currentFolderId );
+        dialog->show();
+    } else if ( m_currentTypeId != 0 ) {
+        if ( dialogManager->activateDialog( "ManageGlobalAlertsDialog", m_currentTypeId ) )
+            return;
+        ManageGlobalAlertsDialog* dialog = new ManageGlobalAlertsDialog( m_currentTypeId );
+        dialogManager->addDialog( dialog, m_currentTypeId );
+        dialog->show();
     }
 }
 
@@ -437,12 +527,16 @@ void ProjectsView::contextMenu( const QPoint& pos )
     QString menuName;
     if ( index.isValid() ) {
         int level = m_model->levelOf( index );
-        if ( level == 0 )
+        if ( level == ProjectsModel::Projects )
             menuName = m_systemAdmin ? "menuProjectAdmin" : "menuProject";
-        else if ( level == 1 )
+        else if ( level == ProjectsModel::Types )
+            menuName = "menuGlobalList";
+        else if ( level == ProjectsModel::Folders )
             menuName = "menuFolder";
-        else
+        else if ( level == ProjectsModel::Alerts || level == ProjectsModel::GlobalAlerts )
             menuName = "menuAlert";
+        else
+            menuName = "menuNull";
     } else {
         menuName = "menuNull";
     }
@@ -458,7 +552,11 @@ void ProjectsView::doubleClicked( const QModelIndex& index )
         int level = m_model->levelOf( index );
         int rowId = m_model->rowId( index );
 
-        if ( level == 1 )
+        if ( level == ProjectsModel::Projects )
+            viewManager->openSummaryView( rowId );
+        else if ( level == ProjectsModel::Types )
+            viewManager->openGlobalListView( rowId );
+        else if ( level == ProjectsModel::Folders )
             viewManager->openFolderView( rowId );
     }
 }
