@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -48,18 +48,23 @@ public:
 
 public:
     /**
-    * Select specified folder or alert.
+    * Select specified folder, global list or alert.
     */
-    void setSelection( int folderId, int viewId );
+    void setSelection( int folderId, int typeId, int viewId );
 
 public: // overrides
     void initialUpdate();
 
 signals:
     /**
-    * Emitted when the selected folder or alert is changed.
+    * Emitted when the selected folder, global list or alert is changed.
     */
-    void selectionChanged( int folderId, int viewId );
+    void selectionChanged( int folderId, int typeId, int viewId );
+
+    /**
+    * Emitted when the selected project is changed.
+    */
+    void projectSelected( int projectId );
 
 protected: // overrides
     void updateAccess( Access access );
@@ -75,13 +80,15 @@ private slots:
     void updateTimeout();
 
     void updateProjects();
-    void showMembers();
+    void managePermissions();
     void addProject();
     void addFolder();
     void editRename();
     void editDelete();
     void moveFolder();
+    void openProject();
     void openFolder();
+    void openGlobalList();
     void manageAlerts();
 
     void contextMenu( const QPoint& pos );
@@ -105,11 +112,13 @@ private:
 
     int m_selectedProjectId;
     int m_selectedFolderId;
+    int m_selectedTypeId;
     int m_selectedViewId;
 
     int m_currentProjectId;
     bool m_currentProjectAdmin;
     int m_currentFolderId;
+    int m_currentTypeId;
 
     bool m_systemAdmin;
     bool m_anyProjectAdmin;
