@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -210,7 +210,7 @@ void StartView::returnPressed()
         showWarning( tr( "The address you entered is not valid." ) );
 }
 
-void StartView::openConnection( const QString& url, const ServerCredential& credential /*= ServerCredential()*/ )
+void StartView::openConnection( const QString& url, const ServerCredential& credential )
 {
     QUrl parsedUrl = QUrl::fromEncoded( url.toUtf8(), QUrl::TolerantMode );
 
