@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include "commands/updatebatch.h"
 #include "data/datamanager.h"
 #include "data/entities.h"
+#include "dialogs/dialogmanager.h"
 #include "dialogs/typedialogs.h"
 #include "dialogs/viewsettingsdialog.h"
 #include "models/typesmodel.h"
@@ -213,14 +214,11 @@ void TypesView::editDelete()
 void TypesView::viewSettings()
 {
     if ( m_selectedTypeId != 0 ) {
-        bool isPublic = true;
-        for ( ; ; ) {
-            ViewSettingsDialog dialog( m_selectedTypeId, isPublic, mainWidget() );
-            if ( dialog.exec() == ViewSettingsDialog::SwitchMode )
-                isPublic = !isPublic;
-            else
-                break;
-        }
+        if ( dialogManager->activateDialog( "PublicViewSettingsDialog", m_selectedTypeId ) )
+            return;
+        PublicViewSettingsDialog* dialog = new PublicViewSettingsDialog( m_selectedTypeId );
+        dialogManager->addDialog( dialog, m_selectedTypeId );
+        dialog->show();
     }
 }
 
