@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -56,6 +56,18 @@ void View::setViewerSizeHint( const QSize& size )
     m_sizeHint = size;
 }
 
+QString View::viewerSizeKey() const
+{
+    if ( !m_sizeKey.isEmpty() )
+        return m_sizeKey;
+    return metaObject()->className();
+}
+
+void View::setViewerSizeKey( const QString& key )
+{
+    m_sizeKey = key;
+}
+
 void View::setAccess( Access access, bool initial )
 {
     if ( initial || m_access != access ) {
