@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -106,8 +106,10 @@ void ViewerWindow::setView( View* view )
 
     LocalSettings* settings = application->applicationSettings();
 
-    QString geometryKey = QString( "%1Geometry" ).arg( m_view->metaObject()->className() );
-    QString offsetKey = QString( "%1Offset" ).arg( m_view->metaObject()->className() );
+    QString key = m_view->viewerSizeKey();
+
+    QString geometryKey = QString( "%1Geometry" ).arg( key );
+    QString offsetKey = QString( "%1Offset" ).arg( key );
 
     if ( settings->contains( geometryKey ) ) {
         restoreGeometry( settings->value( geometryKey ).toByteArray() );
@@ -157,8 +159,10 @@ void ViewerWindow::storeGeometry( bool offset )
 {
     LocalSettings* settings = application->applicationSettings();
 
-    QString geometryKey = QString( "%1Geometry" ).arg( m_view->metaObject()->className() );
-    QString offsetKey = QString( "%1Offset" ).arg( m_view->metaObject()->className() );
+    QString key = m_view->viewerSizeKey();
+
+    QString geometryKey = QString( "%1Geometry" ).arg( key );
+    QString offsetKey = QString( "%1Offset" ).arg( key );
 
     settings->setValue( geometryKey, saveGeometry() );
     settings->setValue( offsetKey, offset );
@@ -180,7 +184,7 @@ void ViewerWindow::captionChanged( const QString& caption )
     setWindowTitle( tr( "%1 - WebIssues Desktop Client" ).arg( caption ) );
 }
 
-void ViewerWindow::showStatus( const QPixmap& pixmap, const QString& text, int icon /*= 0*/ )
+void ViewerWindow::showStatus( const QPixmap& pixmap, const QString& text, int icon )
 {
     m_statusLabel->setPixmap( pixmap );
     m_statusLabel->setText( text );
