@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,9 +20,10 @@
 #include "viewfactory.h"
 #include "usersview.h"
 #include "typesview.h"
+#include "summaryview.h"
 #include "folderview.h"
+#include "globallistview.h"
 #include "issueview.h"
-#include "commentview.h"
 
 #include <QMetaObject>
 
@@ -32,11 +33,13 @@ View* ViewFactory::createView( const char* className, QObject* parent, QWidget*
         return new UsersView( parent, parentWidget );
     if ( !qstrcmp( className, TypesView::staticMetaObject.className() ) )
         return new TypesView( parent, parentWidget );
+    if ( !qstrcmp( className, SummaryView::staticMetaObject.className() ) )
+        return new SummaryView( parent, parentWidget );
     if ( !qstrcmp( className, FolderView::staticMetaObject.className() ) )
         return new FolderView( parent, parentWidget );
+    if ( !qstrcmp( className, GlobalListView::staticMetaObject.className() ) )
+        return new GlobalListView( parent, parentWidget );
     if ( !qstrcmp( className, IssueView::staticMetaObject.className() ) )
         return new IssueView( parent, parentWidget );
-    if ( !qstrcmp( className, CommentView::staticMetaObject.className() ) )
-        return new CommentView( parent, parentWidget );
     return NULL;
 }
