@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -47,23 +47,28 @@ void ViewManager::openUsersView()
     openView( "UsersView", 0 );
 }
 
+void ViewManager::openSummaryView( int projectId )
+{
+    openView( "SummaryView", projectId );
+}
+
 void ViewManager::openFolderView( int folderId )
 {
     openView( "FolderView", folderId );
 }
 
-void ViewManager::openIssueView( int issueId, int itemId /*= 0*/ )
+void ViewManager::openGlobalListView( int typeId )
+{
+    openView( "GlobalListView", typeId );
+}
+
+void ViewManager::openIssueView( int issueId, int itemId )
 {
     IssueView* view = (IssueView*)openView( "IssueView", issueId );
     if ( itemId != 0 )
         view->gotoItem( itemId );
 }
 
-void ViewManager::openCommentView( int issueId )
-{
-    openView( "CommentView", issueId );
-}
-
 bool ViewManager::queryCloseViews()
 {
     QList<View*> views = m_views.keys();
