@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -69,21 +69,26 @@ public:
     */
     void openUsersView();
 
+    /**
+    * Open the project summary view for the given project.
+    */
+    void openSummaryView( int projectId );
+
     /**
     * Open the folder view for the given folder.
     */
     void openFolderView( int folderId );
 
+    /**
+    * Open the global list view of the given type.
+    */
+    void openGlobalListView( int typeId );
+
     /**
     * Open the issue details view for the given issue.
     */
     void openIssueView( int issueId, int itemId = 0 );
 
-    /**
-    * Open the add comment view for the given issue.
-    */
-    void openCommentView( int issueId );
-
     /**
     * Add the view to the view manager.
     */
