@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -68,6 +68,11 @@ public:
     */
     virtual QString inputValue() = 0;
 
+    /**
+    * Set the identifier of the project associated with the editor.
+    */
+    virtual void setProjectId( int projectId ) = 0;
+
 protected:
     /**
     * Called by inherited classes to set the editor's widget.
