@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -122,19 +122,16 @@ QString FindBar::text() const
     return m_edit->text();
 }
 
-void FindBar::setFlags( QTextDocument::FindFlags flags )
+void FindBar::setCaseSensitive( bool on )
 {
     bool old = blockSignals( true );
-    m_caseCheckBox->setChecked( ( flags & QTextDocument::FindCaseSensitively ) != 0 );
+    m_caseCheckBox->setChecked( on );
     blockSignals( old );
 }
 
-QTextDocument::FindFlags FindBar::flags() const
+bool FindBar::isCaseSensitive() const
 {
-    QTextDocument::FindFlags flags = 0;
-    if ( m_caseCheckBox->isChecked() )
-        flags |= QTextDocument::FindCaseSensitively;
-    return flags;
+    return m_caseCheckBox->isChecked();
 }
 
 void FindBar::showWarning( bool on )
