@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -58,14 +58,14 @@ public:
     QString text() const;
 
     /**
-    * Set the find flags.
+    * Set the case sensitivity setting.
     */
-    void setFlags( QTextDocument::FindFlags flags );
+    void setCaseSensitive( bool on );
 
     /**
-    * Return the find flags.
+    * Return the case sensitivity setting.
     */
-    QTextDocument::FindFlags flags() const;
+    bool isCaseSensitive() const;
 
     /**
     * Return @c true if find is enabled.
