@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -136,6 +136,8 @@ void InputLineEdit::updateInput()
     int length = selectedText().length();
     int position = cursorPosition();
 
+    bool modified = isModified();
+
     QString value = inputValue();
 
     if ( !m_error || m_empty ) {
@@ -147,6 +149,8 @@ void InputLineEdit::updateInput()
             else
                 setSelection( start + length, -length );
         }
+
+        setModified( modified );
     }
 }
 
@@ -179,11 +183,7 @@ void InputLineEdit::calculateLayout()
         m_errorLabel->hide();
     }
 
-#if ( QT_VERSION >= 0x040500 )
     setTextMargins( 0, 0, padding, 0 );
-#else
-    setStyleSheet( QString( "QLineEdit { padding-right: %1px; }" ).arg( padding ) );
-#endif
 
     setMinimumHeight( qMax( minimumSizeHint().height(), buttonSize.height() + 2 * frameWidth ) );
 }
@@ -323,12 +323,16 @@ void EnumLineEdit::setItems( const QStringList& items )
     completer->setCaseSensitivity( Qt::CaseInsensitive );
     completer->setMultiSelect( m_multiSelect );
 
-#if ( QT_VERSION >= 0x040600 )
     completer->setMaxVisibleItems( 10 );
-#endif
 
     setCompleter( completer );
 
+    if ( hasFocus() ) {
+        disconnect( completer, NULL, this, NULL );
+        connect( completer, SIGNAL( activated( const QString& ) ), this, SLOT( setCompletedText( const QString& ) ) );
+        connect( completer, SIGNAL( highlighted( const QString& ) ), this, SLOT( setCompletedText( const QString& ) ) );
+    }
+
     setPopupVisible( !items.isEmpty() );
 }
 
@@ -398,6 +402,26 @@ void EnumLineEdit::popup()
     completer()->complete();
 }
 
+void EnumLineEdit::focusInEvent( QFocusEvent* e )
+{
+    QLineEdit::focusInEvent( e );
+
+    QCompleter* comp = completer();
+    if ( comp ) {
+        disconnect( comp, NULL, this, NULL );
+        connect( comp, SIGNAL( activated( const QString& ) ), this, SLOT( setCompletedText( const QString& ) ) );
+        connect( comp, SIGNAL( highlighted( const QString& ) ), this, SLOT( setCompletedText( const QString& ) ) );
+    }
+}
+
+void EnumLineEdit::setCompletedText( const QString& newText )
+{
+    if ( newText != text() ) {
+        setText( newText );
+        setModified( true );
+    }
+}
+
 NumericLineEdit::NumericLineEdit( QWidget* parent ) : InputLineEdit( parent ),
     m_decimal( 0 ),
     m_stripZeros( false ),
@@ -440,21 +464,21 @@ void NumericLineEdit::setMaxValue( double value )
 
 void NumericLineEdit::updateValidator()
 {
-    DefinitionInfo info = DefinitionInfo::fromString( dataManager->setting( "number_format" ) );
+    DefinitionInfo numberFormat = dataManager->numberFormat();
 
     QString pattern;
 
     if ( format() == Identifier )
         pattern = "#?";
 
-    QString groupSeparator = info.metadata( "group-separator" ).toString();
+    QString groupSeparator = numberFormat.metadata( "group-separator" ).toString();
     if ( !groupSeparator.isEmpty() )
         pattern += "-?(\\d*|\\d{0,3}(" + QRegExp::escape( groupSeparator ) + "\\d{0,3})*)";
     else
         pattern += "-?\\d*";
 
     if ( m_decimal > 0 )
-        pattern += "(" + QRegExp::escape( info.metadata( "decimal-separator" ).toString() ) + QString( "\\d{0,%1})?" ).arg( m_decimal );
+        pattern += "(" + QRegExp::escape( numberFormat.metadata( "decimal-separator" ).toString() ) + QString( "\\d{0,%1})?" ).arg( m_decimal );
 
     delete validator();
 
@@ -534,7 +558,7 @@ void DateTimeLineEdit::setLocalTime( bool local )
 
 void DateTimeLineEdit::updateValidator()
 {
-    DefinitionInfo dateFormat = DefinitionInfo::fromString( dataManager->setting( "date_format" ) );
+    DefinitionInfo dateFormat = dataManager->dateFormat();
 
     QString dateSeparator = dateFormat.metadata( "date-separator" ).toString();
     QString order = dateFormat.metadata( "date-order" ).toString();
@@ -551,7 +575,7 @@ void DateTimeLineEdit::updateValidator()
     pattern += parts.value( order.at( 2 ) );
 
     if ( m_withTime ) {
-        DefinitionInfo timeFormat = DefinitionInfo::fromString( dataManager->setting( "time_format" ) );
+        DefinitionInfo timeFormat = dataManager->timeFormat();
 
         pattern += QLatin1String( " \\d{0,2}" );
         pattern += QRegExp::escape( timeFormat.metadata( "time-separator" ).toString() );
@@ -629,7 +653,7 @@ void DateTimeLineEdit::popup()
         m_calendar->setMinimumDate( QDate( 1, 1, 1 ) );
         m_calendar->setMaximumDate( QDate( 9999, 12, 31 ) );
 
-        int firstDayOfWeek = dataManager->setting( "first_day_of_week" ).toInt();
+        int firstDayOfWeek = dataManager->localeSetting( "first_day_of_week" ).toInt();
         m_calendar->setFirstDayOfWeek( (Qt::DayOfWeek)( firstDayOfWeek != 0 ? firstDayOfWeek : 7 ) );
 
         connect( m_calendar, SIGNAL( activated( QDate ) ), this, SLOT( setDate( QDate ) ) );
@@ -640,13 +664,11 @@ void DateTimeLineEdit::popup()
         layout->setSpacing( 0 );
         layout->addWidget( m_calendar );
 
-        if ( ( functions() & TodayFunction ) ) {
-            QPushButton* todayButton = new QPushButton( tr( "Today" ), m_popup );
+        QPushButton* todayButton = new QPushButton( tr( "Today" ), m_popup );
 
-            connect( todayButton, SIGNAL( clicked() ), this, SLOT( setToday() ) );
+        connect( todayButton, SIGNAL( clicked() ), this, SLOT( setToday() ) );
 
-            layout->addWidget( todayButton, 0, Qt::AlignHCenter );
-        }
+        layout->addWidget( todayButton, 0, Qt::AlignHCenter );
     }
 
     QString value = text();
@@ -689,10 +711,10 @@ void DateTimeLineEdit::setDate( const QDate& date )
         suffix = text().mid( index );
 
     if ( suffix.isEmpty() && m_withTime ) {
-        DefinitionInfo format = DefinitionInfo::fromString( dataManager->setting( "time_format" ) );
-        if ( format.metadata( "time-mode" ).toInt() == 12 )
+        DefinitionInfo timeFormat = dataManager->timeFormat();
+        if ( timeFormat.metadata( "time-mode" ).toInt() == 12 )
             suffix = " 12:00 am";
-        else if ( format.metadata( "pad-hour" ).toBool() )
+        else if ( timeFormat.metadata( "pad-hour" ).toBool() )
             suffix = " 00:00";
         else
             suffix = " 0:00";
@@ -701,12 +723,24 @@ void DateTimeLineEdit::setDate( const QDate& date )
     Formatter formatter;
     setText( formatter.formatDate( date ) + suffix );
 
+    setModified( true );
+
     m_popup->hide();
 }
 
 void DateTimeLineEdit::setToday()
 {
-    setInputValue( "[Today]" );
+    if ( ( functions() & TodayFunction ) ) {
+        setInputValue( "[Today]" );
+    } else {
+        Formatter formatter;
+        if ( m_withTime )
+            setText( formatter.formatDateTime( QDateTime::currentDateTime(), false ) );
+        else
+            setText( formatter.formatDate( QDate::currentDate() ) );
+    }
+
+    setModified( true );
 
     m_popup->hide();
 }
