@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -128,6 +128,11 @@ protected: // overrides
     QString textToValue( const QString& text );
     void popup();
 
+    void focusInEvent( QFocusEvent* e );
+
+private slots:
+    void setCompletedText( const QString& newText );
+
 private:
     QStringList m_items;
 
