@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -43,6 +43,8 @@ InputTextEdit::InputTextEdit( QWidget* parent ) : QPlainTextEdit( parent ),
     m_errorLabel->setAlignment( Qt::AlignCenter );
 
     calculateLayout();
+
+    updateTabStopWidth();
  }
 
 InputTextEdit::~InputTextEdit()
@@ -123,6 +125,8 @@ void InputTextEdit::updateInput()
     int anchor = oldCursor.anchor();
     int position = oldCursor.position();
 
+    bool modified = document()->isModified();
+
     QString value = inputValue();
 
     if ( !m_error || m_empty ) {
@@ -132,6 +136,8 @@ void InputTextEdit::updateInput()
         newCursor.setPosition( anchor );
         newCursor.setPosition( position, QTextCursor::KeepAnchor );
         setTextCursor( newCursor );
+
+        document()->setModified( modified );
     }
 }
 
@@ -225,3 +231,15 @@ void InputTextEdit::setError( int code )
     setError( helper.errorMessage( (ErrorHelper::ErrorCode)code ) );
 }
 
+void InputTextEdit::changeEvent( QEvent* e )
+{
+    QPlainTextEdit::changeEvent( e );
+
+    if ( e->type() == QEvent::FontChange )
+        updateTabStopWidth();
+}
+
+void InputTextEdit::updateTabStopWidth()
+{
+    setTabStopWidth( fontMetrics().width( QLatin1Char( ' ' ) ) * 8 );
+}
