@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -67,6 +67,7 @@ public:
 protected: // overrides
     void resizeEvent( QResizeEvent* e );
     void focusOutEvent( QFocusEvent* e );
+    void changeEvent( QEvent* e );
 
 private:
     void updateInput();
@@ -78,6 +79,8 @@ private:
 
     void setError( int code );
 
+    void updateTabStopWidth();
+
 private:
     QLabel* m_errorLabel;
 
