@@ -1,7 +1,7 @@
 /**************************************************************************
 * This file is part of the WebIssues Desktop Client program
 * Copyright (C) 2006 Michał Męciński
-* Copyright (C) 2007-2012 WebIssues Team
+* Copyright (C) 2007-2013 WebIssues Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -106,7 +106,7 @@ EnumMetadataEditor::EnumMetadataEditor( QObject* parent, QWidget* parentWidget )
 
     connect( m_editableCheckBox, SIGNAL( toggled( bool ) ), this, SLOT( checkBoxToggled() ) );
 
-    m_multiSelectCheckBox = new QCheckBox( tr( "Allow &selecting multiple itmes" ), widget );
+    m_multiSelectCheckBox = new QCheckBox( tr( "Allow &selecting multiple items" ), widget );
     layout->addWidget( m_multiSelectCheckBox, 1, 0, 1, 2 );
 
     connect( m_multiSelectCheckBox, SIGNAL( toggled( bool ) ), this, SLOT( checkBoxToggled() ) );
@@ -339,7 +339,7 @@ UserMetadataEditor::UserMetadataEditor( QObject* parent, QWidget* parentWidget )
 
     m_membersCheckBox = new QCheckBox( tr( "&Allow selecting only project members" ), widget );
     layout->addWidget( m_membersCheckBox );
-    m_multiSelectCheckBox = new QCheckBox( tr( "Allow &selecting multiple itmes" ), widget );
+    m_multiSelectCheckBox = new QCheckBox( tr( "Allow &selecting multiple items" ), widget );
     layout->addWidget( m_multiSelectCheckBox );
 
     setWidget( widget );
